#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "hwidth_14":        256,    #896    =ko_kai
cvt_dict = {
    "w_1337":           57,     #1337
    "w_1290":           127,    #1290
    "w_1231":           75,     #1231
    "w_1180":           73,     #1180
    "w_1133":           60,     #1133
    "w_1120":           200,    #1120
    "w_1112":           228,    #1112
    "w_1081":           71,     #1081
    "w_1051":           225,    #1051
    "w_1024":           138,    #1024
    "w_973":            178,    #973
    "w_926":            275,    #926
    "w_866":            286,    #866
    "w_569":            58,     #569
    "w_522":            108,    #522
    "w_455":            109,    #455
    "w_397":            45,     #397
    "w_385":            44,     #385
    "w_307":            1,      #307
    "w_291":            87,     #291
    "w_264":            271,    #264
#
    "w_236":            159,    #236
    "w_213":            102,    #213
    "w_195":            144,    #195
    "w_172":            16,     #172
    "w_154":            85,     #154
    "w_139":            238,    #139
#
    "base":             10,     #0
    "hstem":            13,         #358
    "hstem_curve":      144,        #195    =big curve hstem
    "hstem_thin":       54,         #246
#
    "vstem_236":        159,        #236    =3 spline, thinner
    "vstem_258":        161,        #258    =2 spline, thicker
    "vstem_thin":       85,         #154
    "vstem_small":      221,        #133 
    "vstem_tiny":       124,        #152
#
    "headstem":         30,         #127
    "headstem_plus_hole":   301,    #279
    "headstem_small":   36,         #113    =kho
    "headstem_small_plus_hole":   271,          #264
    "headstem_tiny":    158,        #106
    "headstem_tiny_plus_hole":    4,            #233
    "headstem_wan":     260,    #60
    "headstem_big":     16,     #172
    "headstem_sara":    59,     #88
    "headstem_sara_plus_hole":    94,    #193
    "sarastem":         30,         #127
#
    "headdia":          298,        #406
    "headdia_small":    198,        #377    =kho
    "headdia_tiny":     24,         #340
    "headdia_sara":     91,         #281
    "headhole":         131,        #152    
    "headneck_kho":     39,     #180    =kho
#
    "hwidth_a":         61,     #1085   =a
    "hwidth_ching":     275,    #926    =cho_ching
#
    "hnext_1":          58,         #569    =next spline of sho_sher
#
    "vheight":          179,        #1120   =normal height 
    "vheight_shoot":    202,        #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       163,        #1556   =po_pla, fo_fa
    "vheight_o":        197,        #1638   =sara_o, sara_i
    "vheight_lo":       152,        #29 
    "vheight_lu":       98,         #410    =lo_lu
    "vheight_below_do": 98,     #410
    "vheight_num":      275,        #926
    "vheight_sara1":    127,        #1290
#
    "head_diff":        131,    #254    =head of character: bo,po
    "beak_diff":        148,    #84     =beak of ko,tho
    "beak_diff_2":      38,     #340    =beak of ko,tho
#
    "front_001":        7,          #162
#
    "front_kai":        59,         #88     =front spacing of ko_kai
    "front_khai":       262,        #20     =front spacing of kho_khai
    "front_dek":        30,         #127
    "front_thahan":    38,         #37
#
    "front_khuad":      157,    #451    =front spacing of kho_khud
    "front_tahan":      38,     #340    =front spaceing of to_tahan
    "front_dek":        106,    #213    =front spaceing of do_dek
    "front_thong":      79,     #229    =front spaceing of to_thong
    "front_pung":       228,    #174    =front spaceing of po_pung
    "front_pan":        31,     #330    =front spacing of do_chada, po_pan
    "front_ma":         180,    #377    =front spaceing of mo_ma
    "front_ling":       1,      #184    =front spaceing of lo_ling, aw_ang
#
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
#gap
    "gap_20":           262,    #20
    "gap_88":           59,     #88
    "gap_113":          36,     #113
    "gap_143":          129,    #143
    "gap_162":          7,      #162
    "gap_172":          16,     #172
    "gap_186":          41,     #186
    "gap_195":          144,    #195
    "gap_236":          159,    #236
}

#SKEL
#vd: vstem delta shift
#f_deltap    x 16+4  x 17+2  x 18+2  x 19+2  x 23+4  x 24+4  x 25+4  x 31+4

#hd: head delta shift
#top head
#f_deltap    y 17+8  y 18+8  y 19+8
#bottom_head
#f_deltap    y 17-8  y 18-8  y 19-8

#sd: sara delta shift
#1
#f_deltap   y 12+8  y 16+8  y 18+8  y 38+8  
######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
SRP0    26
mirp[rp0,rnd,grey]  gap_186 14
ip  18
mirp[min,rnd,grey]  hstem 12
srp0    27
mdrp[rp0,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 25
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 13
mirp[rp0,rnd,grey]  vheight_shoot   22
ip  17
ip  8
mdrp[grey]  5
IUP[y]
""",

    #kho_khai
    "uni0E02":  """
SRP0    52
mdrp[rp0,rnd,white] 1
f_deltap    1 20-8
mirp[min,rnd,grey]  hstem 29
mdrp[rp0,rnd,grey]  7
f_deltap    7 12-8  7 13-8  7 14-8  7 19+8  7 28-8
mdrp[grey]  24
mdrp[rp0,rnd,white] 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-8
ip  49
ip  43
srp0    53
mdrp[rp0,rnd,grey]  34
f_deltap    34 14+8  34 15+8
mirp[min,rnd,grey]  hstem 36
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  31
mirp[rnd,grey]  vheight 36
mirp[rp0,rnd,grey]  vheight_shoot 21
mdrp[rnd,grey]  10
mdrp[rnd,grey]  15
ip  46
rp  40
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
#SRP0    58
#mdrp[rp0,rnd,white] 1
#mirp[rnd,grey]  hstem 35
#mdrp[rp0,rnd,grey]  7
#mdrp[grey]  30
#mdrp[rp0,rnd,grey]  22
#f_deltap    22 14-8  22 15-8   22 29+8
#mdrp[rnd,grey] 16
#f_deltap    16 12-8  16 13-8  16 17-8  16 18-8  16 22-8  16 23-8  16 29-8  16 31-8  
#ip  55
#ip  49
#ip  13
#srp0    59
#f_deltap    59 10+8
#mdrp[rp0,rnd,grey]  40
#f_deltap    40 14+8  40 15+8  40 18+8  40 22+8  40 26+8  40 30+8  40 31+8  
#mirp[min,rnd,grey]  hstem 42
#IUP[x]
##
#SVTCA[y-axis]
#MDAP[rnd]   0
#mdrp[grey]  37
#mirp[rnd,grey]  vheight 42
#mirp[rp0,rnd,grey]  vheight_shoot   27
#alignrp 25
#mdrp[rnd,grey]  9
#shp[rp2]    11
#mdrp[rp0,rnd,grey]  13
#f_deltap    13 12+8  13 13+8  13 14+8  13 15+8
#mdrp[rnd,grey]  19
#f_deltap    19 9+8  19 10+8  19 19+8  19 20+8  19 21+8  19 30+8  
#ip  52
#ip  46
#srp1    19
#srp2    1
#ip  3
#ip  34
#IUP[y]
#
#---new interpolated code---
srp0    58
mdrp[rp0,rnd,grey]  7
f_deltap    7 11-8  
ip  22
ip  16
ip  1
mdrp[grey]  30
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 35
mdap[rnd]   22
mdap[rnd]   16
f_deltap    16 16-8  22 16-8  
srp2    22
ip  55
ip  49
ip  13
srp0    59
mdrp[rp0,rnd,grey]  40
f_deltap    40 10+8  40 14+8  40 15+8  40 18+8  40 22+8  40 23+8  40 26+8  40 30+8   
mirp[min,rnd,grey]  hstem 42
iup[x]
#
svtca[y-axis]
mdap[rnd]   0
mdrp[grey]  37
mirp[rnd,grey]  vheight 42
mirp[rp0,rnd,grey]  vheight_shoot 27
mdrp[rnd,grey]  9
mdap[rnd]   13
mdap[rnd]   19
f_deltap    19 14+8
srp2    13
ip  52
ip  46
iup[y]
""",

    #kho_kwai
    "uni0E04": """
SRP0    51
mirp[rp0,rnd,white] gap_113 32
f_deltap    32 11-8  
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  hstem 28
srp0    32
mdrp[rp0,rnd,white] 14
f_deltap    14 12-8  14 13-8  14 16-8  
mdrp[rnd,grey]  20
f_deltap    20 22-8  20 32-8  
ip  48
ip  42
srp0    52
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 28+8  1 30+8  
mirp[min,rnd,grey]  hstem 38
#
f_deltap    25 12-6  25 13-8  
f_deltap    8 20-6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 28
mirp[rp0,rnd,grey]  vheight_shoot 35
mdrp[grey]  5
mdrp[rp0,min,rnd,white] 17
f_deltap    17 12-8  17 13-8  
mdrp[rnd,grey]  23
ip  45
ip  39
ip  25
IUP[y]
""",

    #kho_kon
    "uni0E05": """
SRP0    54
mirp[rp0,rnd,grey]  gap_113 33
f_deltap    33 11-8
mirp[min,rnd,grey]  hstem 9
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  hstem 29
srp0    33
mdrp[rp0,rnd,white] 15
f_deltap    15 12-8  15 13-8 15 16-8
mdrp[rnd,grey]  21
f_deltap    21 32-8
ip  26
ip  51
ip  45
srp0    55
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 28+8  1 30+8
mirp[min,rnd,grey]  hstem 41
#
f_deltap    26 11-5
f_deltap    9 20-6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     29
mirp[rp0,rnd,grey]  vheight_shoot 38
alignrp 36
mdrp[grey]  4
shp[rp2]    7
mdrp[rp0,rnd,grey]  37
mdrp[rp0,rnd,grey]  5
mdrp[rp0,min,rnd,white] 18
mdrp[rnd,grey]  24
ip  48
ip  42
ip  26
IUP[y]
""",

    #kho_rakang
    "uni0E06": """
#---OLD STYLE---
#SRP0    78
#mdrp[rp0,rnd,white] 13
#f_deltap    13 11-8  13 20-8
#mirp[rp0,min,rnd,grey]  hstem 48
#alignrp 3
#mdrp[rnd,grey]  9
#f_deltap    9 15+8  9 18+8  9 24+8  
#ip  75
#ip  69
#srp0    13
#mdrp[rp0,rnd,grey]  19
#f_deltap    19 17+8  19 31-8
#mdrp[grey]  42
#mdrp[rp0,rnd,grey] 34
#f_deltap    34  20+8  34 26+8  
#mdrp[rnd,grey]  28
#f_deltap    28 12-8  28 13-8  28 23-8  
#ip  63
#ip  57
#ip  25
#srp0    79
#mdrp[rp0,rnd,grey]  51
#f_deltap    51 15+8  51 19+8  
#alignrp 1
#mirp[min,rnd,grey]  hstem 53
#IUP[x]
##
#SVTCA[y-axis]
#MDAP[rnd]   1
#mirp[rnd,grey]  vheight_lo 6
#mdrp[grey]  53
#mirp[rnd,grey]  vheight 53
#mirp[rp0,rnd,grey]  vheight_shoot 39
#alignrp     37
#mdrp[grey]  21
#shp[rp2]    23
#mdrp[rp0,rnd,grey]  25
#f_deltap    25 9+8  25 10+8  25 12+8  25 13+8  25 14+8  25 15+8  25 16+8
#mdrp[rnd,grey]  31
#f_deltap    31 19+8  31 20+8  31 21+8  31 26+8  31 30+8  
#ip  60
#ip  54
#srp0    6
#mdrp[rnd,grey]  13
#f_deltap    13 10-8  13 11-8  13 14-8  13 15-8  13 18-8  13 20-8  13 22-8  13 23-8
#ip  49
#ip  72
#ip  66
#ip  3
#srp1    31
#srp2    6
#ip  14
#ip  48
#IUP[y]
#
#---NEW INTERPOLATED STYLE, USE LESS DELTA HINT---
srp0    78
mdrp[rp0,rnd,grey]  19
ip  34
ip  28
ip  13
ip  9
mdrp[grey]  42
mdap[rnd]   13
mirp[min,rnd,grey]  hstem   48
shp[rp2]    3
mdap[rnd]   9
srp2        3
ip      75
ip      69
mdap[rnd]   34
mdap[rnd]   28
f_deltap    28 11-8 
srp2        34
ip  63
ip  57
ip  25
srp0    79
mdrp[rp0,rnd,grey]  51
f_deltap    51 11+8  51 14+8  51 15+8  51 16+8  
alignrp 1
mirp[min,rnd,grey]  hstem   53
iup[x]
#
svtca[y-axis]
mdap[rnd]   1
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 53
mirp[rp0,rnd,grey]  vheight_shoot   39
alignrp 37
ip  25
ip  31
ip  13
mdrp[rnd,grey]  21
shp[rp2]    23
mdap[rnd]   25
mdap[rnd]   31
f_deltap    31 18+8  31 19+8  
srp2    25
ip  60
ip  54
mdap[rnd]   13
srp2    6
ip  72
ip  66
ip  49
ip  3
iup[y]
""",

    #ngo_ngu
    "uni0E07": """
SRP0    35
mdrp[rp0,rnd,grey]  9
mirp[rp0,min,rnd,grey]  hstem 20
mdrp[rnd,grey]  15
f_deltap    15 16+8  
ip  32
ip  26
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  7
mirp[rp0,rnd,grey]  vheight_shoot 18
mdrp[rnd,grey]  12
ip  29
ip  23
IUP[y]
""",

    #jo_jan
    "uni0E08": """
SRP0    44
mdrp[rp0,rnd,grey]  7
ip  22
mdrp[rnd,grey]  12
ip  41
ip  35
srp0    45
mdrp[rp0,rnd,grey]  16
f_deltap    16 11+8  16 15+8  16 16+8  16 23+8  16 31+8  
mirp[min,rnd,grey]  hstem 29
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 0
ip  13
#
f_deltap    11 16-4
srp1    11
srp2    13
ip  12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot   26
mdrp[grey]  19
mdrp[rp0,rnd,white] 10
mdrp[rnd,grey]  4
ip  38
ip  32
ip  2
#
f_deltap    13 15-4  13 16-4  13 17-8  13 18-8  13 19-8
IUP[y]
""",

    #cho_ching
    "uni0E09": """
SRP0    65
mdrp[rp0,rnd,grey]  1
mirp[rp0,min,rnd,grey]  hstem 12
alignrp 0
mdrp[rnd,grey]  7
f_deltap    7 16+8
ip  22
ip  50
ip  44
srp0    66
mdrp[rp0,rnd,grey]  15
alignrp 39
mirp[min,rnd,grey]  hstem 29
mdrp[rnd,grey]  33
f_deltap    33 9+8  33 10+8  33 15-8  33 19-8  
ip  56
ip  62
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[rnd,grey]  vheight_lo 36
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 26
mdrp[grey]  19
mdrp[rp0,rnd,grey]  10
f_deltap    10 12-8  10 13-8
mdrp[rnd,grey]  4
ip  47
ip  41
srp0    36
mdrp[rnd,grey]  30
shp[rp2]    15
ip  39
ip  59
ip  53
IUP[y]
""",

    #cho_chang
    "uni0E0A": """
SRP0    63
mdrp[rp0,rnd,white] 1
f_deltap    1 19+8  1 20-8  1 28-8  
mirp[min,rnd,grey]  hstem 29
mdrp[rp0,rnd,grey]  7
f_deltap    7 12-8  7 13-8  7 14-8  
mdrp[grey]  24
mdrp[rp0,rnd,white] 12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-8
ip  60
ip  54
ip  10
srp0    64
mdrp[rp0,rnd,grey]  34
f_deltap    34 10-8  
mdrp[grey]  37
mirp[min,rnd,grey]  hstem 47
ip  45
mdrp[rp0,rnd,grey]  41
mirp[min,rnd,grey]  hstem 42
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  31
mirp[rp0,rnd,grey]  vheight_shoot 21
ip 38
ip 37
ip 45
mdrp[grey]  41
mdrp[min,rnd,grey]  10
mdrp[rnd,grey]  15
ip  57
ip  51
IUP[y]
""",

    #so_zo
    "uni0E0B": """
#SRP0    69
#mdrp[rp0,rnd,white] 1
#mirp[min,rnd,grey]  hstem 35
#mdrp[rp0,rnd,grey]  7
#mdrp[grey]  30
#mdrp[rp0,rnd,grey]	22
#f_deltap    22 12+8  22 13+8   22 14-8  22 15-8
#mdrp[rnd,grey]	16
#f_deltap    16 12-8  16 13-8
#ip	13
#ip	66
#ip	60
#srp0    70
#mdrp[rp0,rnd,grey]  40
#f_deltap	40 15+8  
#mirp[min,rnd,grey]  hstem 53
#ip   51
#mdrp[rp0,rnd,grey]  47
#mirp[min,rnd,grey]  hstem 48
#IUP[x]
##
#SVTCA[y-axis]
#MDAP[rnd]   0
#mdrp[grey]  37
#mirp[rp0,rnd,grey]  vheight_shoot 27
#alignrp 25
#ip  44
#ip  51
#ip  43
#mdrp[grey]  47
#mdrp[rnd,grey]  9
#shp[rp2]    11
#mdrp[rp0,rnd,grey]  13
#f_deltap    13 12+8  13 13+8  13 14+8  13 15+8  13 16+8  
#mdrp[rnd,grey]  19
#f_deltap    19 9+8  19 10+8  19 11+8  19 19+8  19 20+8  19 21+8  
#ip  63
#ip  57
##
#srp1    19
#srp2    1
#ip  3
#ip  34
#IUP[y]
#
#---new interpolated code
srp0    69
mdrp[rp0,rnd,grey]  7
f_deltap    7 11-8  7 20-8  
ip  22
ip  16
ip  1
mdrp[grey]  30
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 35
mdap[rnd]   22
mdap[rnd]   16
f_deltap    16 16-8  22 16-8
srp2    22
ip  66
ip  60
ip  13
srp0    70
mdrp[rp0,rnd,grey]  40
f_deltap    40 15+8
mirp[min,rnd,grey]  hstem 53
ip  51
mdrp[grey]  43
mdrp[rp0,rnd,grey]  47
mirp[min,rnd,grey]  hstem 48
iup[x]
#
svtca[y-axis]
mdap[rnd]   0
mdrp[grey]  37
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     25
ip  44
ip  51
ip  43
ip  13
ip  19
mdrp[grey]  47
mdrp[rnd,grey]  9
shp[rp2]    11
mdap[rnd]   13
mdap[rnd]   19
f_deltap    19 18+8  19 19+8  
srp2    13
ip  63
ip  57
iup[y]
""",

    #sho_sher
    "uni0E0C": """
SRP0    74
mirp[rp0,rnd,grey]  gap_186 33
f_deltap    33 16+8  
mirp[min,rnd,grey]  hstem 23
mdrp[rnd,grey]  28
f_deltap    28 16-8
ip  59
ip  53
mdrp[rp0,rnd,grey]  12
f_deltap    12 10-8
srp1    28
ip  9
mirp[rnd,grey]  hstem 44
mdap[rnd]   9
mdrp[rnd,grey]  3
ip  71
ip  65
srp0    75
mdrp[rp0,rnd,grey]  47
alignrp 1
mirp[min,rnd,grey]  hstem 49
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  47
mirp[rnd,grey]  vheight_lo  6
shp[rp2]    31
mirp[rnd,grey]  vheight 49
mirp[rp0,rnd,grey]  vheight_shoot 41
ip  19
ip  36
mdrp[grey]  16
srp0    31
mdrp[rnd,grey]  25
shp[rp2]    12
shp[rp2]    45
ip  56
ip  50
ip  68
ip  62
ip  3
IUP[y]
""",

    #yo_ying
    "uni0E0D": """
SRP0    79
mirp[rp0,rnd,grey]  gap_186 22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  17
f_deltap    17 16-8
ip  47
ip  41
mdrp[rp0,rnd,grey]  1
f_deltap    1 10-8  
mirp[min,rnd,grey]  hstem 33
srp0    80
mdrp[rp0,rnd,grey]  35
f_deltap    35 11+8  
mirp[min,rnd,grey]  hstem   37
####################
ip  65
srp0    1
mdrp[rp0,rnd,grey]  53
mdrp[rnd,grey]  59
ip  76
ip  70
ip  61
#################
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  34
mirp[rnd,grey]  vheight_lo 20
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    20
mdrp[rnd,grey]  14
ip  44
ip  38
##################3
srp0    1
mdrp[rp0,min,rnd,white] 56
alignrp     64
mdrp[rp0,rnd,grey]  50
ip  73
ip  67
mdrp[min,rnd,grey]  61
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
SRP0    50
mirp[rp0,rnd,grey]  gap_186 22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  17
f_deltap    17 16-8
ip  47
ip  41
mdrp[rp0,rnd,grey]  1
f_deltap    1 10-8  
mirp[min,rnd,grey]  hstem 33
srp0    51
mdrp[rp0,rnd,grey]  35
f_deltap    35 11+8  
mirp[min,rnd,grey]  hstem   37
####################
#################
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  34
mirp[rnd,grey]  vheight_lo 20
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    20
mdrp[rnd,grey]  14
ip  44
ip  38
##################
##################
IUP[y]
""",

    #do_chada
    "uni0E0E": """
SRP0    71
mdrp[rp0,rnd,grey]  39
mirp[rp0,min,rnd,grey]  hstem 29
mdrp[rnd,grey]  35
f_deltap    35 16+8  
ip  60
ip  54
srp0    72
mdrp[rp0,rnd,grey]  18
f_deltap    18 15+8  18 16+8  
alignrp 1
mirp[min,rnd,grey]  hstem 50
mdrp[rnd,grey]  8
sloop   5
ip  69 65 13 16 3
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   72
mirp[rnd,grey]  vheight_lo 32
mirp[rnd,grey]  vheight_lu 5
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 48
ip  25
ip  43
mdrp[grey]  22
srp0    32
mdrp[rnd,grey]  38
ip  57
ip  51
srp0    5
mdrp[rnd,grey]  11
ip  67
ip  63
IUP[y]
""",

    #to_patak
    "uni0E0F": """
SRP0    78
mdrp[rp0,rnd,grey]  46
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rnd,grey]  42
f_deltap    42 16+8  
ip  67
ip  61
srp0    79
mdrp[rp0,rnd,grey]  25
f_deltap    25 15+8  25 16+8  
mirp[min,rnd,grey]  hstem 57
mdrp[rnd,grey]  12
sloop   7
ip  76 72 17 6 20 22 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   78
mirp[rnd,grey]  vheight_lo 39
mirp[rnd,grey]  vheight_lu 9
shp[rp2]    4
shp[rp2]    1
mirp[rp0,rnd,grey]  vheight_shoot 54
ip  32
ip  49
mdrp[grey]  29
srp0    39
mdrp[rnd,grey]  45
ip  64
ip  58
srp0    9
mdrp[rnd,grey]  15
ip  74
ip  70
ip  22
ip  25
ip  6
ip  2
IUP[y]
""",

    #tho_than
    "uni0E10": """
SRP0    113
mdrp[rp0,rnd,grey]  16
ip  19
ip  7
ip  54
ip  48
ip  12
ip  1
ip  13
mirp[min,rnd,grey]  hstem 42
mdap[rnd]   7
mdap[rnd]   12
srp2    7
ip  54
ip  48
ip  2
mdap[rnd]   1
mirp[min,rnd,grey]  hstem   0
#######################
srp0    42
mdrp[rp0,rnd,grey]  90
mdrp[rnd,grey]  84
ip  102
ip  96
mdrp[min,rnd,grey]  80
mdrp[rnd,grey]  67
ip  111
ip  107
ip  75
######################
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 22
ip  39
ip  10
ip  4
mdap[rnd]   10
f_deltap    10 16-8
mdap[rnd]   4
srp2    10
ip  51
ip  45
ip  2
srp2    37
ip  17
ip  41
######################
srp0    1
mdrp[rp0,min,rnd,grey]  87
mdrp[rp0,rnd,grey]  81
ip  99
ip  93
mdrp[rp0,rnd,grey]  57
alignrp 61
alignrp 64
ip  80
ip  76
mdrp[rnd,grey]  70
ip  109
ip  104
####################
IUP[y]
""",

    #tho_than.descless
    "uni0E10.descless": """
SRP0    57
mdrp[rp0,rnd,grey]  16
ip  19
ip  7
ip  54
ip  48
ip  12
ip  1
ip  13
mirp[min,rnd,grey]  hstem 42
mdap[rnd]   7
mdap[rnd]   12
srp2    7
ip  54
ip  48
ip  2
mdap[rnd]   1
mirp[min,rnd,grey]  hstem   0
#######################
######################
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 22
ip  39
ip  10
ip  4
mdap[rnd]   10
f_deltap    10 16-8
mdap[rnd]   4
srp2    10
ip  51
ip  45
ip  2
srp2    37
ip  17
ip  41
######################
####################
IUP[y]
""",

    #to_nangmonto
    "uni0E11": """
#f_deltap    72 10+8  72 11+8  72 19+8  72 21+8  72 22+8  72 32+8
#srp0    71
#mdrp[rp0,rnd,grey]  29
#f_deltap    29 11-8
#mirp[min,rnd,grey]  headstem_small 62
#mirp[rp0,rnd,grey]  headstem_small_plus_hole 68
#mdrp[grey]  24
#mdrp[grey]  35
#srp0    29
#mdrp[rp0,rnd,white] 18
#f_deltap    18 17-4   18 20-8   18 28-8
#mdrp[grey]  43
#srp2    24
#sloop   6
#ip      38 39 40 20 21 22
#mdrp[rp0,rnd,grey]  12
#mdap[rnd]   12
#f_deltap    12 11+8   12 14+8   12 17-8   12 18+8   12 24-8   12 25+8   12 26+8   12 27+8   
#mirp[min,rnd,grey]  hstem 48
#shp[rp2]    11
##
#srp0    72
#mirp[rp0,rnd,grey]  gap_162 58
#mirp[min,rnd,grey]  hstem 1
#srp1    43
#ip  54
#ip  6
#IUP[x]
##
#SVTCA[y-axis]
#mdap[rnd]  11
#alignrp     1
#mirp[min,rnd,grey]  vstem_236   49
#mirp[rp0,rnd,grey]  vheight_shoot   56
#alignrp     38
#alignrp     40
#mirp[min,rnd,grey]  vstem_236 4
#srp0    38
#mirp[min,rnd,grey]  sarastem 22
#shp[rp2]    20
#mdrp[rp0,min,rnd,grey]  39
#mirp[rp0,min,rnd,grey]  sarastem 21
#mdrp[rp0,rnd,white] 26
#f_deltap    26 10+8 
#mdrp[min,rnd,grey]  24
#mirp[min,rnd,grey]  headstem_small 65
#mirp[rp0,rnd,grey]  headdia_small 32
#f_deltap    32 9+8   32 19+8
#mirp[min,rnd,grey]  headstem_small 59
#srp2    49
#ip      14
#ip      47
#f_deltap    14 12-4   14 13-4   14 15-4   14 16-4   14 17-4   14 20-8
#IUP[y]
#
#---new code---
srp0    69
mdrp[rp0,rnd,grey]  18
f_deltap    18 11-8 
ip  33
ip  27
ip  12
mdrp[grey]  41
mdap[rnd]   12
mirp[min,rnd,grey]  hstem 47
mdap[rnd]   33
mdap[rnd]   27
srp2    33
ip  66
ip  60
ip  24
srp0    70
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  
srp1    41
ip  52
ip  6
ip  50
ip  8
srp1    47
ip  11
mirp[min,rnd,grey]  hstem 56
iup[x]
#
svtca[y-axis]
mdap[rnd]   1
alignrp     11
ip  24
ip  30
mirp[rp0,rnd,grey]  vheight_shoot   54
alignrp     38
alignrp     36
mdrp[grey]  4
mdrp[rnd,grey]  20
shp[rp2]    22
mdap[rnd]   24
mdap[rnd]   30
srp2    24
ip  63
ip  57
iup[y]
""",

    #to_putao
    "uni0E12": """
SRP0    80
mirp[rp0,rnd,grey]  gap_113 42
f_deltap    42 11-8
mirp[min,rnd,grey]  hstem 20
mdrp[rp0,rnd,grey]  39
mirp[min,rnd,grey]  hstem 38
srp2    20
ip      23
srp0    42
mdrp[rp0,rnd,white]  29
mdrp[rp0,rnd,grey]  35
ip  65
ip  59
ip  26
mdrp[rp0,rnd,white] 12
f_deltap    12 16+8
mirp[min,rnd,grey]  hstem 50
mdrp[rp0,rnd,grey]  9
mdrp[rnd,grey]  3
ip  77
ip  71
srp0    81
mdrp[rp0,rnd,grey]  53
alignrp 1
mirp[min,rnd,grey]  hstem 55
#
f_deltap    20 20-4 23 20-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     38
mdrp[grey]  53
mdrp[grey]  23
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 55
mirp[rp0,rnd,grey]  vheight_shoot 47
alignrp     45
mdrp[grey]  15
shp[rp2]    18
mdrp[rp0,rnd,grey]  32
mdrp[rnd,grey]  26
ip  62
ip  56
srp0    6
mdrp[rnd,grey]  12
shp[rp2]    51
ip  74
ip  68
IUP[y]
""",

    #no_nen
    "uni0E13": """
SRP0    74
mirp[rp0,rnd,grey]  gap_186 22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  17
f_deltap    17 16-8  17 20-8 
ip  59
ip  53
mdrp[rp0,rnd,grey]  1
f_deltap    1 15+8  1 19-8  1 20-8 
mirp[min,rnd,grey]  hstem 33
shp[rp2]    0
srp0    75
mdrp[rp0,rnd,grey]  36
f_deltap    36 10+8  36 19-8  36 20-8
mirp[min,rnd,grey]  hstem 38
mdrp[rp0,rnd,grey]  42
f_deltap    42 16-8
mdrp[rnd,grey]  48
ip  71
ip  65
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  34
mirp[rnd,grey]  vheight_lo  20
shp[rp2]    45
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot   30
ip  8
ip  25
mdrp[grey]  5
srp0    20
mdrp[rnd,grey]  14
shp[rp2]    36
shp[rp2]    39
ip  56
ip  50
ip  68
ip  62
IUP[y]
""",

    #do_dek
    "uni0E14": """
SRP0    49
mirp[rp0,rnd,white] gap_113 30
f_deltap    30 11-8  
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  27
mirp[min,rnd,grey]  hstem 26
srp2    8
ip  11
srp0    30
mdrp[rp0,rnd,white] 17
f_deltap    17 12-8  17 13-8  17 30-8  
mdrp[rp0,rnd,grey]  23
ip  46
ip  40
ip  14
srp0    50
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 28+8  1 32+8  
mirp[min,rnd,grey]  hstem 36
#
f_deltap    8 20-4 11 20-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 26
mdrp[grey]  11
mirp[rp0,rnd,grey]  vheight_shoot 33
mdrp[grey]  5
mdrp[rp0,rnd,white] 20
f_deltap    20 12-8
mdrp[rnd,grey]  14
ip  43
ip  37
IUP[y]
""",

    #to_tao
    "uni0E15": """
SRP0    52
mirp[rp0,rnd,white] gap_113 31
f_deltap    31 11-8  
mirp[min,rnd,grey]  hstem 9
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  hstem 27
srp2    9
ip  12
srp0    31
mdrp[rp0,rnd,white] 18
f_deltap    18 12-8  18 13-8  18 30-8  
mdrp[rp0,rnd,grey]  24
ip  49
ip  43
ip  15
srp0    53
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 28+8  1 32+8  
mirp[min,rnd,grey]  hstem 39
#
f_deltap    9 20-4 12 20-4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 27
mdrp[grey]  12
mirp[rp0,rnd,grey]  vheight_shoot 36
alignrp 34
mdrp[grey]  4
shp[rp2]    7
mdrp[rp0,min,rnd,grey] 5
mdrp[rp0,min,rnd,white] 21
mdrp[rnd,grey]  15
ip  46
ip  40
IUP[y]
""",

    #to_tung
    "uni0E16": """
SRP0    46
mirp[rp0,rnd,grey]  gap_186 22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  17
f_deltap    17 16-8
ip  43
ip  37
srp0    47
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 18+8  
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 20
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    20
mdrp[rnd,grey]  14
ip  40
ip  34
IUP[y]
""",

    #tho_thahan
    "uni0E17": """
SRP0    39
mdrp[rp0,rnd,grey]  8
mirp[rp0,min,rnd,grey]  hstem 18
alignrp 7
mdrp[rnd,grey]  13
f_deltap    13 16+7
ip  36
ip  30
srp0    40
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 19+8  1 23+8
mirp[min,rnd,grey]  hstem 26
srp1    10
ip  20
srp1    20
ip  6
srp0    6
mdrp[grey]  22
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 7
mirp[rp0,rnd,grey]  vheight_shoot   16
alignrp 23
mdrp[grey]  4
mdrp[rnd,grey]  10
ip  33
ip  27
IUP[y]
""",

    #to_thong
    "uni0E18": """
SRP0    37
mirp[rp0,rnd,grey]  gap_172 2
f_deltap    2 18-8
#ip  10
mdrp[rnd,grey]  10
mirp[min,rnd,grey]  hstem 4
srp0    38
mdrp[rp0,rnd,grey]  6
f_deltap    6 14+8  6 18+8  6 19+8
mirp[min,rnd,grey]  hstem 33
#
mdrp[rnd,grey]  21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  5
mirp[rp0,rnd,grey]  vheight_shoot 13
sloop   7
ip  3 4 10 11 30 32 8
mdrp[grey]  30
IUP[y]
""",

    #no_nu
    "uni0E19": """
SRP0    52
mdrp[rp0,rnd,grey]  1
f_deltap    1 10-8  
mirp[rp0,min,rnd,grey]  hstem 11
alignrp     0
mdrp[rnd,grey]  6
f_deltap    6 16+8
ip  37
ip  31
srp0    53
mdrp[rp0,rnd,grey]  14
f_deltap    14 16+8  14 23+8
ip  20
mirp[min,rnd,grey]  hstem 16
mdap[rnd]   20
mdrp[rnd,grey]  26
ip  49
ip  43
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  12
mirp[rnd,grey]  vheight_lo  23
mirp[rnd,grey]  vheight 16
mirp[rp0,rnd,grey]  vheight_shoot 9
mdrp[rnd,grey]  3
ip  34
ip  28
srp0    23
mdrp[rnd,grey]  17
shp[rp2]    14
ip  46
ip 40
ip 26
#
f_deltap    26 15+3  26 16+4
IUP[y]
""",

    #bo_baimai
    "uni0E1A": """
SRP0    33
mdrp[rp0,rnd,grey]  3
f_deltap    3 10-8  3 11-8
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[rnd,grey]  8
f_deltap    8 16+8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  15
f_deltap    15 14+8  15 18+8  
mirp[min,rnd,grey]  hstem 17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  15
shp[rp2]    3
mirp[rnd,grey]  vheight 17
mirp[rp0,rnd,grey]  vheight_shoot 11
mdrp[rnd,grey]  4
ip  27
ip  21
IUP[y]
""",

    #po_pla
    "uni0E1B": """
SRP0    33
mdrp[rp0,rnd,grey]  3
f_deltap    3 10-8  3 11-8
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[rnd,grey]  8
f_deltap    8 16+8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  15
f_deltap    15 14+8  15 18+8
mirp[min,rnd,grey]  hstem 17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  15
shp[rp2]    3
mirp[rnd,grey]  vheight_po 19
mirp[rp0,rnd,grey]  vheight_shoot 11
mdrp[rnd,grey]  4
ip  27
ip  21
IUP[y]
""",

    #po_pung
    "uni0E1C": """
SRP0    33
mirp[rp0,rnd,grey]  gap_143 4
mirp[min,rnd,grey]  hstem 14
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 16-8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  18
f_deltap    18 10+8  18 14+8  
alignrp 1
srp1    14
ip  2
mirp[min,rnd,grey]  hstem 20
srp0    2
mdrp[grey]  16
mdrp[grey]  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 3
mdrp[grey]  18
f_deltap    18 14-4  18 15-4  18 16-8
shp[rp2]    15
mirp[rnd,grey]  vheight 20
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rnd,grey]  13
ip  27
ip  21
srp2    1
ip  17
ip  2
IUP[y]
""",

    #fo_fa
    "uni0E1D": """
SRP0    33
mirp[rp0,rnd,grey]  gap_143 4
mirp[min,rnd,grey]  hstem 14
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 16-8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  18
f_deltap    18 10+8  18 14+8
alignrp 1
srp1    14
ip  2
mirp[min,rnd,grey]  hstem 20
srp0    2
mdrp[grey]  16
mdrp[grey]  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 3
mdrp[grey]  18
f_deltap    18 14-4  18 15-4  18 16-8
shp[rp2]    15
mirp[rnd,grey]  vheight_po 20
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rnd,grey]  13
ip  27
ip  21
srp2    1
ip  17
ip  2
IUP[y]
""",

    #po_pan
    "uni0E1E": """
SRP0    33
mdrp[rp0,rnd,grey]  4
f_deltap    4 10-8  
mirp[rp0,min,rnd,grey]  hstem 14
alignrp 3
mdrp[rnd,grey]  9
f_deltap    9 16+8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  19
f_deltap    19 14+8  
alignrp 1
srp1    14
ip  2
mirp[min,rnd,grey]  hstem 20
srp0    2
mdrp[grey]  16
mdrp[grey]  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 3
mdrp[grey]  18
f_deltap    18 14-4  18 15-4  18 16-4
shp[rp2]    15
mirp[rnd,grey]  vheight 20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
ip  27
ip  21
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
SRP0    33
mdrp[rp0,rnd,grey]  4
f_deltap    4 10-8
mirp[rp0,min,rnd,grey]  hstem 14
alignrp 3
mdrp[rnd,grey]  9
f_deltap    9 16+8
ip  30
ip  24
srp0    34
mdrp[rp0,rnd,grey]  19
f_deltap    19 14+8
alignrp 1
srp1    14
ip  2
mirp[min,rnd,grey]  hstem 20
srp0    2
mdrp[grey]  16
mdrp[grey]  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 3
mdrp[grey]  18
f_deltap    18 14-4  18 15-4  18 16-4
shp[rp2]    15
mirp[rnd,grey]  vheight_po 20
shp[rp2]    17
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
ip  27
ip  21
IUP[y]
""",

    #po_sampao
    "uni0E20": """
SRP0    46
mdrp[rp0,rnd,grey]  22
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 16+8
ip  43
ip  37
srp0    47
mdrp[rp0,rnd,grey]  1
f_deltap    1 15+8  
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    15
mdrp[rnd,grey]  21
ip  40
ip  36
IUP[y]
""",

    #mo_ma
    "uni0E21": """
SRP0    53
mdrp[rp0,rnd,grey]  13
f_deltap    13 14+8  
#ip  9
mdrp[rnd,grey]  9
mirp[rp0,min,rnd,grey]  hstem 23
alignrp 3
srp1    9
ip  50
ip  44
mdrp[rnd,grey]  18
f_deltap    18 16+8
ip  38
ip  32
srp0    54
mdrp[rp0,rnd,grey]  26
f_deltap    26 10+8  26 14+8  26 15+8
alignrp 1
mirp[min,rnd,grey]  hstem 28
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[grey]  26
mirp[rnd,grey]  vheight_lo  6
mirp[rnd,grey]  vheight 28
mirp[rp0,rnd,grey]  vheight_shoot 21
mdrp[rnd,grey]  15
ip  35
ip  29
srp0    6
mdrp[rnd,grey]  12
ip  47
ip  41
ip  24
ip  3
#
f_deltap    3 15+3  3 16+3
IUP[y]
""",

    #yo_yak
    "uni0E22": """
SRP0    45
mirp[rp0,rnd,grey]  gap_162 1
mirp[min,rnd,grey]  hstem 28
mdrp[grey]  8
mdrp[rnd,grey]  14
shp[rp2]    23
ip  5
ip  42
ip  36
ip  19
srp0    46
mdrp[rp0,rnd,grey]  30
f_deltap    30 19+8  30 22+8
mirp[min,rnd,grey]  hstem 32
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  30
mirp[rnd,grey]  vheight 32
mirp[rp0,rnd,grey]  vheight_shoot 11
mdrp[rnd,grey]  17
ip  39
ip  33
srp2    30
ip  23
mdap[rnd]   23
srp1    30
ip  24
mdap[rnd]  24
f_deltap    24 13+8
srp1    23
ip  7
IUP[y]
""",

    #ro_ruar
    "uni0E23": """
SRP0    49
mdrp[rp0,rnd,grey]  7
#ip  11
mdrp[rnd,grey]  11
mdrp[rnd,grey]  22
#
mirp[rp0,min,rnd,grey]  hstem 34
f_deltap    34 16+8
mdrp[rnd,grey]  3
ip  46
ip  40
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   49
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 14
ip  31
ip  22
ip  9
mdrp[grey]  29
srp0    0
mdrp[rnd,grey]  6
ip  43
ip  37
f_deltap    33 16-6
IUP[y]
""",

    #lo_ru
    "uni0E24": """
SRP0    46
mirp[rp0,rnd,grey]  gap_186 22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  17
f_deltap    17 16-8
ip  43
ip  37
srp0    47
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 18+8
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
srp0    46
MIRP[rnd,grey]  vheight_lu 1
mirp[rnd,grey]  vheight_lo 20
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    20
mdrp[rnd,grey]  14
ip  40
ip  34
IUP[y]
""",

    #lo_ling
    "uni0E25": """
SRP0    51
mirp[rp0,rnd,grey]  gap_113 17
mirp[min,rnd,grey]  hstem 7
ip  31
mdrp[rnd,grey]  12
f_deltap    12 16-8
ip  48
ip  42
srp0    52
mdrp[rp0,rnd,grey]  25
f_deltap    25 14+8  25 15+8  25 18+8
alignrp 1
mirp[min,rnd,grey]  hstem 38
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 35
ip  21
mdrp[grey]  28
srp0    15
mdrp[rnd,grey]  9
ip  45
ip  39
mdap[rnd]   21
srp1    9
ip  4
f_deltap    28 12+4  4 12+6   28 13+4 4 13+4   28 20+4  4 20+4   28 21+3 4 21+3
IUP[y]
""",

    #ro_lu
    "uni0E26": """
SRP0    46
mdrp[rp0,rnd,grey]  22
mirp[rp0,min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
f_deltap    18 16+8
ip  43
ip  37
srp0    47
mdrp[rp0,rnd,grey]  1
f_deltap    1 15+8
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
srp0    46
MIRP[rnd,grey]  vheight_lu 1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 30
ip  8
ip  25
mdrp[grey]  5
srp0    15
mdrp[rnd,grey]  21
ip  40
ip  36
IUP[y]
""",

    #wo_wan
    "uni0E27": """
SRP0    36
mdrp[rp0,rnd,grey]  7
mdrp[rnd,grey]  14
f_deltap    7 15+8  7 16+8
#ip  14
mirp[rp0,min,rnd,grey]  hstem 21
mdrp[rnd,grey]  3
f_deltap    3 16+8
ip  33
ip  27
IUP[x]
#
SVTCA[y-axis]
srp0    36
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_shoot 18
mdrp[grey]  11
srp0    0
mdrp[rnd,grey]  6
ip  30
ip  24
IUP[y]
""",

    #so_sala
    "uni0E28": """
SRP0    63
mirp[rp0,rnd,white] gap_113 38
f_deltap    38 11-8
mirp[min,rnd,grey]  hstem 14
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  hstem 34
srp2    14
ip  17
srp0    38
mdrp[rp0,rnd,white] 20
f_deltap    20 12-8  20 13-8  20 16-8  
mdrp[rnd,grey]  26
ip  60
ip  54
ip  31
srp0    64
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 22+8  1 28+8  1 30+8  1 32+8  
mirp[min,rnd,grey]  hstem 50
#
f_deltap    14 20-6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     34
mirp[rp0,rnd,grey]  vheight_shoot 41
mdrp[grey]  11
mdrp[rp0,min,rnd,white] 23
f_deltap    23 12-8  23 13-8  23 23-8  
mdrp[rnd,grey]  29
ip  57
ip  51
ip  31
IUP[y]
""",

    #so_lusi
    "uni0E29": """
SRP0    67
mdrp[rp0,rnd,grey]  3
f_deltap    3 10-8  
mirp[rp0,min,rnd,grey]  hstem 13
mdrp[rnd,grey]  8
f_deltap    8 16+8
ip  52
ip  46
srp0    68
mdrp[rp0,rnd,grey]  15
f_deltap    15 13+8  
srp1    13
ip  21
alignrp 31
mirp[min,rnd,grey]  hstem 33
shp[rp2]    39
mdap[rnd]   21
mdrp[rnd,grey]  27
ip  64
ip  58
ip  29
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  15
shp[rp2]    3
mirp[rnd,grey]  vheight 33
mirp[rp0,rnd,grey]  vheight_shoot 11
ip  24
mdrp[rnd,grey]  5
ip  49
ip  43
mdap[rnd]   24
f_deltap    24 19+8
mdrp[rnd,grey]  18
f_deltap    18 13+8
ip  61
ip  55
ip  34
ip  39
ip  29
IUP[y]
""",

    #so_sua
    "uni0E2A": """
SRP0    63
mirp[rp0,rnd,grey]  gap_113 17
mirp[min,rnd,grey]  hstem 7
ip  37
mdrp[rnd,grey]  12
f_deltap    12 16-8
ip  60
ip  54
srp0    64
mdrp[rp0,rnd,grey]  24
f_deltap    24 14+8  24 15+8  24 18+8
alignrp 1
mirp[min,rnd,grey]  hstem 50
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 15
mirp[rp0,rnd,grey]  vheight_shoot 41
ip  21
mdrp[grey]  34
srp0    15
mdrp[rnd,grey]  9
ip  57
ip  51
mdap[rnd]   21
srp1    9
ip  4
f_deltap    34 12+4  4 12+6   34 13+4 4 13+4   34 20+4  4 20+4   34 21+3 4 21+3
IUP[y]
""",

    #ho_hip
    "uni0E2B": """
SRP0    61
mdrp[rp0,rnd,grey]  8
mirp[rp0,min,rnd,grey]  hstem 18
alignrp 7
mdrp[rnd,grey]  13
f_deltap    13 16+8
ip  46
ip  40
srp0    62
mdrp[rp0,rnd,grey]  1
f_deltap    1 14+8  1 15+8  1 18+8  1 19+8  1 23+8
srp1    18
ip  20
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rp0,rnd,grey]  31
mdrp[rnd,grey]  25
f_deltap    25 20-8
ip  58
ip  52
ip  22
ip  34
srp0    20
mdrp[grey]  6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp     7
mirp[rp0,rnd,grey]  vheight_shoot 16
alignrp 28
mdrp[rnd,grey]  10
ip  43
ip  37
ip  55
ip  49
ip  22
ip  34
mdrp[rnd,grey]  4
f_deltap    19 16-8
IUP[y]
""",

    #lo_chula
    "uni0E2C": """
SRP0    59
mdrp[rp0,rnd,grey]  4
f_deltap    4 10-8  
mirp[rp0,min,rnd,grey]  hstem 14
alignrp 3
mdrp[rnd,grey]  9
f_deltap    9 16+8
ip  44
ip  38
srp0    60
mdrp[rp0,rnd,grey]  18
f_deltap    18 17+8   18 21+8  18 26+8   
srp1    14
ip  2
alignrp 1
mirp[rp0,min,rnd,grey]  hstem 32
mdrp[rnd,grey]  22
ip  56
ip  50
ip  27
srp0    2
mdrp[grey]  16
mdrp[grey]  17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 3
mdrp[grey]  18
f_deltap    18 16-6
shp[rp2]    15
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
ip  41
ip  35
mdrp[rp0,rnd,grey]  25
mdrp[rp0,rnd,grey]  19
ip  53
ip  47
ip  23
ip  32
mdrp[rnd,grey]  17
srp2    1
ip  2
IUP[y]
""",

    #o_ang
    "uni0E2D": """
SRP0    43
mirp[rp0,rnd,white] gap_113 1
mirp[min,rnd,grey]  hstem 11
ip  20
mdrp[rnd,grey]  7
f_deltap    7 13-8  7 16-8
ip  40
ip  34
srp0    44
mdrp[rp0,rnd,grey]  13
f_deltap    13 14+8  13 16+8  13 30+8  
mirp[min,rnd,grey]  hstem 27
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[grey]  17
mdrp[rp0,rnd,white] 4
f_deltap    4 12-8  4 13-8  4 14-8  4 15-8  
mdrp[rnd,grey]  10
ip  37
ip  31
IUP[y]
""",

    #ho_nokhuk
    "uni0E2E": """
SRP0    55
mirp[rp0,rnd,white] gap_113 1
mirp[min,rnd,grey]  hstem 11
mdrp[rnd,grey]  7
f_deltap    7 16-8
ip  44
ip  38
mdrp[rp0,rnd,grey]  21
mdrp[min,rnd,grey]  53
srp0    56
mdrp[rp0,rnd,grey]  13
f_deltap 13 14+8  13 17+8  13 25+8  
mirp[min,rnd,grey]  hstem 31
ip  26
ip  29
mdrp[rnd,grey]  49
ip  16
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  13
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[rnd,grey]  18
f_deltap    18 13-8  18 18-8  
ip  51
ip  47
mdrp[rp0,rnd,grey]  4
mdrp[rnd,grey]  10
ip  41
ip  35
IUP[y]
""",

    #paiyan
    "uni0E2F": """
SRP0    36
mirp[rp0,rnd,grey]  gap_88 8
mdrp[rnd,grey]  14
ip  33
ip  27
ip  17
srp0    37
mdrp[rp0,rnd,grey]  2
f_deltap    2 14+8  2 16+8  
alignrp 22
mirp[min,rnd,grey]  hstem 23
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 11
alignrp     22
mdrp[rp0,rnd,grey]  19
ip  30
ip  24
ip  17
mdrp[min,rnd,grey]  5
IUP[y]
""",

    #sara_a
    "uni0E30": """
srp0    58
mirp[rp0,rnd,white]  gap_88 3
alignrp 32
mdrp[rnd,grey]  9
shp[rp2]    38
ip  26
ip  20
ip  55
ip  49
IUP[x]
#
SVTCA[y-axis]
srp0    58
mdrp[rp0,rnd,grey]  0
mdrp[min,rnd,grey]  11
mdrp[rp0,rnd,grey]  6
ip  23
ip  17
srp0    58
mirp[rp0,rnd,grey]  vheight 35
mdrp[rp0,rnd,grey]  29
ip  52
ip  46
mdrp[min,rnd,grey]  40
IUP[y]
""",

    #sara_maihanakat
    "uni0E31": """
mdap[rnd]   9
mdrp[rnd,grey]  3
ip  26
ip  20
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[min,rnd,grey]  11
mdrp[rnd,grey]  6
ip  23
ip  17
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mirp[rnd,white]  gap_88 8
#
srp0    17
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  5
IUP[y]
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mdrp[rnd,grey]  3
ip  17
ip  11
IUP[x]
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,white]  14
ip  18
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mdrp[rnd,grey]  3
ip  18
ip  12
mdrp[min,rnd,grey]  10
IUP[x]
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,white]  15
ip  19
mdrp[rp0,min,rnd,grey]  7
mdrp[min,rnd,grey]  10
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mdrp[rnd,grey]  3
ip  27
ip  21
mdrp[rp0,rnd,grey]  9
mdrp[rnd,grey]  15
f_deltap    15 12+8  15 13+8  15 14+8  15 15+8
ip  39
ip  33
ip  18
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,white]  24
ip  28
mdrp[rp0,min,rnd,grey]  7
mdrp[rp0,rnd,grey]  18
f_deltap    18 12-8  18 13-8  18 14-8  18 15-8  18 16-8  18 27+8  
mdrp[rnd,grey]  12
f_deltap    12 12+8  12 13+8  12 14+8  12 15+8  12 22+8  12 28+8  
ip  30
ip  36
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mdrp[rnd,grey]  3
ip  23
ip  17
mdrp[rp0,min,rnd,grey]  15
mdrp[rp0,min,rnd,white] 12
mdrp[rp0,min,rnd,grey]  10
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   2
mdrp[rp0,rnd,white]  20
ip  24
mdrp[rp0,min,rnd,grey]  7
mdrp[min,rnd,grey]  10
shp[rp2]    15
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   0
mdrp[min,rnd,grey]	2
mdrp[rnd,grey]	7
ip	23
ip	17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   10
mdrp[rp0,rnd,grey]	4
ip	20
ip	14
mdrp[min,rnd,grey]	1
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   0
mdrp[rp0,min,rnd,grey]	16
mdrp[rp0,min,rnd,grey]	14
mdrp[min,rnd,grey]	2
mdrp[rnd,grey]	7
ip	27
ip	21
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   10
mdrp[rnd,grey]	16
mdrp[rp0,rnd,grey]	4
ip	24
ip	18
mdrp[rnd,grey]	14
mdrp[min,rnd,grey]	1
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[min,rnd,grey]  3
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   6
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    43
mirp[rp0,rnd,grey]	gap_186 3
mdrp[min,rnd,grey]	24
shp[rp2]	35
srp0	44
mdrp[rp0,rnd,grey]	28
mdrp[min,rnd,grey]	17
srp0	44
mdrp[rp0,rnd,grey]	39
mdrp[min,rnd,grey]	17
srp1	24
sloop	8
ip	6 7 33 42 22 31 2 20
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   20
alignrp 3
mdrp[min,rnd,grey]  1
mdrp[rnd,grey]  25
shp[rp2]    24
mdrp[rp0,rnd,grey]  4
alignrp     8
mdrp[min,rnd,grey]  6
mdrp[rnd,grey]  42
shp[rp2]    34
mdrp[rp0,rnd,grey]  31
alignrp     23
mdrp[min,rnd,grey]  36
ip  14
IUP[y]
""",

    #sara_ae
    "uni0E40": """
srp0    25
mdrp[rp0,rnd,grey]	2
mirp[min,rnd,grey]	hstem 4
mdrp[rnd,grey]	9
f_deltap	9 16-8
ip	21
ip	15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  	6
ip	18
ip	12
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mdrp[rp0,rnd,grey]	2
mirp[min,rnd,grey]	hstem 31
mdrp[rnd,grey]	36
f_deltap	36 16-8
ip	48
ip	42
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 10
ip	28
mdrp[grey]  25
srp0	0
mdrp[rnd,grey]	33
ip	45
ip	39
IUP[y]
""",

    #sara_i_moun
    "uni0E43": """
srp0    66
mdrp[rp0,rnd,grey]	2
mirp[min,rnd,grey]	hstem 33
mdrp[rnd,grey]	38
f_deltap	38 16-8
ip	50
ip	44
mdrp[rp0,rnd,grey]	8
mdrp[grey]	28
mdrp[rp0,min,rnd,white]	16
mdrp[rnd,grey]	22
ip	62
ip	56
ip	13
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   66
mirp[rnd,grey]  vheight_lo 0
mdrp[rnd,grey]	35
ip	47
ip	41
mirp[rp0,rnd,grey]  vheight_o 25
mdrp[grey]	11
mdrp[rp0,rnd,grey]	13
mdrp[rnd,grey]	19
ip	59
ip	53
srp2	35
ip	4
ip	32
IUP[y]
""",

    #sara_i_mlai
    "uni0E44": """
SRP0    37
mdrp[rp0,rnd,grey]	9
mirp[min,rnd,grey]	hstem 23
mdrp[rnd,grey]	4
f_deltap	4 16-8
ip	33
ip	27
mdrp[rnd,grey]	15
ip	18
ip	13
ip	12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,rnd,grey]	vheight_lo 7
mdrp[rnd,grey]	1
ip	30
ip	24
mdap[rnd]	20
mdrp[min,rnd,grey]	10
mdrp[rp0,rnd,grey]	18
mdrp[min,rnd,grey]	12
IUP[y]
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mirp[rnd,white]  gap_88 8
#
srp0    17
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   16
mirp[rnd,grey]	vheight_lu	1
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[grey]  5
IUP[y]
""",

    #maiyamok
    "uni0E46": """
srp0	39
mirp[rp0,rnd,grey]	gap_113 18
mdrp[rnd,grey]	12
ip	36
ip	30
ip	9
srp0	40
mdrp[rp0,rnd,grey]	1
f_deltap	1 14+8  
mirp[min,rnd,grey]	hstem 26
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 23
mdrp[grey]	7
shp[rp2]    4
mdrp[rp0,rnd,grey]	9
mdrp[rnd,grey]	15
ip	33
ip	27
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]	42
mdrp[rp0,rnd,grey]	35
ip	54
ip	48
mdrp[rp0,rnd,grey]	26
ip	28
ip 8
mdrp[grey]	11
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp 8
mdrp[rnd,grey]	31
ip	5
ip	28
ip	36
mdrp[rp0,rnd,grey]	39
f_deltap	39 25-8  39 31-8  
ip	51
ip	45
mdrp[rp0,min,rnd,grey]	22
mdrp[grey]	15
IUP[y]
""",

    #maiek
    "uni0E48": """
mdap[rnd]   0
mdrp[min,rnd,grey]  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  2
f_deltap    2 13+8
IUP[y]
""",

    #maitho
    "uni0E49": """
mdap[rnd]   14
mdrp[rnd,grey]	1
mdrp[rnd,grey]	8
ip	32
ip	26
ip	5
ip	16
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  3
mdrp[rp0,rnd,grey]  5
ip	16
mdrp[rnd,grey]	11
ip  29
ip  23
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   26
mdrp[min,rnd,white]	31
mdrp[min,rnd,grey]	3
mdrp[rp0,rnd,grey]	12
mdrp[rnd,grey]	18
ip	44
ip	38
ip	9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
alignrp 15
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  9
ip	41
ip	35
mdrp[rp0,rnd,grey]	21
alignrp 23
ip  7
ip	5
IUP[y]
""",

    "uni0E4B": """
mdap[rnd]   0
alignrp	8
mdrp[min,rnd,grey]	10
mdrp[rp0,min,rnd,grey]	2
alignrp	6
mdrp[min,rnd,grey]	4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,min,rnd,grey]	11
alignrp	2
mdrp[rp0,min,rnd,grey]	8
alignrp	5
mdrp[min,rnd,grey]	7
IUP[y]
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   17
mdrp[rnd,grey]	10
mdrp[rnd,grey]  3
ip	29
ip	23
ip	15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  6
ip	26
ip	20
mdrp[min,rnd,grey]	15
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
MDAP[rnd]   9
mdrp[rnd,grey]	3
ip	21
ip	15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rnd,grey]	6
ip	18
ip	12
IUP[y]
""",

    #nikhahit
    "uni0E4D.high": """
MDAP[rnd]   0
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  15
mdrp[rp0,rnd,grey]  3
mdrp[min,rnd,grey]  21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  18
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
mdap[rnd]	0
mdrp[rp0,rnd,grey]	30
mdrp[min,rnd,grey]	4
srp0	0
mdrp[rp0,rnd,grey]	21
mdrp[min,rnd,grey]	10
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]	34
mdrp[rp0,rnd,white]	26
mdrp[rp0,rnd,grey]	25
ip	7
mdrp[rp0,rnd,white]	18
mdrp[rp0,rnd,grey]	13
IUP[y]
""",

    #fongman
    "uni0E4F": """
srp0        56
mirp[rp0,rnd,grey]  gap_162 5
mirp[rp0,min,rnd,grey]  w_195 29
mdrp[min,rnd,grey]  35
#
srp0    5
mdrp[rp0,rnd,grey]  15
mirp[rnd,grey]  gap_162 57
mirp[rp0,min,rnd,grey]  w_195 23
mdrp[min,rnd,grey]  41
#
srp1    35
ip  53
ip  47
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,min,rnd,grey]  w_195 20
mdrp[min,rnd,grey]  32
#
srp0    0
mdrp[rp0,rnd,grey]  10
mirp[rp0,min,rnd,grey]  w_195 26
mdrp[min,rnd,grey]  38
#
srp1    32
ip  44
ip  50
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    28
mirp[rp0,rnd,white] gap_113 4
mirp[min,rnd,grey]  w_307 25
#
srp0    29
mirp[rp0,rnd,white]  gap_113 12
mirp[min,rnd,grey]  w_307 19
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rnd,grey]  vheight_lo  0
mirp[rp0,rnd,grey]  vheight_num 8
mdrp[grey]  22
srp0    0
mdrp[grey]  16
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
SRP0    48
mirp[rp0,rnd,white] gap_113 3
mirp[rp0,min,rnd,grey]  w_307 22
mdrp[rp0,rnd,white]  27
mdrp[rnd,grey]  33
f_deltap    33 13-8  33 14-8  33 18-8  
ip  45
ip  39
ip  25
#
srp0    49
mdrp[rp0,rnd,grey]  16
f_deltap    16 13+8
mirp[rp0,min,rnd,grey]  w_307 9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   13
mdrp[grey]  12
mirp[rp0,rnd,grey]  vheight_num 6
mdrp[grey]  19
srp0    13
mdrp[rp0,rnd,grey]  25
ip  0
mdrp[rp0,rnd,grey]  30
ip  42
ip  36
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
SRP0    55
mirp[rp0,rnd,white] gap_143 4
mdrp[min,rnd,grey]  11
mdrp[rp0,rnd,white] 32
mdrp[rnd,grey]  26
ip  23
ip  52
ip  46
srp0    56
mdrp[rp0,rnd,grey]  17
f_deltap    17 22+8
mirp[min,rnd,grey]  w_307 40
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  14
mirp[rp0,rnd,grey]  vheight_num 35
alignrp 37
mdrp[grey]  21
shp[rp2]    19
mdrp[rp0,rnd,grey]  23
f_deltap    23 13+8  23 14+8  23 23+8
mdrp[rnd,grey]  29
ip  49
ip  43
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
SRP0    56
mirp[rp0,rnd,white] gap_113 31
mirp[rp0,min,rnd,grey]  w_307 17
mdrp[rp0,rnd,grey]  19
mdrp[rnd,grey]  25
ip  53
ip  47
srp0    31
mdrp[rp0,rnd,grey]  11
f_deltap    11 13-8  11 17-8  11 20+8  11 24+8  11 28-8  11 29-8  11 32-8  
mirp[min,rnd,grey]  w_307 10
ip  36
#
srp0    57
mdrp[rp0,rnd,grey]  4
f_deltap    4 17-8  
mirp[min,rnd,grey]  w_307 41
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 28
mirp[rp0,rnd,grey]  vheight_num 38
alignrp 34
mdrp[grey]  7
shp[rp2]    14
srp0    28
mdrp[rp0,rnd,grey]  22
ip  19
ip  50
ip  44
mdrp[grey]  11
IUP[y]
""",

    #thaidigit_four
    "uni0E54": """
SRP0    55
mirp[rp0,rnd,white] gap_113 8
mirp[min,rnd,grey]  w_307 23
mdrp[rp0,rnd,grey]  30
mdrp[rnd,grey]  36
ip  52
ip  46
ip  28
ip  39
mdrp[rnd,grey]  42
ip  3
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   55
mirp[rp0,rnd,grey]  vheight_lo 0
alignrp 5
mdrp[grey]  42
shp[rp2]    26
mirp[rp0,rnd,grey]  vheight_num 12
mdrp[grey]  19
srp1    42
sloop   3
ip  33 49 43
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
SRP0    76
mirp[rp0,rnd,white]  gap_113 8
mirp[min,rnd,grey]  w_307 32
mdrp[rp0,rnd,grey]  39
mdrp[rnd,grey]  45
ip  61
ip  55
ip  37
ip  48
mdrp[rnd,grey]  51
ip  3
mdrp[rp0,rnd,grey]  13
mdrp[rnd,grey]  19
ip  73
ip  67
ip  11
ip  21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   76
mirp[rp0,rnd,grey]  vheight_lo 0
alignrp 5
mdrp[grey]  51
shp[rp2]    35
mirp[rp0,rnd,grey]  vheight_num 21
mdrp[grey]  28
srp1    51
sloop   3
ip  42 58 52
mdrp[rnd,grey]  16
ip  70
ip  64
ip  11
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
SRP0    48
mirp[rp0,rnd,white] gap_186 3
alignrp 20
mdrp[grey]  27
mdrp[rnd,grey]  9
ip  45
ip  39
srp0    49
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  w_307 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_num 30
mdrp[grey]  17
srp0    0
mdrp[grey]  11
mdrp[rnd,grey]  6
f_deltap    6 14-8
ip  42
ip  36
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    69
mirp[rp0,rnd,white] gap_113 31
mirp[min,rnd,grey]  w_307 17
mdrp[rp0,rnd,grey]  19
mdrp[rnd,grey]  25
ip  66
ip  60
srp0    31
mdrp[rp0,rnd,grey]  11
f_deltap    11 13-8  
mirp[min,rnd,grey]  w_307 10
ip  36
mdrp[rp0,rnd,grey]  4
f_deltap    4 18-8  
mirp[min,rnd,grey]  w_307 41
#
srp0    70
mdrp[rp0,rnd,grey]  47
f_deltap    47 14+8
mirp[min,rnd,grey]  w_307 54
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[grey]  44
mirp[rnd,grey]  vheight_lo 28
mirp[rp0,rnd,grey]  vheight_num 38
alignrp 34
mdrp[grey]  7
shp[rp2]    14
srp0    28
mdrp[rp0,rnd,grey]  22
ip  19
ip  63
ip  57
mdrp[grey]  11
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
SRP0    53
mirp[rp0,rnd,white] gap_113 7
mirp[min,rnd,grey]  w_307 22
mdrp[rp0,rnd,grey]  32
sloop 5
ip  25 26 27 4 3
mdrp[rnd,grey]  38
f_deltap    38 13-8  
ip  50
ip  44
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   53
mirp[rp0,rnd,grey]  vheight_lo 4
alignrp     0
mdrp[grey]  25
shp[rp2]    3
shp[rp2]    30
mdrp[rnd,grey]  35
ip  47
ip  41
mirp[rp0,rnd,grey]  vheight_num 11
mdrp[grey]  18
IUP[y]
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    60
mirp[rp0,rnd,white] gap_113 21
mirp[min,rnd,grey]  w_307 7
mdrp[rp0,rnd,grey]  9
mdrp[rnd,grey]  15
ip  57
ip  51
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  w_307 0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 18
mirp[rp0,rnd,grey]  vheight_num 30
alignrp 24
mdrp[grey]  43
shp[rp2]    4
srp0    18
mdrp[rnd,grey]  12
ip  54
ip  48
ip  9
IUP[y]
""",

#    #angkhankhu
    "uni0E5A": """
srp0    40
mirp[rp0,rnd,grey]  gap_88 8
mdrp[rnd,grey]  14
ip  33
ip  27
ip  17
#
srp0    41
mdrp[rp0,rnd,grey]  37
mirp[min,rnd,grey]  hstem 39
mdrp[rp0,min,rnd,white] 23
mirp[min,rnd,grey]  hstem 1
shp[rp2]    22
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp 37
mirp[rp0,rnd,grey]  vheight_shoot 11
alignrp 22
ip  23
ip  38
ip  39
mdrp[rp0,rnd,grey]  19
ip  30
ip  24
ip  17
mdrp[rnd,grey]  5
IUP[y]
""",

#    #khomut
    "uni0E5B": """
SRP0    73
mirp[rp0,rnd,white]  gap_162 3
mirp[min,rnd,grey]  w_307 26
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  9
ip  70
ip  64
ip  20
mdrp[rnd,grey]  46
sloop   5
ip  32 37 42 57 53
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  vheight_lo  0
mdrp[grey]  29
srp0    73
mirp[rp0,rnd,grey]  vheight_shoot 6
mdrp[grey]  23
mdrp[rp0,rnd,grey]  18
mdrp[rnd,grey]  12
ip  20
ip  67
ip  61
mdrp[rp0,rnd,grey]  57
alignrp     53
mdrp[grey]  34
shp[rp2]    39
mdrp[rp0,rnd,grey]  48
mdrp[min,rnd,grey]  45
IUP[y]
""",

    #LAO LETTER KO
    "uni0E81": """
SRP0    25
mdrp[rp0,rnd,grey]	4
mirp[rp0,rnd,grey]	hstem 22
mdrp[rnd,grey]	2
shp[rp2]	7
srp0	26
mdrp[rp0,rnd,grey]	17
mirp[min,rnd,grey]	hstem 15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   17
mirp[rnd,grey]	vheight_lo	0
mirp[rp0,rnd,grey]	vheight_shoot	13
alignrp		9
mdrp[grey]	20
mdrp[rnd,grey]	5
srp0	0
mdrp[rnd,grey]	4
IUP[y]
""",

    #LAO LETTER KHO
    "uni0E82": """
SRP0    41
mdrp[rp0,rnd,grey]	8
alignrp		23
mirp[min,rnd,grey]	hstem 34
mdrp[min,rnd,grey]	19
ip	17
mdrp[rp0,rnd,grey]	13
mirp[min,rnd,grey]	hstem 29
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   41
mirp[rnd,grey]	vheight_lo	6
mirp[rp0,rnd,grey]	vheight_shoot 27
ip	12
ip	30
mdrp[grey]	15
mdrp[rnd,grey]	21
srp0	6
mdrp[grey]	36
mdrp[rp0,rnd,grey]	39
mdrp[grey]	3
IUP[y]
""",
    #LAO LETTER  KHO TAM
    "uni0E84": """
SRP0    28
mdrp[rp0,rnd,grey]	15
alignrp	19
mdrp[rnd,grey]	11
shp[rp2]	5
ip	7
mirp[min,rnd,grey]	hstem 2
srp0	29
mdrp[rp0,rnd,grey]	25
mirp[min,rnd,grey]	hstem 23
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rnd,grey]	vheight_lo	13
mirp[rp0,rnd,grey]	vheight_shoot 21
mdrp[grey]	0
srp0	13
mdrp[rp0,rnd,grey]	9
ip	7
mdrp[rp0,rnd,white]	5
mdrp[min,rnd,grey]	4
ip	17
IUP[y]
""",

    #LAO LETTER NGO
    "uni0E87": """
SRP0    25
mdrp[rp0,rnd,grey]  23
mdrp[rnd,grey]  19
srp0    25
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  hstem 12
srp0    26
mdrp[rp0,rnd,grey]  18
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mdrp[rnd,grey]  7
mirp[rp0,rnd,grey]  vheight_shoot 0
mdrp[grey]  19
mdrp[rnd,grey]  21
srp0    7
mdrp[grey]  14
mdrp[rnd,grey]  12
IUP[y]
""",

    #LAO LETTER CO 
    "uni0E88": """
SRP0    24
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  hstem 20
srp0    25
mdrp[rp0,rnd,grey]  5
f_deltap    5 20-8  5 21-8
alignrp 16
mirp[min,rnd,grey]  hstem 3
mdrp[rnd,grey]  12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   5
mirp[rp0,rnd,grey]  vheight_shoot 0
mdrp[grey]  18
mdrp[rnd,grey]  21
mdrp[rp0,rnd,white] 14
mdrp[rnd,grey]  10
ip  16
ip  8
IUP[y]
""",

    #LAO LETTER SO TAM
    "uni0E8A": """
SRP0    42
mdrp[rp0,rnd,grey]  40
alignrp 13
mirp[min,rnd,grey]  hstem 22
mdrp[rnd,grey]  9
srp0    43
mdrp[rp0,rnd,white]  18
mirp[min,rnd,grey]  hstem 3
mdrp[rp0,rnd,grey]  30
mirp[min,rnd,grey]  hstem 35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   42
mirp[rp0,rnd,grey]  vheight_lo 37
mdrp[grey]  24
mdrp[rp0,rnd,grey]  28
mdrp[grey]  35
srp0    42
mirp[rp0,rnd,grey]  vheight_shoot 16
mdrp[grey]  5
mdrp[rnd,grey]  11
srp2    24
ip  1
ip  20
IUP[y]
""",

    #LAO LETTER NYO
    "uni0E8D": """
SRP0    30
mdrp[rp0,rnd,white] 9
alignrp 13
mirp[min,rnd,grey]  hstem 28
mdrp[rp0,rnd,grey]  22
mdrp[rp0,rnd,grey]  18  
mdrp[rnd,grey]  24
srp0    31
mdrp[rp0,rnd,white] 4
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
mirp[rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo  7
mdrp[grey]  0
srp0    30
mirp[rp0,rnd,grey]  vheight_shoot 16
ip  24
mdap[rnd]   24
srp2    16
ip  20
srp2    0
ip  25
IUP[y]
""",

    #LAO LETTER DO
    "uni0E94": """
SRP0    21
mdrp[rp0,rnd,white] 14
mirp[min,rnd,grey]  hstem 7
mdrp[rnd,grey]  10
srp0    22
mdrp[rp0,rnd,white] 0
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   2
mdrp[rnd,grey]  12
mirp[rp0,rnd,grey]  vheight_shoot 18
mdrp[grey]  5
srp0    12
mdrp[rnd,grey]  8
IUP[y]
""",

    #LAO LETTER TO
    "uni0E95": """
SRP0    35
mdrp[rp0,rnd,white] 26
mirp[min,rnd,grey]  hstem 19
mdrp[rnd,grey]  22
srp0    36
mdrp[rp0,rnd,white] 4
mirp[min,rnd,grey]  hstem 6
srp1    19
ip  13
ip  32
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   6
mdrp[rnd,grey]  24
mirp[rp0,rnd,grey]  vheight_shoot 2
alignrp 29
mdrp[rnd,grey]  9
shp[rp2]    17
mdrp[rp0,rnd,grey]  13
mdrp[rnd,grey]  33
srp0    24
mdrp[rnd,grey]  20
IUP[y]
""",

    #LAO LETTER THO SUNG
    "uni0E96": """
SRP0    26
mdrp[rp0,rnd,white] 19
mdrp[rnd,grey]  22
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  15
srp0    27
mdrp[rp0,rnd,white] 5
mirp[min,rnd,grey]  hstem 7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   26
mdrp[rnd,grey]  7
mirp[rnd,grey]  vheight_lo  17
mirp[rp0,rnd,grey]  vheight_shoot   2
alignrp 24
mdrp[grey]  10
mdrp[rnd,grey]  20
IUP[y]
""",

    #LAO LETTER THO TAM
    "uni0E97": """
SRP0    34
mdrp[rp0,rnd,white] 28
alignrp 32
mirp[min,rnd,grey]  hstem 6
mdrp[rnd,grey]  2
mdrp[rp0,rnd,white] 10
mirp[min,rnd,grey]  hstem 23
srp0    35
mdrp[rp0,rnd,white] 16
mirp[rp0,min,rnd,grey]  hstem 18
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   18
mirp[rnd,grey]  vheight_lo 26
mirp[rp0,rnd,grey]  vheight_shoot 14
alignrp 0
mdrp[grey]  21
mdrp[rnd,grey]  30
srp0    26
mdrp[grey]  8
IUP[y]
""",

    #LAO LETTER NO 
    "uni0E99": """
SRP0    26
mdrp[rp0,rnd,white] 7
alignrp 25
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  hstem 4
ip  23
srp0    27
mdrp[rp0,rnd,white] 18
mirp[min,rnd,grey]  hstem 16
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0

IUP[y]
""",

    #LAO LETTER BO 
    "uni0E9A": """
SRP0    23
mdrp[rp0,rnd,white] 21
alignrp 2
mirp[min,rnd,grey]  hstem 10
mdrp[rnd,grey]  6
srp0    24
mdrp[rp0,rnd,white] 16
mirp[min,rnd,grey]  hstem 14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   23
mirp[rnd,grey]  vheight_lo 19
mirp[rnd,grey]  vheight 16
mirp[rp0,rnd,grey]  vheight_shoot 4
mdrp[rnd,grey]  0
srp0    19
mdrp[grey]  12
IUP[y]
""",

    #LAO LETTER PO 
    "uni0E9B": """
SRP0    23
mdrp[rp0,rnd,white] 21
alignrp 2
mirp[min,rnd,grey]  hstem 10
mdrp[rnd,grey]  6
srp0    24
mdrp[rp0,rnd,white] 16
mirp[min,rnd,grey]  hstem 14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   23
mirp[rnd,grey]  vheight_lo 19
mirp[rnd,grey]  vheight_po 16 
mirp[rp0,rnd,grey]  vheight_shoot 4 
mdrp[rnd,grey]  0
srp0    19
mdrp[grey]  12
IUP[y]
""",

    #LAO LETTER PHO SUNG
    "uni0E9C": """
SRP0    41
mdrp[rp0,rnd,white] 6
mirp[min,rnd,grey]  hstem 13
mdrp[rnd,grey]  11
srp0    42
mdrp[rp0,rnd,white] 38
mdrp[rnd,grey]  36
mdrp[rnd,grey]  28
mirp[min,rnd,grey]  hstem 25
srp1    6
ip  18
mdap[rnd]   18
mirp[min,rnd,grey]  hstem 20
ip  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   41
mirp[rp0,rnd,grey]  vheight_lo  4
alignrp     0
mdrp[grey]  16
shp[rp2]    23
srp0    41
mirp[rp0,rnd,grey]  vheight_shoot 30
alignrp 9
mdrp[rp0,rnd,grey]  26
alignrp 13
ip  32
ip  38
mdrp[rnd,grey]  20
IUP[y]
""",

    #LAO LETTER FO TAM
    "uni0E9D": """
SRP0    30
mdrp[rp0,rnd,white] 6
mirp[min,rnd,grey]  hstem 13
mdrp[rnd,grey]  11
srp0    31
mdrp[rp0,rnd,white] 27
mirp[min,rnd,grey]  hstem 25
srp1    6
ip  18
mdap[rnd]   18
mirp[min,rnd,grey]  hstem 20
ip  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
mirp[rp0,rnd,grey]  vheight_lo 4
alignrp 0
mdrp[grey]  16
shp[rp2]    23
srp0    30
mirp[rnd,grey]  vheight_po 27
mirp[rp0,rnd,grey]  vheight_shoot 9
mdrp[rp0,rnd,grey]  13
mdrp[rnd,grey]  20
IUP[y]
""",

    #LAO LETTER PHO TAM
    "uni0E9E": """
SRP0    33
mdrp[rp0,rnd,white] 18
alignrp 22
mirp[min,rnd,grey]  hstem 30
mdrp[rnd,grey]  26
srp0    34
mdrp[rp0,rnd,white] 9
mirp[min,rnd,grey]  hstem 7
srp1    18
ip  0
mdap[rnd]   0
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   33
mirp[rp0,rnd,grey]  vheight_lo 16
alignrp 12
mdrp[grey]  32
shp[rp2]    5
srp0    33
mirp[rnd,grey]  vheight 9
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[rnd,grey]  20
mdrp[rnd,grey]  2
IUP[y]
""",

    #LAO LETTER FO SUNG
    "uni0E9F": """
SRP0    33
mdrp[rp0,rnd,white] 18
alignrp 22
mirp[min,rnd,grey]  hstem 30
mdrp[rnd,grey]  26
srp0    34
mdrp[rp0,rnd,white] 9
mirp[min,rnd,grey]  hstem 7
srp1    18
ip  0
mdap[rnd]   0
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   33
mirp[rp0,rnd,grey]  vheight_lo 16
alignrp 12
mdrp[grey]  32
shp[rp2]    5
srp0    33
mirp[rnd,grey]  vheight_po 9
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[rnd,grey]  20
mdrp[rnd,grey]  2
IUP[y]
""",

    #LAO LETTER MO 
    "uni0EA1": """
SRP0    28
mdrp[rp0,rnd,white] 18
mdrp[rnd,grey]  22
mdrp[rp0,rnd,white] 26
mirp[min,rnd,grey]  hstem 0
ip  13
srp0    29
mdrp[rp0,rnd,white] 7
mirp[min,rnd,grey]  hstem 5
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rp0,rnd,grey]  vheight_lo  15
alignrp 10
mdrp[rnd,grey]  20
mdrp[min,rnd,grey]  24
mdrp[grey]  3
srp0    28
mirp[rnd,grey]  vheight 0
shp[rp2]    7
IUP[y]
""",

    #LAO LETTER YO 
    "uni0EA2": """
SRP0    29
mdrp[rp0,rnd,white] 9
alignrp     13
mirp[min,rnd,grey]  hstem 27
mdrp[rnd,grey]  21
mdrp[rp0,rnd,grey]  17
mdrp[rnd,grey]  23
srp0    30
mdrp[rp0,rnd,white] 4
mirp[min,rnd,grey]  hstem 2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   29
mirp[rnd,grey]  vheight_po 4
mdrp[rp0,rnd,grey]  15
mdrp[rp0,rnd,grey]  23
ip  21
mdrp[grey]  24
ip  11
srp0    29
mirp[rp0,rnd,grey]  vheight_lo  7
mdrp[grey]  0
IUP[y]
""",

    #LAO LETTER LO LING
    "uni0EA3": """
SRP0    37
mdrp[rp0,rnd,white] 25
alignrp 2
mdrp[rnd,grey]  29
mirp[rp0,rnd,grey]  hstem 15
srp0    38
mdrp[rp0,rnd,white] 19
mdrp[grey]  10
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,rnd,grey]  vheight_lo 21
mdrp[grey]  31
mdrp[rnd,grey]  27
srp0    37
mdrp[rp0,rnd,grey]  6
mdrp[grey]  13
mdrp[rp0,rnd,grey]  17
mdrp[grey]  0
IUP[y]
""",

    #LAO LETTER LO LOOT
    "uni0EA5": """
SRP0    32
mdrp[rp0,rnd,white] 4
mdrp[rnd,grey]  0
mdrp[rp0,rnd,white] 18
mirp[min,rnd,grey]  hstem 17
srp0    33
mdrp[rp0,rnd,white] 25
mirp[min,rnd,grey]  hstem 12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   32
mirp[rp0,rnd,grey]  vheight_shoot 21
mdrp[grey]  15
srp0    32
mirp[rp0,rnd,grey]  vheight_lo 30
alignrp 2
mdrp[grey]  10
mdrp[rnd,grey]  6
srp1    15
ip  17
IUP[y]
""",

    #LAO LETTER WO 
    "uni0EA7": """
SRP0    36
mdrp[rp0,rnd,white] 32
mdrp[rnd,grey]  0
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  hstem 14
srp0    37
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem 8
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   36
mirp[rp0,rnd,grey]  vheight_shoot 19
mdrp[grey]  11
srp0    36
mirp[rp0,rnd,grey]  vheight_lo 28
mdrp[grey]  6
mdrp[rnd,grey]  34
srp1    11
ip  14
IUP[y]
""",

    #LAO LETTER SO SUNG
    "uni0EAA": """
SRP0    39
mdrp[rp0,rnd,white] 31
alignrp 9
mdrp[rnd,grey]  27
mirp[min,rnd,grey]  hstem 0
srp0    40
mdrp[rp0,rnd,white] 20
mdrp[rnd,grey]  18
mirp[rp0,rnd,grey]  hstem 4
shp[rp2]    3
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mdrp[rp0,rnd,grey]  11
mdrp[rnd,grey]  7
ip  0
ip  1
ip  13
ip  20
srp0    39
mirp[rp0,rnd,grey]  vheight_lo  25
alignrp 29
mdrp[grey]  37
mdrp[rnd,grey]  33
IUP[y]
""",

    #LAO LETTER HO SUNG
    "uni0EAB": """
SRP0    41
mdrp[rp0,rnd,white] 0
alignrp 4
mirp[min,rnd,grey]  hstem 12
srp0    42
mdrp[rp0,rnd,white] 29
mirp[min,rnd,grey]  hstem 31
srp1    0
srp2    31
ip  16
mdap[rnd]   16
mirp[min,rnd,grey]  hstem 36
ip  25
srp1    12
srp2    16
ip  8
ip  21
IUP[x]
shpix   -8 7
shpix   -8 9
shpix   8 22
shpix   8 20
#
SVTCA[y-axis]
MDAP[rnd]   31
mdrp[rp0,rnd,grey]  27
alignrp 23
alignrp 6
mdrp[rnd,grey]  34
mdrp[rnd,grey]  2
shp[rp2]    19
ip  36
srp0    31
mirp[rp0,rnd,grey]  vheight_lo 39
mdrp[rnd,grey]  14
IUP[y]
""",

    #LAO LETTER O
    "uni0EAD": """
SRP0    30
mdrp[rp0,rnd,white] 0
alignrp 9
mirp[min,rnd,grey]  hstem 26
mdrp[rnd,grey]  13
srp0    31
mdrp[rp0,rnd,white] 4
mirp[rp0,rnd,grey]  hstem 17
shp[rp2]    22
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
mdrp[rp0,rnd,grey]  2
mdrp[rnd,grey]  20
ip  24
ip  28
srp0    30
mirp[rp0,rnd,grey]  vheight_lo 7
mdrp[grey]  15
mdrp[rp0,rnd,grey]  11
srp1    20
srp2    7
ip  11
IUP[y]
""",

    #LAO LETTER HO TAM
    "uni0EAE": """
SRP0    44
mdrp[rp0,rnd,white] 34
alignrp 4
mdrp[rnd,grey]  38
mirp[min,rnd,grey]  hstem 22
srp0    45
mdrp[rp0,rnd,white] 28
mdrp[grey]  13
mirp[min,rnd,grey]  hstem 0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   44
mdrp[rp0,rnd,grey]  6
mdrp[grey]  20
mdrp[rp0,rnd,grey]  16
ip  24
mdrp[grey]  10
srp0    24
mdrp[grey]  2
srp0    44
mirp[rp0,rnd,grey]  vheight_lo  30
mdrp[grey]  42
srp1    2
ip  36
IUP[y]
""",

    #LAO LETTER ELLIPSIS
    "uni0EAF": """
SRP0    34
mdrp[rp0,rnd,white] 10
mirp[rp0,rnd,grey]  hstem 20
mdrp[rnd,grey]  14
ip  18
srp0    35
mdrp[rp0,rnd,white] 30
mdrp[grey]  33
mirp[min,rnd,grey]  hstem 3
#
f_deltap    3 14-4  3 15-4  3 16-6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   34
mdrp[grey]  33
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  16
ip  18
mdrp[rp0,rnd,grey]  8
mdrp[grey]  22
srp0    12
mdrp[rp0,rnd,grey]  27
mdrp[grey]  3
IUP[y]
""",

    #LAO VOWEL SIGN MAI KAN
    "uni0EB1": """
mdap[rnd]   18
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  4
mdrp[rnd,grey]  8
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rnd,grey]  10
mdrp[rp0,rnd,grey]  6
mdrp[grey]  16
IUP[y]
""",

    #LAO VOWEL SIGN AA 
    "uni0EB2": """
SRP0    17
mdrp[rp0,rnd,white] 13
mdrp[rnd,grey]  9
ip  7
srp0    18
mdrp[rp0,rnd,white] 0
mirp[min,rnd,grey]  hstem 2
#
srp2    7
ip  9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   2
mdrp[rp0,rnd,grey]  15
mdrp[grey]  5
mdrp[rnd,grey]  11
IUP[y]
""",

    #LAO VOWEL SIGN I
    "uni0EB4": """
mdap[rnd]   9
mdrp[min,rnd,grey]  14
mdrp[rnd,grey]  12
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  0
mdrp[rnd,grey]  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   11
alignrp 3
mdrp[rp0,min,rnd,grey]  12
alignrp 2
mdrp[rp0,min,rnd,grey]  16
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO VOWEL SIGN II
    "uni0EB5": """
mdap[rnd]   9
mdrp[min,rnd,grey]  17
mdrp[rnd,grey]  15
mdrp[rnd,grey]  12
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  0
mdrp[rnd,grey]  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
alignrp 3
mdrp[rp0,min,rnd,grey]  15
alignrp 2
alignrp 12
mdrp[rp0,min,rnd,grey]  19
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO VOWEL SIGN Y
    "uni0EB6": """
mdap[rnd]   9
mdrp[min,rnd,grey]  14
mdrp[rnd,grey]  12
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  0
mdrp[rnd,grey]  2
srp1    0
srp2    14
ip  24
ip  19
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   11
alignrp 3
mdrp[rp0,min,rnd,grey]  12
alignrp 2
mdrp[rp0,min,rnd,grey]  16
ip  18
ip  21
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO VOWEL SIGN YY
    "uni0EB7": """
mdap[rnd]   9
mdrp[min,rnd,grey]  17
mdrp[rnd,grey]  15
mdrp[rnd,grey]  12
mdrp[rp0,rnd,grey]  5
mdrp[min,rnd,grey]  0
mdrp[rnd,grey]  2
srp1    0
srp2    17
ip  27
ip  22
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
alignrp 3
mdrp[rp0,min,rnd,grey]  15
alignrp 2
alignrp 12
mdrp[rp0,min,rnd,grey]  19
ip  21
ip  24
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO VOWEL SIGN U
    "uni0EB8": """
mdap[rnd]   18
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  12
ip  2
ip  6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
mdrp[rp0,rnd,grey]  10
ip  0
ip  4
mdrp[grey]  20
IUP[y]
""",

    #LAO VOWEL SIGN UU
    "uni0EB9": """
mdap[rnd]   27
mdrp[rp0,min,rnd,grey]  25
mdrp[rp0,min,rnd,grey]  17
mdrp[rp0,rnd,grey]  13
alignrp 9
ip  2
ip  7
ip  11
mdrp[min,rnd,grey]  21
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   15
mdrp[rnd,grey]  26
mdrp[rnd,grey]  11
ip  0
ip  4
mdrp[rp0,rnd,grey]  30
mdrp[min,rnd,grey]  23
IUP[y]
""",

    #LAO VOWEL SIGN MAI KON
    "uni0EBB": """
mdap[rnd]   2
mdrp[min,rnd,grey]  8
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   14
mdrp[rnd,grey]  4
mdrp[rp0,rnd,grey]  0
mdrp[min,rnd,grey]  10
IUP[y]
""",

    #LAO VOWEL SIGN LO
    "uni0EBC": """
mdap[rnd]   14
mdrp[rnd,grey]  27
mdrp[rnd,grey]  18
ip  6
ip  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   20
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,grey]  16
alignrp 8
ip  4
ip  0
mdrp[min,rnd,grey]  24
IUP[y]
""",

    #LAO SEMIVOWEL SIGN NYO
    "uni0EBD": """
SRP0    51
mdrp[rp0,rnd,white] 8
mirp[min,rnd,grey]  hstem 16
srp0    52
mdrp[rp0,rnd,white] 50
mdrp[grey]  37
mirp[min,rnd,grey]  hstem 22
mdrp[rp0,rnd,grey]  46
mirp[min,rnd,grey]  hstem 27
srp1    16
srp2    22
ip  13
mdap[rnd] 13
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   51
mdrp[rp0,rnd,grey]  29
mdrp[grey]  44
mdrp[rp0,rnd,grey]  40
ip  48
mdrp[grey]  33
srp0    48
mdrp[grey]  25
srp0    51
mdrp[rp0,rnd,grey]  4
mdrp[grey]  4
mdrp[rp0,rnd,grey]  15
mdrp[rnd,grey]  11
ip  16
IUP[y]
""",

    #LAO VOWEL SIGN E
    "uni0EC0": """
SRP0    20
mdrp[rp0,rnd,white] 3
mirp[min,rnd,grey]  hstem 13
mdrp[rnd,grey]  18
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  8
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   20
mirp[rp0,rnd,grey]  vheight_shoot 6
mdrp[grey]  11
srp0    20
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  16
ip  14
IUP[y]
""",

    #LAO VOWEL SIGN O
    "uni0EC2": """
SRP0    28
mdrp[rp0,rnd,white] 6
mirp[min,rnd,grey]  hstem 27
mdrp[rnd,grey]  2
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  19
sloop   7
ip 10 9 24 25 21 20 18
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rp0,rnd,grey]  vheight_lo 4
mdrp[rnd,grey]  0
srp0    28
mdrp[rp0,rnd,grey]  16
mdrp[rnd,grey]  20
sloop   7
ip 18 19 21 24 25 10 9
IUP[y]
""",

    #LAO VOWEL SIGN AY
    "uni0EC3": """
SRP0    27
mdrp[rp0,rnd,white] 9
mirp[min,rnd,grey]  hstem 4
srp0    28
mdrp[rp0,rnd,white] 13
mirp[min,rnd,grey]  hstem 0
mdrp[rp0,rnd,grey]  16
mirp[rp0,min,rnd,grey]  hstem 23
mdrp[rnd,grey]  19
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   27
mirp[rp0,rnd,grey]  vheight_lo 21
mdrp[rnd,grey]  17
srp0    27
mdrp[rp0,rnd,grey]  11
mdrp[grey]  2
mdrp[grey]  7
IUP[y]
""",

    #LAO VOWEL SIGN AI
    "uni0EC4": """
SRP0    23
mdrp[rp0,rnd,white] 19
mirp[min,rnd,grey]  hstem 11
mdrp[rnd,grey]  14
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  hstem 5
mdrp[grey]  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   23
mirp[rp0,rnd,grey]  vheight_lo 16
mdrp[rnd,grey]  12
srp0    23
mdrp[rnd,grey]  3
sloop   9
ip  2 5 6 7 8 0 22 21 20
IUP[y]
""",

    #LAO VOWEL SIGN KO LA
    "uni0EC6": """
SRP0    47
mdrp[rp0,rnd,white] 33
alignrp 8
mirp[min,rnd,grey]  hstem 26
shp[rp2]    9
mdrp[rnd,grey]  29
srp0    48
mdrp[rp0,rnd,white] 46
mirp[min,rnd,grey]  hstem 13
srp1    28
srp2    13
sloop   4
ip  40 20 11 4
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   47
mdrp[rp0,rnd,grey]  4
mdrp[grey]  11
mdrp[rnd,grey]  9
srp0    47
mdrp[rp0,rnd,grey]  36
alignrp 44
mdrp[grey]  24
shp[rp2]    16
mdrp[rp0,rnd,grey]  20
mdrp[grey]  40
mdrp[rp0,rnd,white] 27
mdrp[rnd,grey]  31
IUP[y]
""",

    #LAO TONE MAI EK
    "uni0EC8": """
mdap[rnd]   0
mdrp[min,rnd,grey]  2
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #LAO TONE MAI THO
    "uni0EC9": """
mdap[rnd]   17
mdrp[min,rnd,grey]  16
mdrp[rp0,rnd,grey]  6
mdrp[rnd,grey]  2
mdrp[rnd,grey]  10
ip  4
ip  12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,min,rnd,grey]  12
alignrp 2
mdrp[rnd,grey]  16
mdrp[rnd,grey]  8
ip  4
IUP[y]
""",

    #LAO TONE MAI TI
    "uni0ECA": """
mdap[rnd]   10
mdrp[rp0,rnd,grey]  16
mdrp[min,rnd,grey]  17
srp0    10
mdrp[min,rnd,grey]  25
mdrp[rnd,grey]  23
mdrp[rp0,rnd,grey]  45
mdrp[rp0,rnd,grey]  37
ip  41
mdrp[min,rnd,grey]  51
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   22
alignrp 49
mdrp[rnd,grey]  16
mdrp[min,rnd,grey]  23
shp[rp2]    12
shp[rp2]    39
mdrp[rp0,rnd,grey]  43
mdrp[rp0,rnd,white] 31
mdrp[grey]  4
mdrp[rp0,rnd,grey]  8
alignrp 0
mdrp[grey]  27
shp[rp2]    35
IUP[y]
""",

    #LAO TONE MAI CATAWA
    "uni0ECB": """
mdap[rnd]   5
mdrp[rp0,min,rnd,grey]  7
alignrp 4
mdrp[rp0,min,rnd,grey]  1
alignrp 10
mdrp[min,rnd,grey]  11
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   8
mdrp[rp0,min,rnd,grey]  7
alignrp 10
mdrp[rp0,min,rnd,grey]  4
alignrp 1
mdrp[min,rnd,grey]  3
IUP[y]
""",

    #LAO NIGAHITA
    "uni0ECD": """
mdap[rnd]   2
mdrp[rnd,grey]  9
ip  11
ip  15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   4
mdrp[rnd,grey]  0
ip  17
ip  13
IUP[y]
""",

    #LAO DIGIT ZERO
    "uni0ED0": """
SRP0    32
mdrp[rp0,rnd,white]	28
mirp[min,rnd,grey]	hstem 4
srp0	33
mdrp[rp0,rnd,white]	20
mirp[min,rnd,grey]	hstem 12
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   32
mirp[rp0,rnd,grey]	vheight_shoot 16
mdrp[grey]	0
srp0	32
mirp[rp0,rnd,grey]	vheight_lo 24
mdrp[grey]	8
IUP[y]
""",

    #LAO DIGIT ONE
    "uni0ED1": """
SRP0    37
mdrp[rp0,rnd,white]	25
mirp[rp0,min,rnd,grey]	hstem 11
mdrp[rnd,grey]	17
srp0	38
mdrp[rp0,rnd,white]	33
mirp[min,rnd,grey]	hstem 3
mdrp[grey]	0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
mdrp[rp0,rnd,grey]	29
mdrp[grey]	7
mdrp[rp0,rnd,grey]	19
mdrp[rnd,grey]	15
IUP[y]
""",

    #LAO DIGIT TWO
    "uni0ED2": """
SRP0    31
mdrp[rp0,rnd,white]	17
mirp[min,rnd,grey]	hstem 28
mdrp[rp0,rnd,grey]	22
mirp[min,rnd,grey]	hstem 23
srp0	32
mdrp[rp0,rnd,white]	9
mdrp[rnd,grey]	5
ip	3
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   31
mdrp[rnd,grey]	22
mdrp[rp0,rnd,grey]	13
mdrp[min,rnd,grey]	1
mdrp[rnd,grey]	7
ip	3
IUP[y]
""",

    #LAO DIGIT THREE
    "uni0ED3": """
SRP0    56
mdrp[rp0,rnd,white]	11
mdrp[rp0,rnd,grey]	15
mdrp[rp0,rnd,grey]	19
mirp[min,rnd,grey]	hstem 21
ip	6
srp0	57
mdrp[rp0,rnd,white]	0
mdrp[grey]	43
mirp[min,rnd,grey]	hstem 26
mdrp[rp0,rnd,grey]	52
mirp[min,rnd,grey]	hstem 31
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   56
mdrp[rp0,rnd,grey]	35
mdrp[grey]	50
mdrp[rp0,rnd,grey]	46
ip	54
mdrp[grey]	39
srp0	54
mdrp[grey]	29
srp0	56
mdrp[rp0,rnd,grey]	3
alignrp	8
mdrp[grey]	24
mdrp[rnd,grey]	17
mdrp[rnd,grey]	13
mdrp[rnd,grey]	21
IUP[y]
""",

    #LAO DIGIT FOUR
    "uni0ED4": """
SRP0    34
mdrp[rp0,rnd,white]	6
mirp[min,rnd,grey]	hstem 17
mdrp[rp0,rnd,grey]	11
mirp[min,rnd,grey]	hstem 12
srp0	35
mdrp[rp0,rnd,white]	33
mdrp[rp0,rnd,grey]	29
mdrp[rnd,grey]	25
ip	31
ip	23
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   34
mdrp[rnd,grey]	11
mdrp[rp0,rnd,grey]	2
mdrp[grey]	36
mdrp[rp0,rnd,grey]	21
mdrp[rnd,grey]	27
ip	31
IUP[y]
""",

    #LAO DIGIT FIVE
    "uni0ED5": """
SRP0    44
mdrp[rp0,rnd,white] 23
mirp[min,rnd,grey]  hstem 0
mdrp[rp0,rnd,grey]  29
mdrp[rnd,grey]	33
ip	27
ip	40
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  hstem 36
srp0    45
mdrp[rp0,rnd,white] 16
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  8
ip  6
ip  14
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   44
mdrp[rnd,grey]  35
mdrp[rnd,grey]	31
ip	33
ip	27
ip	40
mdrp[rp0,rnd,grey]  19
mdrp[grey]  17
mdrp[rp0,rnd,grey]  4
mdrp[rnd,grey]  10
ip  14
IUP[y]
""",

    #LAO DIGIT SIX
    "uni0ED6": """
SRP0    59
mdrp[rp0,rnd,white]	10
mirp[min,rnd,grey]	hstem 17
mdrp[rnd,grey]	15
srp0	60
mdrp[rp0,rnd,white]	0
mdrp[grey]	46
mirp[min,rnd,grey]	hstem 29
srp2	10
ip	23	
mdrp[rp0,rnd,grey]	55
mirp[min,rnd,grey]	hstem 34
mdap[rnd]	23
mirp[min,rnd,grey]	hstem 24
ip	6
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   59
mirp[rp0,rnd,grey]	vheight_shoot 13
mdrp[rp0,rnd,grey]	17
mdrp[rnd,grey]	23
srp0	59
mdrp[rp0,rnd,grey]	38
mdrp[grey]	53
mdrp[rp0,rnd,grey]	49
ip	57
mdrp[grey]	42
srp0	57
mdrp[grey]	32
srp0	59
mirp[rp0,rnd,grey]	vheight_lo 8
alignrp	4
mdrp[rnd,grey]	20
shp[rp2]	27
IUP[y]
""",

    #LAO DIGIT SEVEN
    "uni0ED7": """
SRP0    25
mdrp[rp0,rnd,white]	2
alignrp	7
mdrp[rp0,rnd,grey]	22
mirp[min,rnd,grey]	hstem 5
ip	11
srp0	26
mdrp[rp0,rnd,white]	15
mirp[min,rnd,grey]	hstem 17
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rp0,rnd,grey]	vheight_shoot 13
alignrp	9
mdrp[grey]	20
mdrp[rnd,grey]	5
srp0	25
mdrp[rnd,grey]	17
mirp[rp0,rnd,grey]	vheight_lo	0
mdrp[rnd,grey]	4
IUP[y]
""",

    #LAO DIGIT EIGHT
    "uni0ED8": """
SRP0    68
mdrp[rp0,rnd,white]	47
mirp[min,rnd,grey]	hstem 40
mdrp[rnd,grey]	43
srp0	69
mdrp[rp0,rnd,white]	0
alignrp	6
mdrp[rnd,grey]	10
mirp[min,rnd,grey]	hstem 27
shp[rp2]	67
srp2	40
ip	54
ip	34
mdrp[rp0,rnd,grey]	22
mdrp[min,rnd,grey]	63
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   68
mdrp[rp0,rnd,grey]	50
alignrp	58
mdrp[grey]	38
shp[rp2]	30
mdrp[rp0,rnd,grey]	34
mdrp[grey]	54
mdrp[rp0,rnd,grey]	41
mdrp[rnd,grey]	45
srp0	68
mdrp[rp0,rnd,grey]	20
srp1	50
sloop	4
ip	2 5 27 60
mdrp[min,rnd,grey]	63
mdrp[rp0,rnd,grey]	14
mdrp[rnd,grey]	6
ip	67
ip	16
IUP[y]
""",

    #LAO DIGIT NINE
    "uni0ED9": """
SRP0    33
mdrp[rp0,rnd,white]	4
mirp[min,rnd,grey]	hstem 11
mdrp[rnd,grey]	9
srp0	34
mdrp[rp0,rnd,white]	23
mirp[min,rnd,grey]	hstem 25
srp2	11
ip	16
mdap[rnd]	16
mirp[min,rnd,grey]	hstem 30
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rp0,rnd,grey]	vheight_shoot 21
alignrp	7
mdrp[grey]	28
mdrp[rnd,grey]	11
srp0	25
mirp[rp0,rnd,grey]	vheight_lo 0
mdrp[grey]	14
IUP[y]
""",

    #LAO HO NO
    "uni0EDC": """
SRP0    59
mdrp[rp0,rnd,white]	9
alignrp	13
mirp[min,rnd,grey]	hstem 21
srp0	60
mdrp[rp0,rnd,white]	45
mirp[rp0,min,rnd,grey]	hstem 43
srp1	9
ip	25
ip	58
mdap[rnd]	25
mirp[min,rnd,grey]	hstem 4
ip	34
srp1	21
srp2    25
ip	17
ip	30
mdap[rnd]	58
mirp[min,rnd,grey]	hstem 38
ip	51
srp1	4
srp2    58
ip	56
IUP[x]
shpix   -8 16
shpix   -8 18
shpix   8 31
shpix   8 29
shpix   8 57
shpix   8 55
#
SVTCA[y-axis]
MDAP[rnd]   59
mdrp[rnd,grey]  45
mdrp[rp0,rnd,grey]	15
alignrp	32
alignrp	36
mdrp[rnd,grey]	11
shp[rp2]	28
mdrp[min,rnd,grey]	2
srp0	59
mirp[rp0,rnd,grey]	vheight_lo	7
alignrp	53
alignrp	48
mdrp[min,rnd,grey]	23
shp[rp2]	41
mdrp[rnd,grey]	58
IUP[y]
""",

    #LAO HO MO
    "uni0EDD": """
SRP0    58
mdrp[rp0,rnd,white] 9
alignrp 13
mirp[min,rnd,grey]  hstem 21
srp0    59
mdrp[rp0,rnd,white] 45
mirp[min,rnd,grey]  hstem 43
srp1    9
srp2    43
ip  25
ip  57
mdap[rnd]   25
mirp[min,rnd,grey]  hstem 4
ip  34
srp1    21
srp2    25
ip  17
ip  30
mdap[rnd]   57
mirp[min,rnd,grey]  hstem 38
ip  50
srp1    4
srp2    57
ip  53
mdap[rnd]   53
IUP[x]
shpix   -8 16
shpix   -8 18
shpix   8 31
shpix   8 29
#
SVTCA[y-axis]
MDAP[rnd]   58
mdrp[rnd,grey]  45
mdrp[rp0,rnd,grey]  36
alignrp 15
alignrp 32
mdrp[min,rnd,grey]  2
mdrp[rnd,grey]  11
shp[rp2]    28
srp0    58
mirp[rp0,rnd,grey]  vheight_lo 7
alignrp 52
alignrp 48
mdrp[min,rnd,grey]  23
shp[rp2]    53
shp[rp2]    41
IUP[y]
""",

    #LAO ..
    "uni0EXX": """
SRP0    0

IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0

IUP[y]
""",

#lll

    #CHAR_NAME
    "uni0EXX": """
#yyy
SRP0    0

IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0

IUP[y]
""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
