#!/usr/bin/env python
#Usage: $0 uni0E01 > code.txt
#or:    $0 --all

import os
import sys
import dfont

# cvt value
#NEW VALUE ***
#    "headdia":          257,    #384
#    "headstem":         258,    #120
#    "w_896":            256,    #896    =ko_kai
cvt_dict = {
    "w_1001":           71,     #1001   =
    "w_340":            38,
    "w_102":            9,      #102 
    "w_60":             260,    #60
#
#LAO'S
    "w_115":            69,     #115    =gap1
    "w_186":            70,     #186    =gap2
    "w_184":            8,      #184    =hstem
    "w_195":            18,     #195    =hstem_curve
    "w_156":            135,    #156    =vstem
    "w_1147":           184,    #1147   =vheight_shoot
    "w_1556":           151,    #1556   =vheight_po
    "w_29":             140,    #29     =vheight_lo
    "w_1120":           188,    #1120   =vheight
    "w_426":            189,    #426    =vheight_lu
    "w_492":            158,    #492    =vheight_lowest
#
    "base":             10,     #0
    "hstem":            8,      #184
    "hstem_curve":      18,     #195    =big curve hstem
#
    "vstem":            169,    #143    =straight vstem
    "vstem_curve":      185,    #156    =curve vstem
#    "vstem":            96,     #154 
    "vstem_small":      27,     #135 
    "vstem_tiny":       9,      #102 
    "vstem_thick":      130,    #266 
    "headstem":         258,    #116
    "headstem_plus_hole":   259, #268
    "headstem_small":   11,     #113    =kho
    "headstem_small_plus_hole":   130,     #266    =kho
    "headstem_tiny":    148,    #84
    "headstem_wan":     260,    #60
    "sarastem":         90,     #127
#
    "headdia":          257,    #384
    "headdia_small":    180,    #377    =kho
    "headdia_plus":     261,    #442 
    "headdia_full":     157,    #451 
    "headdia_tiny":     0,      #309
    "headhole":         107,    #152    
    "headneck_kho":     39,     #180    =kho
#
    "hnext_1":          111,    #469    =next spline of sho_sher
    "hnext_2":          68,     #479    =next spline of yo_ying
#
    "vheight":          188,    #1120   =normal height 
    "vheight_shoot":    184,    #1147   =overshoot height
    "vheight_hi":       49,     #1208   =ko 
    "vheight_hi_kho":   47,     #1204   =kho 
    "vheight_po":       151,    #1556   =po_pla, fo_fa
    "vheight_o":        179,    #1638   =sara_o, sara_i
    "vheight_lo":       140,    #29 
    "vheight_lu":       176,    #410    =lo_lu
    "vheight_below_do": 176,    #410
    "vheight_num":      209,    #905
    "vheight_sara1":    250,    #1262
#
    "gap_51":           32,     #51
    "gap_84":           148,    #84
    "gap_102":          9,
    "gap_113":          11,     #113    =front spacing of ko_kai
    "gap_127":          90,
    "gap_143":          84,
    "gap_152":          107,    #152
    "gap_164":          85,     #164
    "gap_186":          70,
    "gap_197":          194,    #197    =gap front/rear
    "gap_205":          100,    #205    =gap front/rear
    "gap_240":          24,    
    "gap_315":          207,
    "gap_340":          38,
    "gap_377":          180,
#special
    "special_1":        230,    #45
    "special_2":        88,     #20
}

#SKEL
#hd: headstem delta shift at 13-16 ppem
#f_deltap    x 12-4 x 13-4 x 14-1 x 15-1 x 16-1
#f_deltap    y1 14-1 y1 15-1 y1 16-1   y2 14+1 y2 15+1 y2 16+1
#f_deltap    x 12+4 x 13+4 x 14+1 x 15+1 x 16+1

#vd: vstem_curve delta shift at 18-25 ppem
#shpix   16 y
#f_deltap    y 17-4   y 18+4 y 19+3 y 20+2 y 21+2 y 22+2 y 23+2 y 24+2 y 25+2   y 26+1   y 29+6 y 30+6 y 31+6 y 32+6 y 33+6 y 34+6 y 35+6


######### PSUEDO-CODE ##########
pseudo_code_dict = {
    #ko_kai
    "uni0E01": """
srp0                26
mirp[rp0,rnd,grey]  gap_197 14
mirp[min,rnd,grey]  hstem  12
#
srp0    27
mirp[rp0,rnd,grey]  gap_164 25
mirp[min,rnd,grey]  hstem  1
IUP[x]
shpix   -16 8
shpix   16  17
#
SVTCA[y-axis]
mdap[rnd]           1
alignrp             13
mirp[rp0,rnd,grey]  vheight_shoot    22
sloop 6
ip 17 18 19 8 9 10
mirp[grey]  vstem_curve 5
shpix   28 5
#f_deltap    x 9-4  x 10-3  x 11-3  x 12-3  x 13-2  x 14-1 
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
shpix   -8 19
#f_deltap    5 14+1 5 15+2  5 16+2
IUP[y]
shpix   8 3
""",

    #kho_khai
    "uni0E02":  """
srp0                53
mirp[rp0,rnd,grey]  gap_51 21
f_deltap    21 15+8
mdrp[rnd,grey]  15
f_deltap    15 19-8  15 24-8
ip  12
ip  50
ip  44
mdrp[rp0,rnd,white] 7
f_deltap    7 11-8  7 14+8  7 19+8  7 28-8  7 29-8
mdrp[grey]  27
mdrp[rp0,rnd,grey]  1
f_deltap    1 20-8  1 22-8  1 27-8
mirp[min,rnd,grey]  hstem 32
#
srp0    54
mirp[rp0,rnd,grey]  gap_164 38
f_deltap    38 22+8  
mirp[rp0,min,rnd,grey] hstem 36
f_deltap    7 17+2  27 17+2  27 20-3
IUP[x]
shpix   24 19
shpix   -24 17
shpix   -24 16
shpix   -24 14
shpix   -24 13
#
SVTCA[y-axis]
mdap[rnd]   1
mirp[grey]  vstem 34
shpix   -16 34
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 24
mdrp[rp0,rnd,grey]  10
mdrp[rp0,rnd,grey]  12
f_deltap    12 10+8  12 11+8  12 12+4  12 13+4  12 14+8  12 15+8  12 16+8
mdrp[rnd,grey]  18
ip  12
ip  47
ip  41
srp1    18
srp2    1
ip  2
ip  32
f_deltap    10 14+3  10 15+3  10 16+3  22 14+2  22 15+2  22 16+2
IUP[y]
""",

    #kho_khuad
    "uni0E03": """
srp0    57
mdrp[rp0,rnd,grey]  24
f_deltap    24 19+8
mdrp[rnd,grey]  18
f_deltap    18 13-8  18 23-8
ip  13
ip  54
ip  48
mdrp[rp0,rnd,white]  7
f_deltap    7 14+8  7 15+8  7 23-8  7 27-8
ip  27
ip  29
ip  11
ip  9
mdrp[grey]  31
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 36
#
srp0    58
mirp[rp0,rnd,grey]  gap_164 42
mirp[rp0,min,rnd,grey]  hstem 40
IUP[x]
shpix   24  22
shpix   -24 20
shpix   -24 19
shpix   -24 17
shpix   -24 16
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem   38
shpix   -16  38
mirp[rnd,grey]  vheight 42
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
mdrp[grey]  11
shp[rp2]    9
ip  28
ip  10
shpix   -24 28
shpix   -24 10
mdrp[rp0,rnd,white] 15
f_deltap    15 17+8
mdrp[rnd,grey]  21
f_deltap    21 19+8  21 24+8
ip  51
ip  45
srp1    21
srp2    1
ip  2
ip  36
shpix   -16 28
f_deltap    28 9-4  28 10-4  28 11-4  28 12-4
IUP[y]
""",

    #kho_kwai
    "uni0E04": """
srp0    51
mirp[rp0,rnd,grey]  gap_164     29
f_deltap    29 17+8  29 18+8  29 19+8  29 20+8  29 21+8  
mdrp[rnd,grey]  32
mirp[rp0,min,rnd,grey]  hstem   28
mdrp[rnd,grey]  8
shpix   -8  8
ip  11
srp0    29
mdrp[rp0,rnd,white] 14
f_deltap    14 12+8  
mdrp[rnd,grey]  20
f_deltap    20 13-8  20 18-8  20 19-8  20 23-8  20 24-8
ip  25
ip  48
ip  42
srp1    8
srp2    48
ip  14
ip  25
srp0    52
mirp[rp0,rnd,white] gap_164 38
mirp[min,rnd,grey]  hstem   1
iup[x]
shpix   -24 18
shpix   -24 19
shpix   -24 21
shpix   -24 22
shpix   24 24
#
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     28
mirp[rp0,rnd,grey]  vheight_shoot   35
ip  11
mirp[grey]  vstem_curve 5
shpix   28  5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
mdrp[rp0,rnd,white] 17
mdrp[rnd,grey]  23
f_deltap    23 19+8  23 24+8
ip  45
ip  39
ip  25
shpix   -16 11
f_deltap    11 14-4  11 15-4  11 16-8
iup[y]
""",

    #kho_kon
    "uni0E05": """
srp0    56
mirp[rp0,rnd,grey]  gap_164     32
f_deltap    32 17+8  32 18+8  32 19+8  32 20+8  32 21+8  
mdrp[rnd,grey]  35
mirp[rp0,min,rnd,grey]  hstem   31
mdrp[rnd,grey]  11
shpix   -8  11
ip  14
srp0    32
mdrp[rp0,rnd,white] 17
f_deltap    17 12+8  
mdrp[rnd,grey]  23
f_deltap    23 13-8  23 18-8  23 19-8  23 23-8  23 24-8
ip  28
ip  53
ip  47
srp1    11
srp2    53
ip  17
ip  28
srp0    57
mirp[rp0,rnd,white] gap_164 43
mirp[min,rnd,grey]  hstem   1
iup[x]
shpix   24  27
shpix   -24 21
shpix   -24 22
shpix   -24 24
shpix   -24 25
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     31
mirp[rp0,rnd,grey]  vheight_shoot   40
alignrp     38
ip  14
mirp[grey]  vstem_curve 5
shpix   28  5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
shp[rp2]    8
mdrp[rp0,rnd,grey]  6
ip  39
mdrp[rp0,min,rnd,white] 20
shpix   -28 39
shpix   -28 6
mdrp[rnd,grey]  26
f_deltap    26 19+8  26 24+8
ip  50
ip  44
ip  28
f_deltap    14 14-4  14 15-8  14 16-8
f_deltap    28 14+4  28 15+4  28 16+4
iup[y]
""",

    #kho_rakang
    "uni0E06": """
srp0    79
mdrp[rp0,rnd,grey]  37
f_deltap    37 19+8
mdrp[rnd,grey]  31
f_deltap    31 13-8  31 23-8
ip  26
ip  64
ip  58
mdrp[rp0,rnd,white]  20
f_deltap    20 15+8   20 23-8  20 27-8
ip  40
ip  42
ip  24
ip  22
mdrp[grey]  44
mdrp[rp0,rnd,grey]  14
f_deltap    14 16+8  14 18+8  
mirp[rp0,min,rnd,grey]  hstem 49
alignrp     3
mdrp[rnd,grey]  9
f_deltap    9 12+8  9 16+8  
ip  76
ip  70
srp0    80
mirp[rp0,rnd,grey]  gap_164 54
mirp[min,rnd,grey]  hstem 52
shp[rp2]    1
iup[x]
shpix   24  35
shpix  -24  29
shpix  -24  30
shpix  -24  32
shpix  -24  33
#
svtca[y-axis]
mdap[rnd]   0
mdrp[grey]  52
mirp[rnd,grey]  vheight 54
mirp[rp0,rnd,grey]  vheight_shoot 42
alignrp     40
mdrp[grey]  22
shp[rp2]    24
mdrp[rp0,rnd,white] 28
ip  41
ip  23
shpix   -16 41
f_deltap    28 9+8  28 10+8  28 11+8
mdrp[rnd,grey]  34
f_deltap    34 19+8  34 24+8  
ip  61
ip  55
srp1    34
srp2    0
ip  16
ip  48
srp0    0
mirp[rp0,rnd,grey]  vheight_lo 6
mdrp[rp0,rnd,grey]  12
ip  73
ip  67
mdrp[rp0,rnd,grey]  50
mdrp[grey]  3
iup[y]
""",

    #ngo_ngu
    "uni0E07": """
srp0    37
mdrp[rp0,rnd,white] 4
mdrp[grey]  5
srp0    38
mirp[rp0,rnd,white] gap_164 22
mirp[min,rnd,grey]  hstem 11
mdrp[rnd,grey]  17
f_deltap    17 12+4  17 13+4
ip  34
ip  28
mdrp[grey]  1
ip  8
f_deltap    3 12+4  3 13+4  3 14+4  3 15+4  3 16+6
IUP[x]
shpix   24  19
shpix   24  18
shpix   24  16
shpix   16  15
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[grey]  vstem 9
shpix   -16 9
mirp[rp0,rnd,grey]  vheight_shoot 20
mdrp[rnd,grey]  14
f_deltap    14 19+8  14 24+8  14 30+8
ip  31
ip  25
srp0    0
mdrp[rp0,rnd,grey]  5
mdrp[grey]  4
shpix   8 4
IUP[y]
""",

    #jo_jan
    "uni0E08": """
srp0    44
mirp[rp0,rnd,grey]  gap_113 22
f_deltap    22 9-8  22 10-8
mdrp[rp0,rnd,grey]  7
mdrp[rnd,grey]  12
f_deltap    12 12-8  
ip  41
ip  35
ip  2
mdrp[rp0,rnd,grey]  1
mdrp[grey]  0
f_deltap    0 14-4  0 15-4  0 16-4 
ip  13
#
srp0    45
mirp[rp0,rnd,grey]  gap_113 29
mirp[min,rnd,grey]  hstem 16
f_deltap    12 10-3  12 12+2  12 13-2  12 14-1  12 15-2  12 16-3  12 18+1  12 20+1  12 21-3  
srp1    13
srp2    12
ip  11
IUP[x]
shpix    24  9
shpix    24  8
shpix    24  6
shpix    24  5
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[grey]  vstem 13
shpix   -16 13
mirp[rp0,rnd,grey]  vheight_shoot 26
mirp[grey]  vstem_curve 19
shpix   28 19
f_deltap    19 9-4  19 10-3  19 11-3  19 12-3  19 13-2  19 14-1 
mdrp[rp0,min,rnd,white]  10
f_deltap    10 14-8  
mdrp[rnd,grey]  4
f_deltap    4 19+8  4 24+8  4 30+8
ip  38
ip  32
ip  2
f_deltap    2 14+4  2 15+4  2 16+4
f_deltap    13 14-4  13 15-3  13 16-4  13 18-4  13 19-4  13 21-4
IUP[y]
""",


    #cho_ching
    "uni0E09": """
srp0    67
mirp[rp0,rnd,white] gap_84 7
mdrp[rnd,grey]  22
mdrp[rp0,rnd,grey]  12
f_deltap    12 12-8  12 13-8
alignrp     0
ip  52
ip  46
mirp[min,rnd,grey]  hstem 1
f_deltap    7 13-4
#
srp0    68
mirp[rp0,rnd,grey]  gap_205 29
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  33
mdrp[rnd,grey]  39
ip      64
ip      58
IUP[x]
shpix    24  9
shpix    24  8
shpix    24  6
shpix    24  5
#
shpix    12  38
shpix    24  37
shpix    -24  35
shpix    -24  34
shpix    -24  32
shpix   -12  31

SVTCA[y-axis]
mdap[rnd]   0
mirp[grey]  vstem_curve 13
mirp[rp0,rnd,grey]  vheight_shoot  26
mirp[grey]  vstem_curve 19
shpix   28 19
f_deltap    19 9-4  19 10-3  19 11-3  19 12-3  19 13-2  19 14-1 
mdrp[rnd,grey]  22
ip  23
shpix   -16 23
mdrp[rp0,rnd,white]  10
f_deltap    10 13-8
mdrp[rnd,grey]  4
f_deltap    4 19+8  4 24+8
ip  49
ip  43
srp0    0
mirp[rp0,rnd,grey]  vheight_lo  36
mdrp[rnd,grey]  30
shp[rp2]    15
ip  41
ip  61
ip  55
IUP[y]
shpix   -16 13
""",

    #cho_chang
    "uni0E0A": """
srp0                62
mirp[rp0,rnd,white]  gap_51 21
mdrp[rnd,grey]  15
f_deltap    15 19-8  
ip  59
ip  53
ip  12
mdrp[rp0,rnd,white] 7
f_deltap    7 14+8  7 28-8  7 29-8  
mdrp[grey]  27
f_deltap    27 14-1  27 15-1  27 16-2 
mdrp[rp0,rnd,grey]  1
f_deltap    1 11-8  1 13+8  1 20-8  1 21-8  
mirp[min,rnd,grey]  hstem 32
srp0    63
mirp[rp0,rnd,grey]  gap_205 47
f_deltap    47 26+8
mirp[min,rnd,grey]  hstem 36
mdrp[rp0,min,rnd,grey]  43
mirp[min,rnd,grey]  hstem 42
srp1    36
srp2    27
ip  39
srp0    39
mdrp[grey]  45
shpix   -16 45
shpix   12 7
f_deltap    45 14-4  45 15-4  45 16-4
IUP[x]
shpix   -12 13
shpix   -24 14
shpix   -24 16
shpix   -24 17
shpix    24 19
#
SVTCA[y-axis]
mdap[rnd]           0
mirp[grey]  vstem 34
shpix   -16 34
mirp[rp0,rnd,grey]  vheight_shoot 24
sloop   3
ip  40 45 39
mdrp[min,rnd,grey]  42
mdrp[rp0,rnd,grey]  10
f_deltap    10 14+2  10 15+2  10 16+2  
mdrp[rp0,rnd,grey]  12
f_deltap    12 10+8  12 11+8  12 12+8  12 13+8  12 14+8  12 15+8  
mdrp[rnd,grey]  18
ip  56
ip  50
IUP[y]
""",

    #so_zo
    "uni0E0B": """
srp0    66
mirp[rp0,rnd,white]  gap_51 24
f_deltap    24 19+8
mdrp[rnd,grey]  18
f_deltap    18 13-8  18 18-8  18 19-8  18 23-8
ip  13
ip  63
ip  57
mdrp[rp0,rnd,white]  7
f_deltap    7 14+8  7 15+8  7 18-8  7 19-8  7 20-8   7 23-8  7 27-8
ip  27
ip  29
ip  11
ip  9
mdrp[grey]  31
mdrp[rp0,rnd,grey]  1
mirp[min,rnd,grey]  hstem 36
#
srp0    67
mirp[rp0,rnd,grey]  gap_205 51
mirp[min,rnd,grey]  hstem 40
mdrp[rp0,min,rnd,grey]  47
mirp[min,rnd,grey]  hstem 46 
srp1    31
srp2    40
ip  43
srp0    43
mdrp[grey]  49
shpix   -16 49
shpix   12 7
f_deltap    49 14-4  49 15-4  49 16-4
IUP[x]
shpix   24  22
shpix   -24 16
shpix   -24 17
shpix   -24 19
shpix   -24 20
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem   38
shpix   -16  38
mirp[rp0,rnd,grey]  vheight_shoot   27
alignrp     29
ip  44
ip  43
ip  49
mdrp[min,rnd,grey]  47
mdrp[grey]  11
shp[rp2]    9
ip  28
ip  10
shpix   -28 28
shpix   -28 10
mdrp[rp0,rnd,white] 15
f_deltap    15 17+8  15 20+8  
mdrp[rnd,grey]  21
f_deltap    21 19+8  21 24+8
ip  60
ip  54
srp1    21
srp2    1
ip  2
ip  36
shpix   -16 28
#f_deltap    28 9-4  28 10-4  28 11-4  28 12-4
IUP[y]
""",

    #sho_sher
    "uni0E0C": """
srp0    77
mirp[rp0,rnd,grey]  gap_197 36
mirp[min,rnd,grey]  hstem 25
mdrp[rnd,grey]  31
f_deltap    31 12-8  31 13-4
ip  62
ip  56
#
srp0    78
mirp[rp0,rnd,grey]  gap_164 52
mirp[min,rnd,grey]  hstem 50
shp[rp2]    1
srp1    36
srp2    50
ip      14
#
mdap[rnd]   14
mirp[min,rnd,grey]  hstem 47
srp1    31
srp2    14
ip      11
mdap[rnd]   11
f_deltap    11 18+8  
mdrp[rnd,grey]  5
ip  74
ip  68
IUP[x]
shpix    -24    29
shpix    -24    30
shpix    -24    32
shpix    -24    33
shpix   12  35
#
shpix   12 13
shpix   24 12
shpix   24 10
shpix   24 9
shpix   -24 7
shpix   -24 6
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[grey]   vstem_curve 50
mirp[rnd,grey]  vheight 52
mirp[rp0,rnd,grey]  vheight_shoot 44
sloop   6
ip  41 40 39 21 22 23
mirp[grey]  vstem_curve 18
shpix   28 18
f_deltap    18 9-4  18 10-3  18 11-3  18 12-3  18 13-2  18 14-1 
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  8
alignrp 34
mdrp[rnd,grey]  14
f_deltap    14 19-8  14 24-8
shp[rp2]    28
sloop   6
ip  59 53 71 65 48 3
shpix   -16 41
IUP[y]
shpix   -16 50
""",

    #yo_ying
    "uni0E0D": """
srp0    82
mirp[rp0,rnd,grey]  gap_197 23
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
ip  48
ip  42
#
srp0    83
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 36
srp1    23
srp2    36
ip      1
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
#
############################
mdrp[rp0,rnd,grey]  54
mdrp[rnd,grey]  60
ip  79
ip  73
srp0    38
mdrp[rp0,rnd,grey]  67
IUP[x]
shpix    -24 16
shpix    -24 17
shpix    -24 19
shpix    -24 20
shpix    12  22
#
shpix    12  56
shpix    12  55 
shpix    -12 58
shpix    -12 59
shpix    -12 61
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[grey]  vstem 35
shpix   -16 35
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 31
sloop   6
ip  26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    1
mirp[rp0,rnd,grey]  vheight_lo 21
mdrp[rnd,grey]  15
f_deltap    15 19-8  15 24-8 
ip  45
ip  39
shpix   -16 28
########################
srp0    1
mdrp[rp0,min,rnd,grey]  57
alignrp 66
mdrp[rp0,rnd,grey]  51
ip  76
ip  70
mdrp[min,rnd,grey]  63
IUP[y]
""",

    #yo_ying
    "uni0E0D.descless": """
srp0    51
mirp[rp0,rnd,grey]  gap_197 23
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  18
ip  48
ip  42
#
srp0    52
mirp[rp0,rnd,grey]  gap_164 38
mirp[min,rnd,grey]  hstem 36
srp1    23
srp2    36
ip      1
#
mdap[rnd]   1
mirp[min,rnd,grey]  hstem 34
#
############################
IUP[x]
shpix    -24 16
shpix    -24 17
shpix    -24 19
shpix    -24 20
shpix    12  22
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]  1
mirp[grey]  vstem 35
shpix   -16 35
mirp[rnd,grey]  vheight 38
mirp[rp0,rnd,grey]  vheight_shoot 31
sloop   6
ip  26 27 28 8 9 10
shpix   -16 28
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    1
mirp[rp0,rnd,grey]  vheight_lo 21
mdrp[rnd,grey]  15
f_deltap    15 19-8  15 24-8 
ip  45
ip  39
########################
IUP[y]
""",

    #do_chada
    "uni0E0E": """
srp0    74
mirp[rp0,rnd,grey]  gap_84 35
f_deltap    35 12-8  35 13-8
mdrp[rp0,rnd,grey]  29
f_deltap    35 12+8  35 13+4
ip  61
ip  55
mirp[min,rnd,grey]  hstem 40
#
srp0    75
mirp[rp0,rnd,grey]  gap_164 51
mirp[min,rnd,grey]  hstem 18
shp[rp2]    1
mdrp[rp0,rnd,grey]  8
mdrp[min,rnd,grey]  71
srp1    71
srp2    18
sloop   4
ip  66 13 16 3
#
IUP[x]
shpix    24  37
shpix    24  36
shpix    24  34
shpix    24  33
shpix    -12 31
#
shpix   16  43
shpix   -16 25
#
shpix    16  66
shpix    -16 16
#
SVTCA[y-axis]
mdap[rnd]   74
mirp[rp0,rnd,grey]  vheight_shoot 48
sloop   6
ip  45 44 45 25 26 27
mirp[grey]  vstem_curve 22
shpix   28  22
f_deltap    22 9-4  22 10-3  22 11-3  22 12-3  22 13-2  22 14-1 
srp0    74
mirp[rp0,rnd,grey]  vheight_lo 32
mdrp[rnd,grey]  38
f_deltap    38 19-8  38 24-8  
ip  58
ip  52
srp0    74
mirp[rp0,rnd,grey]  vheight_lu 5
shp[rp2]    1
mdrp[grey]  18
mdrp[rnd,grey]  11
ip  68
ip  64
IUP[y]
shpix -16 45
shpix   -16 18
""",

    #to_patak
    "uni0E0F": """
srp0    78
mirp[rp0,rnd,grey]  gap_84 41
f_deltap    41 12-8  41 13-8
mdrp[rp0,rnd,grey]  35
f_deltap    41 12+8  41 13+4
ip  67
ip  61
mirp[min,rnd,grey]  hstem 46
#
srp0    79
mirp[rp0,rnd,grey]  gap_164 57
mirp[min,rnd,grey]  hstem 24
shp[rp2]    1
mdrp[rp0,rnd,grey]  11
mdrp[min,rnd,grey]  76
srp1    76
srp2    24
sloop   6
ip  72 16 19 6 21 2
#
IUP[x]
shpix    24  43
shpix    24  42
shpix    24  40
shpix    24  39
shpix    -12 37
#
shpix   16  49
shpix   -16 31
#
shpix    16  72
shpix    -16 19
#
SVTCA[y-axis]
mdap[rnd]   78
mirp[rp0,rnd,grey]  vheight_shoot 54
sloop   6
ip  49 50 51 31 32 33
shpix -16 51
mirp[grey]  vstem_curve 28
shpix   28  28
f_deltap    28 9-4  28 10-3  28 11-3  28 12-3  28 13-2  28 14-1 
srp0    78
mirp[rp0,rnd,grey]  vheight_lo 38
mdrp[rnd,grey]  44
f_deltap    44 19-8  44 24-8  
ip  64
ip  58
srp0    78
mirp[rp0,rnd,grey]  vheight_lu 8
shp[rp2]    4
shp[rp2]    1
mdrp[grey]  24
mdrp[rnd,grey]  14
sloop   5
ip  74 70 6 21 2
IUP[y]
shpix   -16 24
shpix   16  2
shpix   -16 21
""",

    #tho_than
    "uni0E10": """
srp0    117
mirp[rp0,rnd,grey]  gap_113 19
mdrp[min,rnd,grey]  41
srp0    118
mirp[rp0,rnd,grey]  gap_164 44
mdrp[grey]  31
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,rnd,grey]  0
mirp[min,rnd,grey]  hstem 1
ip  13
srp0    44
mdrp[rp0,rnd,grey]  12
f_deltap    12 14+8  12 15+8  12 18-8
mdrp[grey]  2
f_deltap    2 14+4  2 15+4
mdrp[rnd,grey]  7
f_deltap    7 13+4  7 18+8  7 23+8  7 28+8  7 29+8  
ip  56
ip  50
srp1    13
srp2    12
ip  11
###################################
srp0    0
mdrp[rp0,rnd,grey]  96
mdrp[rnd,grey]  91
ip  106
ip  100
mdrp[min,rnd,grey]  85
mdrp[rp0,rnd,grey]  70
mdrp[min,rnd,grey]  115
srp1    115
srp2    85
sloop   4
ip  111 80 82 61
IUP[x]
shpix   16  8
shpix   16  6
shpix   -16 41
shpix   -16 3
#
SVTCA[y-axis]                       
mdap[rnd]   1
mirp[grey]  vstem_curve 13
shpix   -16 13
mirp[rp0,rnd,grey]  vheight_shoot   23
sloop   3
ip  19 20 41
mirp[grey]  vstem_curve 38
shpix   28  38
f_deltap    38 9-4  38 10-3  38 11-3  38 12-3  38 13-2  38 14-1 
mdrp[rp0,grey]  43
mdrp[rp0,grey]  17
mdrp[rp0,grey]  10
mdap[rnd]   10
f_deltap    10 14-8  10 18-8  10 22-8
mdrp[rnd,grey]  4
f_deltap    4 19+8  4 24+8  4 30+8
ip  53
ip  47
ip  2
############################################
#
srp0    1
mdrp[rp0,min,rnd,white]  94
mdrp[rnd,grey]  88
ip  103
ip  97
mdrp[rp0,rnd,grey]  60
alignrp 63
alignrp 67
sloop   4
ip  84 82 85 61
mdrp[rnd,grey]  73
ip  113
ip  109
#
IUP[y]
shpix   -16 13
""",

    #tho_than_descless
    "uni0E10.descless": """
srp0    59
mirp[rp0,rnd,grey]  gap_113 19
mdrp[min,rnd,grey]  41
srp0    60
mirp[rp0,rnd,grey]  gap_164 44
mdrp[grey]  31
mirp[min,rnd,grey]  hstem 16
mdrp[rp0,rnd,grey]  0
mirp[min,rnd,grey]  hstem 1
ip  13
srp0    44
mdrp[rp0,rnd,grey]  12
f_deltap    12 14+8  12 15+8  12 18-8
mdrp[grey]  2
f_deltap    2 14+4  2 15+4
mdrp[rnd,grey]  7
f_deltap    7 13+4  7 18+8  7 23+8  7 28+8  7 29+8  
ip  56
ip  50
srp1    13
srp2    12
ip  11
###################################
IUP[x]
shpix   16  8
shpix   16  6
shpix   -16 41
shpix   -16 3
#
SVTCA[y-axis]                       
mdap[rnd]   1
mirp[grey]  vstem_curve 13
shpix   -16 13
mirp[rp0,rnd,grey]  vheight_shoot   23
sloop   3
ip  19 20 41
mirp[grey]  vstem_curve 38
shpix   28  38
f_deltap    38 9-4  38 10-3  38 11-3  38 12-3  38 13-2  38 14-1 
mdrp[rp0,grey]  43
mdrp[rp0,grey]  17
mdrp[rp0,grey]  10
mdap[rnd]   10
f_deltap    10 14-8  10 18-8  10 22-8
mdrp[rnd,grey]  4
f_deltap    4 19+8  4 24+8  4 30+8
ip  53
ip  47
ip  2
############################################
IUP[y]
shpix   -16 13
""",

    #tho_nangmontho
    "uni0E11": """
srp0    66
mirp[rp0,rnd,grey]  gap_51 33
f_deltap    33 19+8
mdrp[rnd,grey]  27
f_deltap    27 13-8  27 23-8
ip  22
ip  63
ip  57
mdrp[rp0,rnd,white]  16
f_deltap    16 14+8  16 15+8  16 23-8  16 27-8
sloop   4
ip  36 38 20 18
mdrp[grey]  40
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  hstem 45
#
srp0    67
mirp[rp0,rnd,grey]  gap_164 53
mirp[rp0,min,rnd,grey]  hstem 1
srp1    40
srp2    2
ip  49
srp0    49
mdrp[grey]  6
IUP[x]
shpix   -24 25
shpix   -24 26
shpix   -24 28
shpix   -24 29
shpix   24  31
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     9
mdrp[grey]  46
shpix   -16  46
mirp[rp0,rnd,grey]  vheight_shoot   51
alignrp     38
alignrp     36
mirp[grey]  vstem_curve 4
shpix   28  4
f_deltap    4 9-4  4 10-3  4 11-3  4 12-3  4 13-2  4 14-1 
mdrp[grey]  18
shp[rp2]    20
ip  37
shpix   -16 37
f_deltap    37 9-4  37 10-4  37 11-4  37 12-4
mdrp[rp0,rnd,white] 24
f_deltap    24 17+8
mdrp[rnd,grey]  30
f_deltap    30 19+8  30 24+8
ip  60
ip  54
srp1    30
srp2    10
ip  11
ip  45
IUP[y]
""",

    #to_putao
    "uni0E12": """
srp0    82
mirp[rp0,rnd,white] gap_102     44
mirp[min,rnd,grey]	hstem 22
shpix   -8  22
mdrp[rp0,rnd,grey]  41
mirp[min,rnd,grey]	hstem 40
ip	25
srp0    44
mdrp[rp0,rnd,white] 31
f_deltap	31 10-8  31 11-8  31 12-8  31 28+8  31 29+8  
mdrp[rnd,grey]  37
f_deltap	37 19-8  37 24-8  37 30-8  37 31-8  
ip  28
ip  67
ip  61
srp0    83
mirp[rp0,rnd,white] gap_164 57
mirp[min,rnd,grey]  hstem   55
shp[rp2]	1
mdrp[rp0,rnd,grey]	52
f_deltap	52 17+8  52 26+8  52 30+8  52 32+8  
mirp[min,rnd,grey]	hstem 14
mdrp[rp0,rnd,grey]	5
f_deltap	5  14+8
mdrp[rnd,grey]	11
f_deltap	11 24+8
ip	79
ip	73
srp1	44
srp2	52
ip	48
ip	19
ip	18
iup[x]
shpix   24 	29
shpix   24 	30
shpix   24 	32
shpix   24 	33
shpix   -24 35
#
shpix   24  13
shpix   24  12
shpix   24  10
shpix   24  9
shpix   -24 7
shpix   -24 6
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     40
mdrp[grey]	25
mdrp[grey]	55
mirp[rnd,grey]	vheight	57
mirp[rp0,rnd,grey]  vheight_shoot   49
alignrp     47
ip  14
mirp[grey]  vstem_curve 17
shpix   28  17
f_deltap    17 9-4  17 10-3  17 11-3  17 12-3  17 13-2  17 14-1 
shp[rp2]    20
mdrp[rp0,rnd,grey]  18
ip  48
mdrp[rp0,min,rnd,white] 34
shpix   -28 48
shpix   -28 18
mdrp[rnd,grey]  28
f_deltap    28 19+8  28 24+8	28 30+8
ip  64
ip  58
srp0	1
mirp[rp0,rnd,grey]	vheight_lo	8
mdrp[rnd,grey]	14
f_deltap	14 19-8
ip	76
ip	70
ip	53
ip	3
iup[y]
shpix	-16 55
shpix	-16 25
""",

    #no_nane
    "uni0E13": """
srp0    77
mirp[rp0,rnd,white] gap_197 23
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]	18
f_deltap	18 12-8  18 13-4  
ip	62
ip	56
#
srp0    78
#mirp[rp0,rnd,white] gap_84 43
mdrp[rp0,rnd,white] 43
f_deltap	43 10-8  43 11-8
mdrp[rnd,grey]	49
ip	74
ip	68
mdrp[rp0,rnd,grey]	39
mirp[min,rnd,grey]  hstem 37
mdrp[rp0,rnd,grey]	34
alignrp	0
mirp[min,rnd,grey]	hstem 1
#
IUP[x]
shpix   -24 16
shpix   -24 17
shpix   -24 19
shpix   -24 20
shpix   12  22
#
shpix   -24 41
shpix   -24 42
shpix   -24 44
shpix   -24 45
shpix   24  47
shpix   24  48
#
shpix    -16 8
shpix    16  26
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[min,rnd,grey]  vstem_curve 35
mirp[rnd,grey]  vheight 39
mirp[rp0,rnd,grey]  vheight_shoot 31
sloop	6
ip	26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0	0
mirp[rp0,rnd,grey]	vheight_lo	21
alignrp	46
mdrp[rnd,grey]	15
f_deltap	15 19-8  15 24-8  
shp[rp2]	40
shp[rp2]	37
sloop	5
ip	59 53 71 65 51
IUP[y]
shpix   -16 35
shpix   -16 28
""",

    #do_dek
    "uni0E14": """
SRP0    49
MIRP[rp0,rnd,grey]   gap_113 30
mirp[min,rnd,grey]	hstem 8
shpix	-16 8
mdrp[rp0,rnd,grey]	27
mirp[min,rnd,grey]	hstem 26
ip	11
srp0	30
mdrp[rp0,rnd,white]	17
f_deltap    17 11-8  17 12-8  17 17+8
mdrp[rnd,grey]	23
f_deltap    23 19-8  23 24-8  
ip	46
ip	40
ip	14
srp0	50
mirp[rp0,rnd,grey]	gap_164 36
mirp[min,rnd,grey]	hstem 1
srp1    30
srp2    36
ip  33
ip  5
IUP[x]
#
shpix   24  18
shpix   24  16
shpix   24  15
shpix   24  19
shpix   -24 21
shpix   -24 22
#
SVTCA[y-axis]
MDAP[rnd]   26
ALIGNRP     1
mdrp[grey]	11
mirp[rp0,rnd,grey]	vheight_shoot 33
mirp[grey]	vstem_curve 5
shpix   28  5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
mdrp[rp0,rnd,white]	20
f_deltap    20 9-8  20 12-8  20 16-8  
mdrp[rnd,grey]	14
f_deltap    14 19+8  14 24+8  
ip	43
ip	37
f_deltap    11 14-2  11 15-2  11 16-2
IUP[y]
shpix   -16 11
""",

    #to_tao
    "uni0E15": """
SRP0    52
MIRP[rp0,rnd,grey]   gap_113 31
mirp[min,rnd,grey]  hstem 9
shpix   -16 9
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  hstem 27
ip  12
srp0    31
mdrp[rp0,rnd,white] 18
f_deltap    18 11-8  18 12-8  18 17+8
mdrp[rnd,grey]	24
f_deltap    24 19-8  24 24-8  
ip	49
ip	43
ip	15
srp0	53
mirp[rp0,rnd,grey]	gap_164 39
mirp[min,rnd,grey]	hstem 1
srp1    31
srp2    39
ip  35
ip  6
ip  5
IUP[x]
#
shpix   24  20
shpix   24  19
shpix   24  17
shpix   24  16
shpix   -24  22
shpix   -24  23
#
SVTCA[y-axis]
MDAP[rnd]   27
ALIGNRP     1
mdrp[grey]	12
mirp[rp0,rnd,grey]	vheight_shoot 34
alignrp     36
mirp[grey]	vstem_curve 7
shpix   28  7
f_deltap    7 9-4  7 10-3  7 11-3  7 12-3  7 13-2  7 14-1 
shp[rp2]    4
mdrp[rp0,rnd,grey]  5
ip  35
mdrp[rp0,min,rnd,white] 21
shpix   -28 35
shpix   -28 5
mdrp[rnd,grey]  15
f_deltap    15 19+8  15 24+8
ip  46
ip  40
f_deltap    12 16-2
IUP[y]
shpix   -16 12
""",

    #to_tung
    "uni0E16": """
srp0                47
mirp[rp0,rnd,grey]  gap_197 23
mirp[min,rnd,grey]  hstem  12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  44
ip  38
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem  1
IUP[x]
shpix   -24 16
shpix   -24 17
shpix   -24 19
shpix   -24 20
shpix   -12 22
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]           1
mirp[rp0,rnd,grey]  vheight_shoot    31
sloop 6
ip 26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  21
mdrp[rnd,grey]  15
f_deltap    15 19-8  15 24-8
ip  41
ip  35
IUP[y]
shpix   -8 28
""",

    #to_tahan
    "uni0E17": """
srp0    40
mirp[rp0,rnd,grey]  gap_84 15
f_deltap    15 9-8  15 12-8  
mdrp[rp0,rnd,grey]  20
alignrp     8
f_deltap    15 12+8  15 13+4
ip  37
ip  31
mirp[min,rnd,grey]  hstem 9
srp0    41
mirp[rp0,rnd,grey]  gap_164 27
mirp[min,rnd,grey]  hstem 1
srp1    20
srp2    1
ip  23
srp0    23
mdrp[grey]  6
IUP[x]
shpix   24  17
shpix   24  16
shpix   24  14
shpix   24  13
shpix   -12 19
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 25
alignrp     18
ip  21
mirp[grey]  vstem_curve 4
shpix   28 4
f_deltap    4 9-4  4 10-3  4 11-3  4 12-3  4 13-2  4 14-1 
mdrp[rnd,grey]  12
f_deltap    12 19+8  12 24+8
ip  34
ip  28
f_deltap    21 13-8  21 14-6  21 15-6  21 16-4  
IUP[y]
shpix   -16 21
""",

    #to_thong
    "uni0E18": """
srp0    39
mirp[rp0,rnd,grey]  gap_113 11
f_deltap    11 9-8  11 10-8  11 11-8
mdrp[grey]  33
mdrp[rp0,min,rnd,grey]  1
mirp[min,rnd,grey]  hstem 3
srp0    40
mirp[rp0,rnd,grey]  gap_164 36
mirp[min,rnd,grey]  hstem 7
mdrp[grey]  23
IUP[x]
shpix   -16 33
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[grey]  vstem 5
shpix   -16 5
mirp[rp0,rnd,grey]  vheight_shoot 15
sloop   3
ip  11 12 33
mirp[grey]  vstem_curve 30
shpix   28 30
f_deltap    30 9-4  30 10-3  30 11-3  30 12-3  30 13-2  30 14-1 
mdrp[rp0,grey]  35
mdrp[rp0,grey]  9
mdrp[rp0,rnd,grey]  3
mdap[rnd]   3
IUP[y]
""",

    #no_nu
    "uni0E19": """
srp0    55
mirp[rp0,rnd,grey]  gap_84  7
f_deltap    7 9-8  7 10-8  7 11-8  7 12-8  7 13-8
mdrp[rp0,rnd,grey]  12
f_deltap    12 12-8  
f_deltap    7 13+4
ip  40
ip  34
mirp[min,rnd,grey]  hstem 1
srp0    56
mirp[rp0,rnd,grey]  gap_84 21
f_deltap    21 14+8
mdrp[rnd,grey]  27
ip  52
ip  46
mdrp[rp0,rnd,grey]  17
mirp[min,rnd,grey]  hstem 15
IUP[x]
shpix   24  9
shpix   24  8
shpix   24  6
shpix   24  5
shpix   -12 11
#
shpix   -12 19
shpix   -24 20
shpix   -24 22
shpix   -24 23
shpix   24  25
shpix   24  26
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem_curve 13
mirp[rnd,grey]  vheight 17
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rnd,grey]  4
f_deltap    4 19+8  4 24+8
ip  37
ip  31
srp0    0
mirp[rp0,rnd,grey]  vheight_lo  24
mdrp[rnd,grey]  18
ip  49
ip  43
ip  15
ip  29
IUP[y]
shpix   -16 13
shpix   16  29
""",

    #bo_baimai
    "uni0E1A": """
srp0    35
mirp[rp0,rnd,white] gap_84  9
f_deltap    9 9-8  9 13-8
mdrp[rp0,rnd,grey]  14
f_deltap    14 12-8
f_deltap    9 13+4
ip  32
ip  26
mirp[rp0,min,rnd,grey]  hstem   3
mdrp[min,rnd,grey]  1
#
srp0    36
mirp[rp0,rnd,grey]  gap_164 20
mirp[min,rnd,grey]  hstem 18
IUP[x]
shpix    24 11
shpix    24 10
shpix    24 8
shpix    24 7
shpix   -12 13
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem 16
shpix   -16 16
shp[rp2]    3
mirp[rnd,grey]  vheight 20
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
f_deltap    6 19+8  6 24+8  6 30+8
ip  29
ip  23
IUP[y]
""",

    #po_pla
    "uni0E1B": """
srp0    35
mirp[rp0,rnd,white] gap_84  9
f_deltap    9 9-8  9 13-8
mdrp[rp0,rnd,grey]  14
f_deltap    14 12-8  
f_deltap    9 13+4
ip  32
ip  26
mirp[rp0,min,rnd,grey]  hstem   3
mdrp[min,rnd,grey]  1
#
srp0    36
mirp[rp0,rnd,grey]  gap_164 20
mirp[min,rnd,grey]  hstem 18
IUP[x]
shpix    24 11
shpix    24 10
shpix    24 8
shpix    24 7
shpix   -12 13
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem 16
shpix   -16 16
shp[rp2]    3
mirp[rnd,grey]  vheight_po 20
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
f_deltap    6 19+8  6 24+8  6 30+8
ip  29
ip  23
IUP[y]
""",

    #po_phung
    "uni0E1C": """
srp0    34
mirp[rp0,rnd,grey]  gap_186 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 16-8
ip  31
ip  25
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
srp2    19
ip  2
srp0    2
mdrp[grey]  17
mdrp[grey]  18
f_deltap    10 12-8  10 13-4
IUP[x]
shpix    -24    8
shpix    -24    9
shpix    -24    11
shpix    -24    12
shpix    12     6
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[grey]  vstem_curve 19
f_deltap    19 14-3  19 15-3  19 16-3
shp[rp2]    16
mirp[rnd,grey]  vheight 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rp0,rnd,grey]  13
f_deltap    13 19+8  13 24+8
ip  28
ip  22
mdrp[rp0,grey]  17
mdrp[grey]  2
IUP[y]
shpix   -16 16
shpix   -16 19
""",

    #fo_fa
    "uni0E1D": """
srp0    34
mirp[rp0,rnd,grey]  gap_186 4
mirp[min,rnd,grey]  hstem 15
shp[rp2]    3
mdrp[rnd,grey]  10
f_deltap    10 16-8
ip  31
ip  25
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem   19
shp[rp2]    1
srp1    15
srp2    19
ip  2
srp0    2
mdrp[grey]  17
mdrp[grey]  18
f_deltap    10 12-8  10 13-4
IUP[x]
shpix    -24    8
shpix    -24    9
shpix    -24    11
shpix    -24    12
shpix    12     6
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[grey]  vstem_curve 19
f_deltap    19 14-3  19 15-3  19 16-3
shp[rp2]    16
mirp[rnd,grey]  vheight_po 21
mirp[rp0,rnd,grey]  vheight_shoot 7
mdrp[rp0,rnd,grey]  13
f_deltap    13 19+8  13 24+8
ip  28
ip  22
mdrp[rp0,grey]  17
mdrp[grey]  2
IUP[y]
shpix   -16 16
shpix   -16 19
""",

    #po_pan
    "uni0E1E": """
srp0    34
mirp[rp0,rnd,white] gap_84  10
f_deltap    10 9-8  10 12-8  10 13-8
mdrp[rp0,rnd,grey]  15
f_deltap    15 12-8
f_deltap    10 13+4
ip  31
ip  25
mirp[min,rnd,grey]  hstem   4
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21
mirp[min,rnd,grey]  hstem 19
srp1    15
srp2    19
sloop   5
ip  1 2 3 17 18
IUP[x]
shpix   24  12
shpix   24  11
shpix   24  9
shpix   24  8
shpix   -12 14
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rnd,grey]  vheight 20
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  18
ip  2
ip  16
ip  19
shpix   -8 16
shpix   -8 19
shpix   16 2
mdrp[rnd,grey]  7
f_deltap    7 19+8  7 24+8
ip  28
ip  22
IUP[y]
""",

    #fo_fun
    "uni0E1F": """
srp0    34
mirp[rp0,rnd,white] gap_84  10
f_deltap    10 9-8  10 12-8  10 13-8
mdrp[rp0,rnd,grey]  15
f_deltap    15 12-8   
f_deltap    10 13+4
ip  31
ip  25
mirp[min,rnd,grey]  hstem   4   
#
srp0    35
mirp[rp0,rnd,grey]  gap_164 21 
mirp[min,rnd,grey]  hstem 19
srp1    15
srp2    19
sloop   5
ip  1 2 3 17 18
IUP[x]  
shpix   24  12
shpix   24  11
shpix   24  9
shpix   24  8
shpix   -12 14
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rnd,grey]  vheight_po 20
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  18
ip  2
ip  16
ip  19
shpix   -8 16
shpix   -8 19
shpix   16 2
mdrp[rnd,grey]  7
f_deltap    7 19+8  7 24+8
ip  28
ip  22
IUP[y]
""",

    #po_sampao
    "uni0E20": """
srp0    47
mirp[rp0,rnd,grey]  gap_84 18
f_deltap    18 12-8  18 13-8
mdrp[rp0,rnd,grey]  12
f_deltap    18 12+8  18 13+4
ip  44
ip  38
mirp[min,rnd,grey]  hstem 23
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem 1
IUP[x]
shpix    24 20
shpix    24 19
shpix    24 17
shpix    24 16
shpix    -12 14
#
shpix    16  26
shpix    -16 8
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 31
sloop   6
ip  26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28  5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    0
mirp[rp0,rnd,grey]  vheight_lo 15
mdrp[rnd,grey]  21
f_deltap    21 19-8  21 24-8  
ip  41
ip  35
IUP[y]
shpix   -8 28
""",

    #mo_ma
    "uni0E21": """
srp0    55
mirp[rp0,rnd,white] gap_84  9
f_deltap    9 9-8  9 13-8
alignrp 20
mdrp[rp0,rnd,grey]  25
f_deltap    25 12-8
f_deltap    9 13+4
f_deltap    20 13+4
alignrp 3
sloop   4
ip  52 46 40 34
mirp[min,rnd,grey]  hstem   14
#
srp0    56
mirp[rp0,rnd,grey]  gap_164 30
mirp[min,rnd,grey]  hstem 28
shp[rp2]    1
IUP[x]
shpix    24 22
shpix    24 21
shpix    24 19
shpix    24 18
shpix    -12 24
#
shpix    24 11
shpix    24 10
shpix    24 8
shpix    24 7
shpix    -24    5
shpix    -12    4
#
SVTCA[y-axis]
mdap[rnd]   1
mdrp[grey]  28
mirp[rnd,grey]  vheight 30
mirp[rp0,rnd,grey]  vheight_shoot 23
mdrp[rnd,grey]  17
f_deltap    17 19+8  17 24+8
ip  37
ip  31
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  6
mdrp[rnd,grey]  12
f_deltap    12 19-8  12 24-8
sloop   4
ip  49 43 26 3
IUP[y]
shpix   -16 28
shpix   16  3
""",

    #yo_yak
    "uni0E22": """
srp0        50
mirp[rp0,rnd,grey]  gap_186 1
f_deltap    1 9-8  1 16+8
mdrp[grey]  4
mirp[rp0,min,rnd,grey]  hstem 29
mdrp[rnd,grey]  25
mdrp[rp0,rnd,grey]  21
f_deltap    21 12+8  21 13+8  21 14+8  21 15+8  21 16+8
mdrp[grey]  7
mdrp[rnd,grey]  13
f_deltap    13 19-8  13 24-8  13 30-8
ip  19
ip  47
ip  41
srp0    51
mirp[rp0,rnd,grey]  gap_164 35
mirp[min,rnd,grey]  hstem 33
f_deltap    21 14-2  21 15-2  21 16-2  21 21-1
IUP[x]
shpix   12  9
shpix   -24 11
shpix   -24 12
shpix   -24 14
shpix   -24 15
shpix   24  17
shpix   24  18
#
shpix   16  4
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[grey]  vstem 31
shpix   -16 31
mirp[rnd,grey]  vheight 35
mirp[rp0,rnd,grey]  vheight_shoot 10
mdrp[rp0,rnd,grey]  16
f_deltap    16 19+8  16 24+8  16 30+8
ip  44
ip  38
ip  19
mdrp[rp0,rnd,grey]  26
mirp[grey]  vstem 25
shpix   -16 25
ip  4
IUP[y]
shpix   16 19
shpix   -16 22
#
""",

    #ro_ruar
    "uni0E23": """
srp0    52
mirp[rp0,rnd,white]  gap_113 12
mdrp[grey]  34
#
srp0    53
#mirp[rp0,rnd,white]  gap_240 37
mirp[rp0,rnd,white]  gap_113 24
mdrp[rp0,rnd,grey]  37
mirp[min,rnd,grey]  hstem 8
mdrp[rnd,grey]  3
f_deltap    3 12+4  3 13+4
ip  49
ip  43
IUP[x]
shpix    24 5
shpix    24 4
shpix    24 2
shpix    24 1
shpix    -12 39
#
shpix   -16 34
#
SVTCA[y-axis]
mdap[rnd]   52
mirp[rp0,rnd,grey]  vheight_shoot 16
sloop   5
ip  12 13 34 36 10
mirp[grey]  vstem_curve 31
shpix   28 31
f_deltap    31 9-4  31 10-3  31 11-3  31 12-3  31 13-2  31 14-1 
srp0    52
mirp[rp0,rnd,grey]  vheight_lo  0
mdrp[rnd,grey]  6
f_deltap    6 19-8  6 24-8
ip  46
ip  40
IUP[y]
shpix   -8 13
""",

    #lo_lu
    "uni0E24": """
srp0                47
mirp[rp0,rnd,grey]  gap_197 23
mirp[min,rnd,grey]  hstem  12
mdrp[rnd,grey]  18
f_deltap    18 12-8  18 13-4
ip  44
ip  38
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem  1
IUP[x]
shpix   -24 16
shpix   -24 17
shpix   -24 19
shpix   -24 20
shpix   12  22
#
shpix   -16 8
shpix   16  26
#
SVTCA[y-axis]
mdap[rnd]           47
mirp[rnd,grey]  vheight_lu  1
mirp[rp0,rnd,grey]  vheight_shoot    31
sloop 6
ip 26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    47
mirp[rp0,rnd,grey]  vheight_lo  21
mdrp[rnd,grey]  15
f_deltap    15 19-8  15 24-8
ip  41
ip  35
IUP[y]
shpix   -8 28
""",

    #lo_ling
    "uni0E25": """
srp0    51
mirp[rp0,rnd,white] gap_143 17
f_deltap    17 9-8  
mdrp[rnd,grey]  31
mirp[min,rnd,grey]  hstem 6
mdrp[rnd,grey]  12
f_deltap    12 12-8  12 13-4
ip  48
ip  42
srp0    52
mirp[rp0,rnd,white] gap_164 38
mirp[min,rnd,grey]  hstem   24
shp[rp2]    1
IUP[x]
shpix   12  16
shpix   -24 10
shpix   -24 11
shpix   -24 13
shpix   -24 14
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot   35
ip  21
ip  24
f_deltap    24 14-4  24 15-4  24 16-8  24 16-4
mirp[grey]  vstem_curve 28
shpix   28  28
f_deltap    28 9-4  28 10-3  28 11-3  28 12-3  28 13-2  28 14-1 
mdap[rnd]   21
f_deltap    21 9-8
mdrp[grey]  4
shpix   8   4
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  15
mdrp[rnd,grey]  9
f_deltap    9 19-8  9 24-8  9 30-6
ip  45
ip  39
IUP[y]
shpix   -8 32
""",

    #ro_ru
    "uni0E26": """
srp0    47
mirp[rp0,rnd,grey]  gap_84 18
f_deltap    18 12-8  18 13-8
mdrp[rp0,rnd,grey]  12
f_deltap    18 12+8  18 13+4
ip  44
ip  38
mirp[min,rnd,grey]  hstem 23
#
srp0    48
mirp[rp0,rnd,grey]  gap_164 34
mirp[min,rnd,grey]  hstem 1
IUP[x]
shpix    24 20
shpix    24 19
shpix    24 17
shpix    24 16
shpix    -12 14
#
SVTCA[y-axis]
mdap[rnd]   47
mirp[rnd,grey]  vheight_lu 0
mirp[rp0,rnd,grey]  vheight_shoot 31
sloop   6
ip  26 27 28 8 9 10
mirp[grey]  vstem_curve 5
shpix   28  5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
srp0    47
mirp[rp0,rnd,grey]  vheight_lo 15
mdrp[rnd,grey]  21
f_deltap    21 19-8  21 24-8
ip  41
ip  35
IUP[y]
shpix   -8 28
""",

    #wo_wan
    "uni0E27": """
srp0    37
mirp[rp0,min,rnd,white] gap_51  15
#
srp0    38
mirp[rp0,rnd,white]  gap_164 22
mirp[min,rnd,grey]  hstem 8
mdrp[rnd,grey]  3
f_deltap    3 12+8  3 13+4
ip  34
ip  28
IUP[x]
shpix    24 5
shpix    24 4
shpix    24 2
shpix    24 1
shpix    -12 24
#
SVTCA[y-axis]
mdap[rnd]    37
mirp[rp0,rnd,grey]  vheight_shoot 19
mirp[grey]  vstem_curve 12
shpix   28 12
f_deltap    12 9-4  12 10-3  12 11-3  12 12-3  12 13-2  12 14-1 
srp0    37
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  6
f_deltap    6 19-8  6 24-8  6 30-8
ip  31
ip  25
IUP[y]
shpix    -8  16
""",

    #so_sala
    "uni0E28": """
srp0    63
mirp[rp0,rnd,white]  gap_113     38
mirp[min,rnd,grey]  hstem 14
shpix   -16  14
mdrp[rp0,rnd,grey]  35
mirp[min,rnd,grey]  hstem 34
srp1    14
srp2    34
ip  17
srp0    38
mdrp[rp0,rnd,white] 20
mdrp[rnd,grey]  26
f_deltap    26 10-8  26 11-8  26 13-8  26 18-8  26 19-8  26 24-8  26 28-8  26 30-8  
ip  31
ip  50
ip  54
srp1    14
srp2    50
ip  20
ip  31 
#
srp0    64
mirp[rp0,rnd,grey]  gap_186 50
f_deltap    50 17+8
mirp[min,rnd,grey]  hstem 1
iup[x]
shpix   12  22
shpix   -24 24
shpix   -24 25
shpix   -24 27
shpix   -24 28
shpix   24  30
#
shpix   -16 48
shpix   16  9
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp     34
mirp[rp0,rnd,grey]  vheight_shoot   41
ip  17
mirp[grey]  vstem_curve 11
shpix   28  11
f_deltap    11 9-4  11 10-3  11 11-3  11 12-3  11 13-2  11 14-1 
mdrp[rp0,rnd,white] 23
f_deltap    23 9-8
mdrp[rnd,grey]  29
f_deltap    29 19+8  29 24+8  29 30+8  
ip  57
ip  51
ip  31
shpix   -16 17
f_deltap    17 14-6  17 15-4  17 16-8  17 19-8
iup[y]
""",

    #so_lusi
    "uni0E29": """
srp0    70
mirp[rp0,rnd,white] gap_84  9
f_deltap    9 9-8  9 13-8
mdrp[rp0,rnd,grey]  14
f_deltap    9 13+4
ip  55
ip  49
mirp[rp0,min,rnd,grey]  hstem   3
mdrp[min,rnd,grey]  1
#
srp0    71
mirp[rp0,rnd,grey]  gap_205 37
f_deltap    37 15+8
alignrp 43
mirp[min,rnd,grey]  hstem 35
shp[rp2]    18
srp1    14
srp2    37
ip  24
mdap[rnd]   24
mdrp[rnd,grey]  30
ip  67
ip  61
ip  32
IUP[x]
shpix    24 11
shpix    24 10
shpix    24 8
shpix    24 7
shpix    -12 13
#
shpix   16  26
shpix   16  25
shpix   -16 28
shpix   -16 29
shpix   -16 31
#
shpix   -16 32
#
SVTCA[y-axis]
mdap[rnd]  0
mirp[grey]  vstem 16
shpix   -16 16
shp[rp2]    2
mirp[rnd,grey]  vheight 37
mirp[rp0,rnd,grey]  vheight_shoot 12
mdrp[rnd,grey]  6
f_deltap    6 19+8  6 24+8  6 30+8
ip  52
ip  46
mdrp[rp0,rnd,grey]  27
mdrp[rp0,rnd,grey]  21
sloop   6
ip  64 58 35 19 38 43
mdrp[min,rnd,grey]  33
IUP[y]
""",

    #so_sua
    "uni0E2A": """
srp0    63
mirp[rp0,rnd,white] gap_143 17
f_deltap    17 9-8  
mdrp[rnd,grey]  37
mirp[min,rnd,grey]  hstem 6
mdrp[rnd,grey]  12
f_deltap    12 12-8  12 13-4
ip  60
ip  54
srp0    64
mirp[rp0,rnd,white] gap_186 50
mirp[min,rnd,grey]  hstem   24
shp[rp2]    1
IUP[x]
shpix   12  16
shpix   -24 10
shpix   -24 11
shpix   -24 13
shpix   -24 14
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot   41
ip  21
ip  24
f_deltap    24 14-4  24 15-4  24 16-8  24 16-4
mirp[grey]  vstem_curve 34
shpix   28  34
f_deltap    34 9-4  34 10-3  34 11-3  34 12-3  34 13-2  34 14-1 
mdap[rnd]   21
f_deltap    21 9-8
mdrp[grey]  4
shpix   8   4
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  15
mdrp[rnd,grey]  9
f_deltap    9 19-8  9 24-8  9 30-6
ip  57
ip  51
IUP[y]
shpix   -8 38
shpix   -16 24
""",

    #ho_hib
    "uni0E2B": """
srp0    64
mirp[rp0,rnd,grey]  gap_84 15
f_deltap    15 9-8  15 12-8  
mdrp[rp0,rnd,grey]  20
alignrp     8
f_deltap    15 12+8  15 13+4
ip  49
ip  43
mirp[min,rnd,grey]  hstem 9
srp0    65
mirp[rp0,rnd,grey]  gap_164 39
mirp[min,rnd,grey]  hstem 1
mdrp[rp0,rnd,grey]  34
mdrp[rnd,grey]  28
ip  61
ip  55
ip  25
ip  37
srp1    20
srp2    1
ip  23
srp0    23
mdrp[grey]  6
IUP[x]
shpix   24  17
shpix   24  16
shpix   24  14
shpix   24  13
shpix   -12 19
#
shpix   24 30
shpix   24 29
shpix   24 27
shpix   12 26
shpix   -24 32
shpix   -24 33
shpix   -24 35
shpix   -12 36
#
shpix   16  25
shpix   -16  37
#
SVTCA[y-axis]
MDAP[rnd]   1
alignrp 8
mirp[rp0,rnd,grey]  vheight_shoot 18
alignrp     31
ip  21
mdrp[rp0,rnd,grey]  12
f_deltap    12 19+8  12 24+8  12 30+8
sloop   6
ip  46 40 58 52 25 37
mdrp[grey]  4
f_deltap    21 14-2  21 15-2  21 16-2  
IUP[y]
shpix   -16 21
""",

    #lo_jula
    "uni0E2C": """
srp0    61
mirp[rp0,rnd,white] gap_84  10
f_deltap    10 9-8  10 12-8  10 13-8
mdrp[rp0,rnd,grey]  15
f_deltap    15 12-8
f_deltap    10 13+4
ip  46
ip  40
mirp[min,rnd,grey]  hstem   4
#
srp0    62
mirp[rp0,rnd,grey]  gap_205 36
alignrp 31
mirp[min,rnd,grey]  hstem 19
mdrp[rnd,grey]  24
ip      58
ip      52
#
srp1    15
srp2    19
sloop   5
ip  1 2 3 17 18
IUP[x]
shpix    24 12
shpix    24 11
shpix    24 9
shpix    24 8
shpix    -12 14
#
shpix    24 26
shpix    24 25
shpix    24 23
shpix    24 22
shpix    -24 28
shpix    -24 29
#
SVTCA[y-axis]
mdap[rnd]   1
alignrp     3
mirp[rp0,rnd,grey]  vheight_shoot 13
ip  18
ip  2
ip  16
ip  19
shpix   -8 16
shpix   -8 19
shpix   16 2
mdrp[rnd,grey]  7
f_deltap    7 19+8  7 24+8
ip  43
ip  37
mdrp[rp0,rnd,grey]  27
mdrp[rnd,grey]  21
sloop   4
ip  55 49 31 36
IUP[y]
""",

    #aw_ang
    "uni0E2D": """
srp0    45
mirp[rp0,rnd,white] gap_143 1
mdrp[rnd,grey]  23
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  7
f_deltap    7 12-8  7 13-4
ip  42
ip  36
#
srp0    46
mirp[rp0,rnd,white]  gap_164 30
mirp[min,rnd,grey]  hstem 16
IUP[x]
shpix    -24 5
shpix    -24 6
shpix    -24 8
shpix    -24 9
shpix    12  3
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[grey]  vstem   14
shpix   -16  14
mirp[rp0,rnd,grey]  vheight_shoot  27
ip  24
ip  23
mirp[grey]  vstem_curve 20
shpix   28 20
f_deltap    20 9-4  20 10-3  20 11-3  20 12-3  20 13-2  20 14-1 
mdrp[rp0,rnd,white]  4
mdrp[rnd,grey]  10
f_deltap    10 19+8  10 24+8  10 30+8
ip  39
ip  33
IUP[y]
shpix   -8 24
""",

    #ho_nokhuk
    "uni0E2E": """
srp0    59
mirp[rp0,rnd,white] gap_143 1
mirp[min,rnd,grey]  hstem 12
mdrp[rnd,grey]  7
f_deltap    7 12-8  7 13-4
ip  42
ip  46
mdrp[rp0,rnd,grey]  24
mirp[min,rnd,grey]  hstem 56
#
srp0    60
mirp[rp0,rnd,white]  gap_164 34
mirp[min,rnd,grey]  hstem 16
sloop   4
ip  51 19 29 32
IUP[x]
shpix    -24 5
shpix    -24 6
shpix    -24 8
shpix    -24 9
shpix    12  3
#
shpix   16  51
shpix   -16 32
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[grey]  vstem   14
shpix   -16  14
mirp[rp0,rnd,grey]  vheight_shoot  27
mirp[grey]  vstem_curve 53
shpix   28 53
f_deltap    53 9-4  53 10-3  53 11-3  53 12-3  53 13-2  53 14-1 
mdrp[rp0,rnd,white]  49
mdrp[grey]  21
mdrp[rp0,rnd,white]  4
mdrp[rnd,grey]  10
f_deltap    10 19+8  10 24+8  10 30+8
ip  43
ip  37
IUP[y]
shpix   -8 24
""",

    #paiyal
    "uni0E2F": """
srp0    35
mirp[rp0,rnd,white]  gap_113 8
mdrp[rnd,grey]  14
ip  32
ip  26
ip  17
#
srp0    36
mirp[rp0,rnd,white]  gap_186 22
mirp[min,rnd,grey]  hstem 1
shp[rp2]    21
IUP[x]
shpix   24 10
shpix   24 9
shpix   -24 12
shpix   -24 13
shpix   -24 15
shpix   -12 16
#
shpix   -16 17
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 11
mdrp[grey]  2
mdrp[grey]  22
mdrp[rp0,rnd,grey]  17
ip  29
ip  23
mdrp[grey]  5
f_deltap    2 14+4  2 15+4  2 16+4
IUP[y]
shpix   16  2
""",

    #sara_a
    "uni0E30": """
srp0    60
mirp[rp0,rnd,white]  gap_102 3
alignrp 21
mdrp[rnd,grey]  9
f_deltap    9 19-8  9 24-8  9 30-8
shp[rp2]    27
sloop   6
ip  45 39 11 57 51 29
#
srp0    61
mdrp[rp0,rnd,white]  15
alignrp     33
IUP[x]
shpix   24  5
shpix   24  4
shpix   -24  7
shpix   -24  8
shpix   -24  10
#
shpix   24  23
shpix   24  22
shpix   -24  25
shpix   -24  26
shpix   -24  28
#
shpix   -16 11
shpix   16 12
shpix   -16 29
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[min,rnd,grey]  11
mdrp[rp0,rnd,grey]  6
ip  42
ip  36
mdrp[rnd,grey]  14
#
srp0    0
mirp[rp0,rnd,grey]  vheight 24
mdrp[rnd,grey]  32
mdrp[rp0,rnd,grey]  18
ip  54
ip  48
mdrp[min,rnd,grey]  29
IUP[y]
""",

    #sara mai han-akat
    "uni0E31": """
mdap[rnd]   9
mdrp[rnd,grey]  3
ip  27
ip  21
ip  11
IUP[x]
shpix   24  5
shpix   24  4
shpix   -24 7
shpix   -24 8
shpix   -24 10
shpix   -16 11
#
SVTCA[y-axis]
mdap[rnd]   0
mdrp[min,rnd,grey]  11
mdrp[rnd,grey]  6
ip  24
ip  18
shpix   -8 11
shpix   8 0
IUP[y]
""",

    #sara_aa
    "uni0E32": """
srp0    16
mirp[min,rnd,white]  gap_51 8
#
srp0    17
mirp[rp0,rnd,white]  gap_164 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_shoot 12
ip  9
ip  8
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
IUP[y]
shpix   -8 9
""",

    #sara_am
    #uni0E33: use sara_aa with nikahit
    
    #sara_i
    "uni0E34": """
mdap[rnd]   0
mdrp[rnd,grey]  14
mdrp[rp0,rnd,grey]  4
mdrp[rnd,grey]  20
IUP[x]
shpix   -16 19
shpix   16  15
#
SVTCA[y-axis]
mdap[rnd]   12
f_deltap    12 9+8  12 11+8  12 12+8  12 14+8
mdrp[grey]  2
shpix   8   2
#
mdrp[rp0,min,rnd,white]   17
mdrp[min,rnd,grey]  8
shpix   -8  12
shpix   8   17
#f_deltap 15 15+4  15 16+4
IUP[y]
""",

    #sara_ii
    "uni0E35": """
mdap[rnd]   0
mdrp[min,rnd,grey]  16
mdrp[min,rnd,grey]  12
mdrp[rp0,rnd,white]  4
mdrp[min,rnd,grey]  22
shpix   -8  0
IUP[x]
shpix   -16 21
shpix   16  17
#
SVTCA[y-axis]
mdap[rnd]   14
f_deltap    14 9+8  14 11+8  14 12+8  14 14+8
mdrp[grey]  2
shpix   8   2
mdrp[rp0,min,rnd,white]   19
mdrp[rp0,min,rnd,grey]  8
mdrp[min,rnd,grey]  12
shpix   -8  14
shpix   8   19
f_deltap 17 15+4  17 16+4  11 16-1
IUP[y]
""",

    #sara_ue
    "uni0E36": """
mdap[rnd]   0
mdrp[rnd,grey]  24
mdrp[rp0,rnd,white]  4
mdrp[rnd,grey]  30
srp0    0
mdrp[rnd,grey]  10
mdrp[min,rnd,grey]  16
srp1    10
srp2    16
ip  41
ip  35
ip  19
shpix   -8  0
IUP[x]
shpix   -16 29
shpix   16  25
shpix   -16  19
shpix   8   11
shpix   -8  15
shpix   -8  17
#
SVTCA[y-axis]
mdap[rnd]   22
f_deltap    22 9+8  22 11+8  22 12+8  22 14+8
mdrp[grey]  2
shpix   8   2
mdrp[grey]  21
mdrp[rp0,min,rnd,white]   27
mdrp[rp0,min,rnd,grey]  8
mdrp[min,rnd,grey]  13
f_deltap    13 19+8  13 20+8  13 21+8  13 22+8
srp1    13
srp2    21
ip  38
ip  32
ip  19
shpix   -8  22
shpix   8   27
IUP[y]
""",

    #sara_uee
    "uni0E37": """
mdap[rnd]   0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  4
mdrp[min,rnd,grey]  26
srp0    0
mdrp[rp0,min,rnd,grey]  16
mdrp[rp0,min,rnd,white] 13
mdrp[rp0,min,rnd,grey]  11
shpix   -8  0
shpix   -8  13
IUP[x]
shpix   -16 25
shpix   16  21
#
SVTCA[y-axis]
mdap[rnd]   18
f_deltap    18 9+8  18 11+8  18 12+8  18 14+8
mdrp[grey]  2
mdrp[rp0,min,rnd,white]   23
mdrp[rp0,grey]  8
ip  10
ip  13
ip  15
mdrp[min,rnd,grey]  11
shp[rp2]    16
shpix   -8  18
shpix   8   23
IUP[y]
""",

    #sara_u
    "uni0E38": """
mdap[rnd]   12
mdrp[min,rnd,grey]  1
mdrp[rp0,rnd,grey]  7
ip  22
ip  16
IUP[x]
shpix   24  9
shpix   24  8
shpix   24  6
shpix   24  5
shpix   -12 11
SVTCA[y-axis]
mdap[rnd]   10
mdrp[rp0,rnd,grey]  4
ip  19
ip  13
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #sara_uu
    "uni0E39": """
mdap[rnd]   16
mdrp[rp0,min,rnd,grey]  14
mdrp[rp0,min,rnd,white]    13
mdrp[min,rnd,grey]  1
mdrp[rnd,grey]  7
ip  26
ip  20
shpix   -4 16
shpix   -8 13
IUP[x]
shpix   24  9
shpix   24  8
shpix   24  6
shpix   24  5
shpix   -12 11
SVTCA[y-axis]
mdap[rnd]   10
alignrp 16
mdrp[rp0,rnd,grey]  4
ip  23
ip  17
mdrp[rp0,min,rnd,grey]  1
mdrp[min,rnd,grey]  13
IUP[y]
""",

    #pinthu
    "uni0E3A": """
mdap[rnd]   9
mdrp[min,rnd,grey]  3
IUP[x]
SVTCA[y-axis]
mdap[rnd]   6
mdrp[min,rnd,grey]  0
IUP[y]
""",

    #thai_baht
    "uni0E3F": """
srp0    43
mirp[rp0,rnd,white]  gap_197 1
mdrp[min,rnd,grey]  28
shp[rp2]    24
#
srp0    44
mirp[rp0,rnd,white]  gap_164 15
mdrp[min,rnd,grey]  39
mdrp[rp0,rnd,grey]  9
mdrp[min,rnd,grey]  32
srp1    28
srp2    32
ip  25
mdap[rnd]    25
alignrp 20
alignrp 21
alignrp 3
mdrp[grey]  42
shp[rp2]    5
shp[rp2]    35
shp[rp2]    18
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   0
alignrp 18
mdrp[min,rnd,grey]  20
mdrp[min,rnd,grey]  25
shp[rp2]    36
mdrp[rp0,rnd,grey]  3
alignrp     6
mdrp[min,rnd,grey]  4
mdrp[min,rnd,grey]  22
shp[rp2]    35
srp1    22
srp2    25
ip      21
mdap[rnd]   21
alignrp 29
mdrp[min,rnd,grey]  26
shp[rp2]    42
ip  12
IUP[y]
""",

    #sara_e
    "uni0E40": """
srp0    26
mirp[rp0,rnd,white] gap_113 10
f_deltap    10 9+8  10 12+8  10 13+8
mdrp[rp0,rnd,grey]  2
f_deltap    10 12-8  10 13-4
ip  22
ip  16
mirp[min,rnd,grey]  hstem 4
IUP[x]
shpix    -24    8
shpix    -24    9
shpix    -24    11
shpix    -24    12
shpix    12    1
#
SVTCA[y-axis]
MDAP[rnd]   25
mirp[rnd,grey]  vheight 4
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  7
f_deltap    7 19-8  7 24-8  7 30-8
ip  19
ip  13
IUP[y]
""",

    #sara_ae
    #use sara_a reference: uni0E40

    #sara_o
    "uni0E42": """
srp0    52
mirp[rp0,rnd,white]  gap_51 6
mdrp[grey]  28
#
srp0    53
mirp[rp0,rnd,white] gap_113 37
f_deltap    37 9+8  37 12+8  37 13+8
mdrp[rp0,rnd,grey]  2
f_deltap    37 12-8  37 13-4
ip  49
ip  43
mirp[min,rnd,grey]  hstem 31
IUP[x]
shpix    -24    35
shpix    -24    36
shpix    -24    38
shpix    -24    39
shpix    12     1
#
shpix   -16 28
#
SVTCA[y-axis]
mdap[rnd]   52
mirp[rnd,grey]  vheight_lo 0
mirp[rp0,rnd,grey]  vheight_o 10
sloop   5
ip  6 7 28 30 4
mirp[grey]  vstem_curve 25
shpix   28 25
f_deltap    25 9-4  25 10-3  25 11-3  25 12-3  25 13-2  25 14-1 
srp0    52
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  34
ip  46
ip  40
IUP[y]
""",

    #sara_i_moun
    "uni0E43": """
srp0    65
mirp[rp0,rnd,white] gap_113 37
f_deltap    37 9+8  37 12+8  37 13+8
mdrp[rp0,rnd,grey]  2
f_deltap    37 12-8  37 13-4
ip  49
ip  43
mirp[min,rnd,grey]  hstem 31
mdrp[rp0,rnd,grey]  14
mdrp[rp0,min,rnd,white] 8
mirp[min,rnd,grey]  hstem 26
srp0    14
mdrp[rnd,grey]  20
ip  61
ip  55
ip  11
IUP[x]
shpix    -24    35
shpix    -24    36
shpix    -24    38
shpix    -24    39
shpix    12     1
#
shpix    -16    13
shpix    -16   11
shpix    8    8
#
SVTCA[y-axis]
mdap[rnd]   11
mdrp[grey]  23
mdrp[rnd,grey]  17
ip  58
ip  52
MDAP[rnd]   64
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  34
f_deltap    34 19-8  34 24-8  34 30-8
ip  46
ip  40
IUP[y]
shpix   -8 12
shpix   16  10
""",

    #sara_i_mlai
    "uni0E44": """
srp0    38
mirp[rp0,rnd,white] gap_113 22
f_deltap    22 9+8  22 12+8  22 13+8
mdrp[rp0,rnd,grey]  2
f_deltap    22 12-8  22 13-4
ip  34
ip  28
mirp[min,rnd,grey]  hstem 16
mdrp[rnd,grey]  9
ip  13
ip  6
ip  5
IUP[x]
shpix    -24    20
shpix    -24    21
shpix    -24    23
shpix    -24    24
shpix    12     1
#
SVTCA[y-axis]
MDAP[rnd]   37
mirp[rp0,rnd,grey]  vheight_o 16
ip  13
ip  5
mirp[min,rnd,grey]  vstem_curve 3
mdrp[rnd,grey]  10
srp0    37
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[rnd,grey]  19
f_deltap    19 19-8  19 24-8  19 30-8
ip  31
ip  25
IUP[y]
shpix   -9  13
shpix   9   3
""",

    #lakkhangyao
    "uni0E45": """
srp0    16
mirp[min,rnd,grey]  gap_113 8
#
srp0    17
mirp[rp0,rnd,white]  gap_164 15
mirp[min,rnd,grey]  hstem 1
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   16
mirp[rnd,grey]  vheight_lu 0
mirp[rp0,rnd,grey]  vheight_shoot 12
ip  9
ip  8
mirp[grey]  vstem_curve 5
shpix   28 5
f_deltap    5 9-4  5 10-3  5 11-3  5 12-3  5 13-2  5 14-1 
IUP[y]
shpix   -8 9
""",

    #maiyamok
    "uni0E46": """
srp0    38
mirp[rp0,rnd,white]	gap_113	19
mdrp[rnd,grey]	13
ip	35
ip	29
ip	8
srp0    39
mirp[rp0,rnd,white]  gap_186 25
mirp[min,rnd,grey]  hstem 1
srp1    8
sloop   6
ip  21 6 22 5 23 4
IUP[x]
shpix   -24 11
shpix   -24 12
shpix   -24 14
shpix   -24 15
shpix   12  17
#
shpix   -16 8
shpix   -9  35
#
SVTCA[y-axis]
MDAP[rnd]   38
mirp[rnd,grey]  vheight_lu 1
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 23
mirp[grey]  vstem_curve   6
shpix   28 6
f_deltap    6 9-4  6 10-3  6 11-3  6 12-3  6 13-2  6 14-1 
shp[rp2]    4
mdrp[rp0,min,rnd,grey]  22
mirp[min,rnd,grey]  vstem   5
mdrp[rp0,rnd,white]  10
mdrp[rnd,grey]	16
ip	32
ip	26
shpix   -8 22
shpix   8   6
shpix   8   4
shpix   9   32
IUP[y]
""",

    #maitaikhu
    "uni0E47": """
mdap[rnd]  44
mdrp[grey]  19
mdrp[rnd,grey]  38
f_deltap	38 12-8
ip	56
ip	50
#
mdrp[rp0,rnd,grey]   26
mdrp[min,rnd,grey]   11
shpix   4 11
srp1    26
srp2	38
ip  28
ip  8
shpix   9   36
shpix   -16 26
IUP[x]
shpix   16 39
shpix   16  40
shpix   -16  42
shpix   -16 43
shpix   -16 45
shpix   -8  46
#
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8   
alignrp     8
mdrp[rnd,grey]	31
f_deltap	31 15-4  31 16-4
ip	5
ip	28
ip  36
mdrp[rp0,rnd,grey]	41
ip	53
ip	47
mdrp[rp0,min,rnd,white]	22
f_deltap	41 9+4  41 10+4  41 11+4  41 17+4  41 18+4  41 19+4
mdrp[min,rnd,grey]	15
shpix   -16  15
IUP[y]
shpix   -8  28
""",

    #maiek
    "uni0E48": """
MDAP[rnd]   0
mdrp[min,rnd,grey]  2
shpix	4 2
shpix	-4 0
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8  0 11+8  0 12+8  0 14+8
mdrp[min,rnd,grey]  2
IUP[y]
""",

    #maitho
    "uni0E49": """
MDAP[rnd]   14
mdrp[grey]  22
mdrp[rnd,grey]  8
shp[rp2]    1
ip  28
ip  34
ip  5
ip  17
IUP[x]
shpix   16  10
shpix   16  9
shpix   16  7
shpix   16  6
shpix   -8 12
#
shpix   16  5
shpix   -16 17
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8  0 11+8  0 12+8  0 14+8
mirp[rp0,min,rnd,grey]  vstem_tiny 17
alignrp     2
mdrp[rp0,rnd,grey]  11
ip  31
ip  25
ip  5
mdrp[grey]  21
srp0    0
shpix   -16 17
shpix   -16 2
IUP[y]
""",

    #maitri
    "uni0E4A": """
mdap[rnd]   31
mdrp[grey]  36
mdrp[min,rnd,grey]  5
mdrp[rp0,rnd,grey]  23
sloop   9
ip  26 27 28 7 8 9 2 1 33
mdrp[rp0,min,rnd,grey]  11
mdrp[rnd,grey]  17
f_deltap    17 9-8 17 10-8 17 11-8 17 12-8 17 15-8 17 16-8 17 17-8 17 18-8 17 19-8
ip  47
ip  41
shpix   4   23
shpix   -4  11
shpix   4   5
shpix   -4   31
shpix   8   37
#
IUP[x]
shpix   -8  33
shpix   8   34
#
shpix   18 13
shpix   18 12
shpix   -18 15
shpix   -18 16
shpix   -18 18
shpix   -18 19
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8  0 11+8  0 12+8  0 14+8
alignrp     20
mdrp[grey]  2
ip  33
mdrp[rp0,rnd,grey]  26
alignrp 28
mdrp[grey]  35
mdrp[min,rnd,grey]  9
shp[rp2]    7
ip  27
srp0    20
mdrp[rnd,grey]  14
ip  44
ip  38
ip  11
shpix   8 1
shpix   8 20
shpix   8   9
shpix   8   7
shpix   -16 27
shpix   -16 11
IUP[y]
""",

    #maichattawa
    "uni0E4B": """
#mdap[rnd]   10
#mdrp[rp0,rnd,grey]  0
#alignrp 8
#mirp[rp0,rnd,grey]  vstem 2
#alignrp 6
#mdrp[rnd,grey]  4
#IUP[x]
#shpix   -8  8
#shpix   -8  11
#shpix   8   5
#shpix   8   2
mdap[rnd]   0
alignrp 8
IUP[x]
shpix   8  5
#
SVTCA[y-axis]
#mdap[rnd]   0
#f_deltap    0 9+8  0 11+8  0 12+8  0 14+8
#mdrp[rp0,rnd,grey]  11
#alignrp 2
#mirp[rp0,rnd,grey]  vstem 8
#alignrp 5
#mdrp[rnd,grey]  7
#IUP[y]
#shpix   -8  8
#shpix   8   11
#shpix   -8  5
#shpix   8   2
mdap[rnd]   11
alignrp 2
IUP[y]
shpix   -8 5
""",

    #thanthakhat
    "uni0E4C": """
mdap[rnd]   17
mdrp[grey]  11
mdrp[rp0,rnd,grey]  3
ip  23
ip  29
IUP[x]
shpix   18  1
shpix   -18 19
shpix   -18 18
shpix   -18 16
#
shpix   -16 15
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8  0 12+8 0 14+8  
mdrp[rp0,rnd,grey]  6
ip  20
mdrp[min,rnd,grey]  15
shpix   8 15
mdrp[grey]  10
IUP[y]
""",

    #nikhahit
    "uni0E4D": """
MDAP[rnd]   9
mdrp[rnd,grey]  3
ip  21
ip  15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap	0 12+8  0 14+8
mdrp[rnd,grey]  6
ip  18
ip  12
IUP[y]
""",

    #yamakkan
    "uni0E4E": """
SRP0    0
mdrp[rp0,rnd,grey]  4
mirp[min,rnd,grey]  sarastem 27
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  sarastem 20
srp0    0
mdrp[rnd,grey]  16
mdrp[grey]  24
shpix   -8  20
shpix   -8  27
IUP[x]
shpix   16  7
#
SVTCA[y-axis]
MDAP[rnd]   0
f_deltap    0 9+8   0 12+8   0 14+8
mirp[min,rnd,grey]  headstem    29
mdrp[rp0,rnd,grey]  23
mirp[min,rnd,grey]  headstem    25
ip  7
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  headstem    18
IUP[y]
shpix   -8  13
shpix   -8  23
shpix   -8  29
""",

    #fongman
    "uni0E4F": """
SRP0    56
mirp[rp0,min,rnd,grey]  gap_102 5
mdrp[min,rnd,grey]  29
mdrp[rp0,rnd,grey]  35
mdrp[min,rnd,grey]  53
mdrp[rp0,rnd,grey]  41
mdrp[min,rnd,grey]  47
mdrp[rp0,rnd,grey]  15
mdrp[min,rnd,grey]  23
mdrp[rnd,white]  57
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   56
mirp[rp0,rnd,grey]  vheight_lo 0
mdrp[min,rnd,grey]  20
mdrp[rp0,rnd,grey]  32
mdrp[min,rnd,grey]  44
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  50
mdrp[rp0,rnd,grey]  10
mdrp[min,rnd,grey]  26
IUP[y]
""",

    #thaidigit_zero
    "uni0E50": """
SRP0    24
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[min,rnd,grey]  hstem   21
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  hstem   9
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   24
mirp[rp0,rnd,grey]  vheight_num 6
mirp[grey]  vstem_curve 18
shpix   16  18
srp0    24
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[grey]  vstem_curve 12
shpix   -16  12
IUP[y]
""",

    #thaidigit_one
    "uni0E51": """
SRP0    48
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[min,rnd,grey]  hstem   22
mdrp[rp0,min,rnd,grey]  33
f_deltap    33 23-8  33 29+8
mdrp[min,rnd,grey]  27
ip  45
ip  39
ip  25
srp0    3
mdrp[rp0,rnd,grey] 16
f_deltap    16 14+8
mirp[min,rnd,grey]  hstem 9
IUP[x]
#
shpix   24  29
shpix   24  28
shpix   24  26
shpix   -24  31
shpix   -24  32
shpix   -24  34
#
shpix   16  25
#
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rp0,rnd,grey]  vheight_num 6
mirp[grey]  vstem_curve 19
shpix   16 19
srp0    48
mdrp[rp0,rnd,grey]  0
mdrp[rnd,grey]  30
ip  42
ip  36
ip  25
shpix   -16 25
mdrp[grey]  13
mdrp[grey]  12
shpix   -16 13
IUP[y]
""",

    #thaidigit_two
    "uni0E52": """
SRP0    50
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[rp0,min,rnd,grey]  hstem   8
mdrp[rp0,min,rnd,white]  30
#f_deltap    30 36-8  30 37-8 30 38-8 30 39-8 30 40-8 30 41-8
mdrp[min,rnd,grey]  19
mdrp[rnd,grey]  24
ip  47
ip  41
srp0    3
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  hstem 36
srp1    19
srp2    13
sloop 6
ip  32 33 34 15 16 17
IUP[x]
shpix   -24 22
shpix   -24 23
shpix   -24 25
shpix   -24 26
shpix   24  28
shpix   12  29
#
shpix   -16 19
#
SVTCA[y-axis]
MDAP[rnd]   0
mirp[grey]  vstem 11
shpix   -16 11
mirp[rp0,rnd,grey]  vheight_num 32
alignrp 34
mdrp[grey]  6
mirp[grey]  vstem_curve 17
shpix   16 17
shp[rp2]    15
mdrp[rp0,rnd,white]  21
ip  33
ip  16
shpix   -24 33
shpix   -24 16
mdrp[rnd,grey]  27
ip  44
ip  38
IUP[y]
""",

    #thaidigit_three
    "uni0E53": """
SRP0    52
mirp[rp0,rnd,white]  gap_152 28
mirp[min,rnd,grey]  hstem   16
mdrp[rnd,grey]  22
#f_deltap    22 26-8  22 34-8
ip  49
ip  43
mdrp[rp0,rnd,grey]  10
mirp[min,rnd,grey]  hstem 8
ip  33
mdrp[rp0,rnd,grey]  3
mirp[min,rnd,grey]  hstem 38
IUP[x]
#
shpix   24  18
shpix   -24 20
shpix   -24 21
shpix   -24 23
shpix   -24 24
shpix   12  26
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rp0,rnd,grey]  vheight_num 31
alignrp 35
mirp[grey]  vstem_curve 13
ip  33
shpix   16 13
shp[rp2]    6
srp0    1
mirp[rp0,rnd,grey]  vheight_lo 25
mdrp[rp0,rnd,grey]  19
ip  46
ip  40
mdrp[rnd,grey]  10
IUP[y]
shpix   -16 38
""",

    #thaidigit_four
    "uni0E54": """
SRP0    51
mirp[rp0,min,rnd,grey]  gap_152 7
mirp[min,rnd,grey]  hstem   20
#
srp0    52
alignrp 14
mdrp[rnd,grey]  38
mdrp[rp0,rnd,grey]  33
f_deltap    33 10+8 
mdrp[rnd,grey]  27
ip  48
ip  42
ip  36
ip  25
IUP[x]
shpix   24  29
shpix   24  28
shpix   12  26
shpix   -24 31
shpix   -24 32
shpix   -24 34
shpix   -24 35
#
shpix   16  25
shpix   -16 36
#
SVTCA[y-axis]
MDAP[rnd]   51
mirp[rp0,rnd,grey]  vheight_num 10
mirp[grey]  vstem_curve 16
shpix   16 16
mdrp[rp0,rnd,grey]  30
mdrp[rnd,grey]  36
ip  45
ip  39
srp0    51
mirp[rp0,rnd,grey]  vheight_lo 4
alignrp 0
mirp[grey]  vstem_curve 23
shpix   -16 23
shp[rp2]    38
IUP[y]
""",

    #thaidigit_five
    "uni0E55": """
SRP0    73
mirp[rp0,min,rnd,grey]  gap_152 7
mirp[min,rnd,grey]  hstem   30
#
srp0    74
alignrp 24
mdrp[rnd,grey]  48
mdrp[rp0,rnd,grey]  43
f_deltap    43 10+8 
mdrp[rnd,grey]  37
ip  58
ip  52
ip  46
ip  35
mdrp[rp0,rnd,grey]  18
mdrp[rnd,grey]  12
ip  70
ip  64
ip  10
ip  20
IUP[x]
shpix   24  39
shpix   24  38
shpix   12  36
shpix   -24 41
shpix   -24 42
shpix   -24 44
shpix   -24 45
#
shpix   16  35
shpix   -16 46
shpix   16  10
shpix   -16 20
#
SVTCA[y-axis]
MDAP[rnd]   73
mirp[rp0,rnd,grey]  vheight_num 20
mirp[grey]  vstem_curve 26
shpix   16 26
mdrp[rnd,grey]  15
ip  67
mdrp[rp0,rnd,grey]  40
mdrp[rnd,grey]  46
ip  55
ip  49
srp0    73
mirp[rp0,rnd,grey]  vheight_lo 4
alignrp 0
mirp[grey]  vstem_curve 33
shpix   -16 33
shp[rp2]    48
IUP[y]
""",

    #thaidigit_six
    "uni0E56": """
SRP0    44
mdrp[white]  21
mdrp[rp0,rnd,grey]  19
mdrp[grey]  24
mdrp[rp0,rnd,grey]  3
mdrp[rnd,grey]  9
ip  41
ip  35
ip  11
#
srp0    45
mirp[rp0,rnd,white] gap_152 29
mirp[min,rnd,grey]  hstem   14
IUP[x]
shpix   24  5
shpix   24  6
shpix   -24 7
shpix   -24 8
shpix   -24 10
#
shpix   -16 11
#
SVTCA[y-axis]
MDAP[rnd]   44
mirp[rp0,rnd,grey]  vheight_num 26
mdrp[grey]  24
mdrp[grey]  22
mirp[grey]  vstem_curve 17
shpix   16 17
srp0    44
mirp[rnd,grey]  vheight_lo 0
mirp[grey]  vstem_curve 11
shpix   -16 11
mdrp[rnd,grey]  6
ip  38
ip  32
IUP[y]
""",

    #thaidigit_seven
    "uni0E57": """
SRP0    61
mirp[rp0,rnd,white]  gap_152 28
mirp[min,rnd,grey]  hstem   16
mdrp[rnd,grey]  22
ip  58
ip  52
srp0    28
mdrp[rp0,rnd,grey]  10
f_deltap    10 10-8  10 11-8  10 18-8  10 22-8  10 26-8  10 29-8  10 36-8
mirp[min,rnd,grey]  hstem 8
mdrp[rp0,rnd,grey]  3
f_deltap    3 11-8  3 12-8  3 15+8  3 17-8  
mirp[rp0,min,rnd,grey]  hstem 38
mdrp[rp0,min,rnd,white] 44
mirp[min,rnd,grey]  hstem 46
#mdrp[rnd,white] 62
IUP[x]
#
shpix   24 18
shpix   -24 20
shpix   -24 21
shpix   -24 23
shpix   -24 24
shpix   12  26
#
shpix   -16 40
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[grey]  vstem_curve 40
shpix   -16 40
mirp[rp0,rnd,grey]  vheight_num 31
alignrp 35
mirp[grey]  vstem_curve 13
shpix   16 13
shp[rp2]    6
srp0    1
mirp[rp0,rnd,grey]  vheight_lo 25
mdrp[rp0,rnd,grey]  19
ip  55
ip  49
mdrp[rnd,grey]  10
IUP[y]
""",

    #thaidigit_eight
    "uni0E58": """
SRP0    52
mirp[rp0,rnd,white] gap_152 6
mirp[min,rnd,grey]  hstem   19
mdrp[rp0,grey]  23
mdrp[grey]  24
ip  2
#
srp0    53
alignrp 13
mdrp[rp0,rnd,grey]  37
mdrp[rnd,grey]  31
ip  49
ip  43
IUP[x]
shpix   24  33
shpix   24  32
shpix   24  30
shpix   24  29
shpix   -24 35
shpix   -24 36
shpix   -12 38
#
SVTCA[y-axis]
MDAP[rnd]   52
mirp[rp0,rnd,grey]  vheight_num 9
mirp[grey]  vstem_curve 15
shpix   16 15
srp0    52
mirp[rp0,rnd,grey]  vheight_lo  0
alignrp 3
mirp[grey]  vstem_curve 26
shpix   -16 26
shp[rp2]    22
mdrp[rnd,grey]  34
sloop   5
ip  23 24 2 46 40
IUP[y]
shpix   24 2
shpix   -16 22
""",

    #thaidigit_nine
    "uni0E59": """
SRP0    59
mirp[rp0,rnd,white]  gap_152 26
mirp[rp0,min,rnd,grey]  hstem   9
mdrp[rp0,rnd,grey]  14
mdrp[rp0,rnd,grey]  20
ip  56
ip  50
mdrp[rp0,min,white]  1
ip  31
ip  48
mdrp[grey]  0
shpix   -16 0
IUP[x]
shpix   24  16
shpix   24  15
shpix   24  13
shpix   -24 18
shpix   -24 19
shpix   -24 21
shpix   -12 22
#
SVTCA[y-axis]
MDAP[rnd]   1
mirp[rnd,grey]  vheight_lo 23
mirp[rp0,rnd,grey]  vheight_num 33
alignrp 29
mirp[grey]  vstem_curve 43
shpix   16 43
shp[rp2]    6
srp0    1
mirp[rp0,rnd,grey]  vheight_lo  23
mirp[grey]  vstem_curve 12
mdrp[rnd,grey]  17
ip  53
ip  47
IUP[y]
shpix   -16 31
shpix   -16 35
""",

    #angkhankhu
    "uni0E5A": """
srp0    39
mirp[rp0,rnd,white]  gap_113 8
mdrp[rnd,grey]  14
ip  32
ip  26
ip  17
#
srp0    40
mirp[rp0,rnd,white]	gap_205	38
mirp[rp0,min,rnd,grey]  hstem 36
mdrp[rp0,min,rnd,white]	22
mirp[min,rnd,grey]  hstem 1
shp[rp2]    21
IUP[x]
shpix   24  10
shpix   24  9
shpix   12  7
shpix   -24 13
shpix   -24 12
shpix   -24 15
#
shpix   -16 17
#
SVTCA[y-axis]
mdap[rnd]   0
mirp[rp0,rnd,grey]  vheight_shoot 21
alignrp 11
sloop 	3
ip	22 37 38
mdrp[grey]  2
mdrp[rp0,rnd,grey]  17
ip  29
ip  23
mdrp[grey]  5
f_deltap    2 14+4  2 15+4  2 16+4
IUP[y]
shpix   16  2
""",

    #khomut
    "uni0E5B": """
SRP0    70
mirp[rp0,min,rnd,grey]  gap_152 3
mirp[rp0,min,rnd,grey]  hstem 26
mdrp[rp0,min,rnd,grey]  15
mdrp[rp0,rnd,grey]  9
ip	67
ip	61
ip	20
mdrp[min,rnd,white] 32
#
srp0    71
mirp[rp0,rnd,white] gap_84 45
#
srp1    32
sloop   12
ip  33 34 37 38 39 42 43 49 51 52 54 55
#
IUP[x]
f_deltap    22 15+8  22 16+8  22 18+8 22 19+8 22 20+8 22 21+8 
shpix   36  16
shpix   36  14
shpix   -36  10
shpix   18  61
#
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]  vheight_lo  0
mirp[min,rnd,grey]  vstem_curve 29
srp0    70
mirp[rp0,rnd,grey]  vheight_num 6
mirp[min,rnd,grey]  vstem_curve 23
mdrp[rp0,rnd,grey]  12
f_deltap    12 10+8 12 11+8  12 12+8  12 18+8  12 19+8  12 21+8   12 30+8 12 39+8 
mdrp[rnd,grey]	18
ip	20
ip	64
ip	58
#
mdap[rnd]   55
alignrp     52
alignrp     49
alignrp     45
mdrp[rp0,rnd,grey]  32
alignrp 37
alignrp 42
#
mdap[rnd]   34
alignrp 39
mdrp[rp0,rnd,grey]  54
alignrp 51
#
srp0    0
mdrp[rp0,rnd,grey]  46
mirp[min,rnd,grey]  vstem 45
#
shpix   16 55
shpix   16 52
shpix   16 49
shpix   -16 20
IUP[y]
""",

#    #LAO KHO TAM
    "uni0E84": """
SRP0    56
mdrp[rp0,rnd,white] 15
alignrp 19
mirp[rp0,rnd,grey]	hstem 47
alignrp 38
mdrp[rnd,grey]	42
ip	0
ip	4
mdrp[rnd,grey]	53
ip	49
ip	13
ip	10
srp0	57
mdrp[rp0,rnd,white]	27
mirp[min,rnd,grey]	hstem 29
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   28
mirp[rp0,rnd,grey]	vheight_shoot 23
ip	40
ip	43
ip	51
mdrp[min,rnd,grey]	34
srp0	28
mirp[rp0,rnd,grey]	vheight_lo 55
mdap[rnd]	51
srp1	51
srp2	55
ip	12
ip	8
mdap[rnd]	40
mdap[rnd]	43
f_deltap	43 16+8  43 17+8
srp1	40
srp2	43
ip	5
ip	2
IUP[y]
""",

    #LAO PHO SUNG
    "uni0E9C": """
SRP0    70
mdrp[rp0,rnd,white]	31
mirp[min,rnd,grey]	hstem 38
mdrp[rnd,grey]	36
ip	15
ip	21
mdrp[rp0,rnd,grey]	43
mirp[min,rnd,grey]	hstem 45
ip	26
mdrp[rp0,rnd,grey]	50
mirp[rp0,rnd,grey]	hstem 66
mdrp[rnd,grey]	53
ip	3
ip	9
mdrp[rp0,rnd,grey]	59
mirp[rnd,grey]	hstem 64
#
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   70
mirp[rp0,rnd,grey]	vheight_shoot	34
alignrp		55
mdrp[rnd,grey]	62
mdrp[rp0,rnd,grey]	38
alignrp		51
sloop	6
ip	12 18 0 6 57 66
mdrp[rnd,grey]	45
srp0	70
mirp[rp0,rnd,grey]	vheight_lo 28
alignrp		24
mdrp[min,rnd,grey]	41
shp[rp2]	48
IUP[y]
""",

    #LAO SO SUNG
    "uni0EAA": """
SRP0    62
mdrp[rp0,rnd,white]	46
alignrp	17
mirp[min,rnd,grey]	hstem 40
shp[rp2]	60
mdrp[rp0,rnd,grey]	42
ip	3
ip	9
mdrp[rp0,min,rnd,white]	36
mdrp[min,rnd,grey]	50
srp0	46
mdrp[rp0,rnd,grey]	12
alignrp	56
mirp[min,rnd,grey]	hstem 31
shp[rp2]	21
mdrp[rp0,rnd,grey]	23
mirp[min,rnd,grey]	hstem 29
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   62
mdrp[rp0,rnd,grey]	19
mdrp[min,rnd,grey]	58
mdrp[rp0,rnd,grey]	15
ip	21
ip  31
mdrp[min,rnd,grey]	54
srp0	62
mirp[rp0,rnd,grey]	vheight_lo	44
alignrp	34
mdrp[min,rnd,grey]	52
mdrp[rnd,grey]	40
ip	0
ip	6
mdrp[rp0,rnd,grey]	48
mdrp[rnd,grey]	38
IUP[y]
""",

    #LAO HO SUNG
    "uni0EAB": """
SRP0    58
mdrp[rp0,rnd,white]	16
alignrp	20
mirp[min,rnd,grey]	hstem 28
mdrp[rnd,grey]	24
f_deltap	24 12-5
ip	2
ip	6
ip	18
mdrp[rp0,rnd,grey]	32
mirp[rp0,min,rnd,grey]	hstem 55
ip	42
mdrp[rnd,grey]	38
f_deltap	38 12+5  38 16+8
ip	9
ip	13
srp0	32
mdrp[rp0,rnd,grey]	48
mirp[min,rnd,grey]	hstem 46
IUP[x]
shpix	-16	23
shpix	-16	25
shpix	16  39
shpix	16  37
#
SVTCA[y-axis]
MDAP[rnd]   47
mdrp[rp0,rnd,grey]	22
mdrp[min,rnd,grey]	51
mdrp[rnd,grey]	18
shp[rp2]	35
sloop	6
ip	0 4 7 11 42 55
srp0	47
mirp[rp0,rnd,grey]	vheight_lo	14
mdrp[min,rnd,grey]	30
IUP[y]
""",

    #LAO ELLIPSIS
    "uni0EAF": """
SRP0    40
mdrp[rp0,rnd,white]	15
mirp[min,rnd,grey]	hstem 28
mdrp[rp0,rnd,grey]	20
mdrp[rnd,grey]	24
ip	1
ip	0
srp0	15
mdrp[rp0,rnd,grey]	37
mirp[min,rnd,grey]	hstem 8
ip	7
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   40
mdrp[grey]  4
mdrp[rp0,rnd,grey]	18
mdrp[min,rnd,grey]	26
mdrp[rp0,rnd,grey]	22
ip	0
ip	3
mdrp[rp0,rnd,grey]	35
mdrp[min,rnd,grey]	8
mdrp[rp0,rnd,grey]	30
ip	7
ip	38
mdrp[min,rnd,grey]	13
IUP[y]
""",

    #LAO VOWEL SIGN U
    "uni0EB8": """
mdap[rnd]	19
mdrp[min,rnd,grey]	7
mdrp[rnd,grey]	13
ip	1
ip	0
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   15
mdrp[rp0,rnd,grey]  11
ip	0
ip	4
ip	9
mdrp[grey]	21
IUP[y]
""",

    #LAO VOWEL SIGN MAI KON
    "uni0EBB": """
mdap[rnd]	0
mdrp[min,rnd,grey]	5
mdrp[rp0,rnd,grey]	15
mdrp[rnd,grey]	11
ip	25
ip	21
IUP[x]
SVTCA[y-axis]
MDAP[rnd]   13
alignrp 2
mdrp[rp0,rnd,grey]  19
ip	23
ip	27
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO SEMIVOWEL SIGN NYO
    "uni0EBD": """
SRP0    51
mdrp[rp0,rnd,white]	17
mirp[rp0,min,rnd,grey]	hstem 26
mdrp[rnd,grey]	22
ip	9
ip	3
mdrp[rp0,rnd,grey]	12
mirp[min,rnd,grey]	hstem 31
mdrp[rp0,rnd,grey]	48
mirp[min,rnd,grey]	hstem 35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   51
mdrp[rp0,rnd,grey]	37
sloop	4
ip	34 49 50 33
mdrp[min,rnd,grey]	47
mdrp[rp0,rnd,grey]	44
mdrp[min,rnd,grey]	39
srp0	51
mdrp[rp0,rnd,grey]	15
mdrp[rp0,min,rnd,grey]	29
mdrp[rp0,min,rnd,white]	24
mdrp[rnd,grey]	20
ip	26
ip	6
ip	0
IUP[y]
""",

    #LAO VOWEL SIGN O
    "uni0EC2": """
srp0    41
mdrp[rp0,rnd,white] 23
mdrp[rp0,rnd,grey]  28
ip  3
ip  9
mirp[min,rnd,grey]  hstem 19
mdrp[rnd,grey]  34
ip  15
ip  13
ip  37
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   41
mirp[rp0,rnd,grey]  vheight_lo 26
mdrp[rnd,grey]  21
ip  0
ip  6
mdap[rnd]   36
mdrp[min,rnd,grey]  14
IUP[y]
""",

    #LAO VOWEL SIGN AI
    "uni0EC4": """
srp0    36
mdrp[rp0,rnd,white] 26
mdrp[rp0,rnd,grey]  30
ip  3
ip  9
mirp[min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  13
mirp[min,rnd,grey]  hstem 18
IUP[x]
#
SVTCA[y-axis]
mdap[rnd]   19
mdrp[min,rnd,grey]  34
MDAP[rnd]   35
mirp[rp0,rnd,grey]  vheight_lo 28
mdrp[rnd,grey]  24
ip  0
ip  6
IUP[y]
""",

    #LAO KO LA
    "uni0EC6": """
SRP0    60
mdrp[rp0,rnd,white] 20
alignrp 42
mirp[min,rnd,grey]  hstem 12
shp[rp2]    43
mdrp[rnd,grey]  15
ip  51
ip  57
mdrp[rp0,rnd,grey]  47
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   60
mdrp[rp0,rnd,grey]  23
alignrp 31
mdrp[min,rnd,grey]  10
shp[rp2]    2
mdrp[rp0,rnd,grey]  6
mdrp[min,rnd,grey]  27
mdrp[rp0,rnd,grey]  13
mdrp[rnd,grey]  18
ip  48
ip  54
srp0    60
mdrp[rnd,grey]  43
mdrp[rp0,rnd,grey]  38
mdrp[min,rnd,grey]  45
IUP[y]
""",

    #LAO TONE MAI TI
    "uni0ECA": """
mdap[rnd]   13
mdrp[rp0,rnd,grey]  19
mdrp[min,rnd,grey]  20
srp0    13
mdrp[min,rnd,grey]  28
mdrp[rp0,rnd,grey]  49
mdrp[rnd,grey]  45
mdrp[rp0,rnd,grey]  2
mdrp[min,rnd,grey]  40
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   24
alignrp     0
mdrp[min,rnd,grey]  15
shp[rp2]    42
shp[rp2]    26
mdrp[rnd,grey]  20
mdrp[rnd,grey]  47
mdrp[rp0,rnd,grey]  34
mdrp[min,rnd,grey]  7
mdrp[rp0,rnd,grey]  11
alignrp 4
mdrp[min,rnd,grey]  30
shp[rp2]    38
IUP[y]
""",

    #LAO DIGIT ZERO
    "uni0ED0": """
SRP0    30
mdrp[rp0,rnd,white] 26
mirp[min,rnd,grey]  hstem 4
mdrp[rp0,rnd,grey]  11
mirp[min,rnd,grey]  hstem 18
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   30
mdrp[rp0,rnd,grey]  14
mdrp[min,rnd,grey]  0
srp0    30
mirp[rp0,rnd,grey]  vheight_lo 22
mdrp[min,rnd,grey]  7
IUP[y]
""",

    #LAO DIGIT ONE
    "uni0ED1": """
SRP0    39
mdrp[rp0,rnd,white] 27
mirp[min,rnd,grey]  hstem 15
mdrp[rp0,rnd,grey]  21
mdrp[rnd,grey]  17
ip  3
ip  0
srp0    27
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  hstem 35
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mdrp[grey]  38
mdrp[rp0,rnd,grey]  31
mirp[min,grey]  vstem_curve 11
f_deltap    11 15+1 11 16+2
mdrp[rp0,rnd,grey]  19
mdrp[rnd,grey]  23
ip  17
ip  3
ip  2
IUP[y]
""",

    #LAO DIGIT TWO
    "uni0ED2": """
SRP0    37
mdrp[rp0,rnd,white] 22
mirp[rp0,min,rnd,grey]  hstem 33
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 6
mdrp[rnd,grey]  10
ip  3
ip  2
mdrp[rp0,rnd,grey]  28
mirp[min,rnd,grey]  hstem 27
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   37
mdrp[rnd,grey]  28
mdrp[rp0,rnd,grey]  18
mirp[rnd,grey]  vstem_curve 4
f_deltap 4 15-1 4 16-2
mdrp[rp0,rnd,grey]  12
mdrp[rnd,grey]  8
ip  2
ip  1
IUP[y]
""",

    #LAO DIGIT THREE
    "uni0ED3": """
SRP0    48
mdrp[rp0,rnd,white] 37
mdrp[rp0,rnd,grey]  43
ip  41
mirp[min,rnd,grey]  hstem 45
ip  33
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  hstem 24
srp0    43
mdrp[rp0,rnd,grey]  2
mirp[rp0,min,rnd,grey]  hstem 28
mdrp[rp0,rnd,grey]  16
mdrp[grey]  15
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   48
mirp[rp0,rnd,grey]  vheight_lo 31
alignrp 35
mdrp[min,rnd,grey]  39
mirp[grey]  vstem_curve 0
f_deltap    0 15-1  0 16-2
mdrp[rnd,grey]  45
mdap[rnd]   9
mirp[min,rnd,grey]  vstem_curve 22
mdrp[rp0,min,rnd,grey]  18
mirp[min,rnd,grey]  vstem_curve 13
IUP[y]
""",

    #LAO DIGIT FOUR
    "uni0ED4": """
SRP0    38
mdrp[rp0,rnd,white] 10
mirp[min,rnd,grey]  hstem 21
mdrp[rp0,rnd,grey]  15
mirp[min,rnd,grey]  hstem 16
srp0    10
mdrp[rp0,rnd,grey]  29
mdrp[rp0,rnd,grey]  33
ip  27
ip  3
ip  2
mdrp[rnd,grey]  37
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   38
alignrp 37
mirp[min,rnd,grey]  vstem_curve 4
mdrp[rnd,grey]  15
mdrp[rp0,rnd,grey]  6
mirp[min,rnd,grey]  vstem_curve 25
mdrp[rp0,rnd,grey]  31
mdrp[rnd,grey]  35
ip  2
ip  1
IUP[y]
""",

    #LAO DIGIT FIVE
    "uni0ED5": """
SRP0    51
mdrp[rp0,rnd,white] 4
mirp[min,rnd,grey]  hstem 23
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 15
srp0 4
mdrp[rp0,rnd,grey]  8
mdrp[rnd,grey]  12
ip  46
ip  50
ip  19
mdrp[rp0,rnd,grey]  31
mdrp[rp0,rnd,grey]  35
ip  3
ip  2
ip  29
mdrp[rnd,grey]  39
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   51
alignrp 37
mirp[min,rnd,grey]  vstem_curve 40
mdrp[rnd,grey]  15
mdrp[rp0,rnd,grey]  10
mdrp[rnd,grey]  6
shp[rp2]    19
ip  50
ip  48
srp0    51
mdrp[rp0,rnd,grey]  42
mirp[min,rnd,grey]  vstem_curve 27
mdrp[rp0,rnd,grey]  33
mdrp[rnd,grey]  37
ip  2
ip  1
IUP[y]
""",

    #LAO DIGIT SIX
    "uni0ED6": """
SRP0    65
mdrp[rp0,rnd,white] 10
mirp[min,rnd,grey]  hstem 17
mdrp[rnd,grey]  15
ip  56
ip  62
mdrp[rp0,rnd,grey]  22
mirp[min,rnd,grey]  hstem 24
mdrp[rp0,rnd,grey]  29
mirp[min,rnd,grey]  hstem 52
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  hstem 48
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   65
mdrp[rp0,rnd,grey]  13
mdrp[rp0,rnd,grey]  17
ip  53
ip  59
mdrp[rnd,grey]  24
mdrp[rp0,rnd,grey]  36
mirp[min,rnd,grey]  vstem_curve 46
mdrp[rp0,rnd,grey]  43
mirp[min,rnd,grey]  vstem_curve 38
srp0    65
mirp[rp0,rnd,grey]  vheight_lo 7
alignrp     3
mirp[min,rnd,grey]  vstem_curve 20
shp[rp2]    27
IUP[y]
""",

    #LAO DIGIT SEVEN
    "uni0ED7": """
SRP0    39
mdrp[rp0,rnd,white] 16
alignrp 23
mdrp[rp0,rnd,grey]  38
sloop   4
ip  7 11 1 5
mirp[min,rnd,grey]  hstem 18
mdrp[rp0,rnd,grey]  31
mirp[min,rnd,grey]  hstem 33
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   39
mdrp[rnd,grey]  33
mdrp[rp0,rnd,grey]  25
alignrp 29
mirp[min,rnd,grey]  vstem_curve 36
mdrp[rnd,grey]  22
ip  27
ip  6
ip  9
ip  38
srp0    39
mirp[rp0,rnd,grey]  vheight_lo 14
mdrp[rnd,grey]  18
ip  0
ip  3
IUP[y]
""",

    #LAO DIGIT EIGHT
    "uni0ED8": """
SRP0    86
mdrp[rp0,rnd,white] 48
mirp[min,rnd,grey]  hstem 40
mdrp[rnd,grey]  43
ip  3
ip  9
mdrp[rp0,rnd,grey]  27
alignrp 78
alignrp 76
mirp[min,rnd,grey]  hstem 61
shp[rp2]    65
mdrp[rnd,grey]  70
ip  17
ip  14
mdrp[rp0,rnd,grey]  22
mdrp[min,rnd,grey]  81
IUP[x]
#
SVTCA[y-axis]
MDAP[rnd]   86
mdrp[rp0,rnd,grey]  51
alignrp 59
sloop   4
ip  78 65 27 62
mirp[min,rnd,grey]  vstem_curve 38
shp[rp2]    30
mdrp[rp0,rnd,grey]  34
mirp[min,rnd,grey]  vstem_curve 55
srp0    86
mdrp[rp0,rnd,grey]  45
mdrp[rnd,grey]  41
ip  0
ip  6
mdrp[rp0,rnd,grey]  68
mdrp[rnd,grey]  74
ip  15
ip  13
mdrp[rp0,rnd,grey]  20
mdrp[min,rnd,grey]  82
IUP[y]
""",

    #LAO DIGIT NINE
    "uni0ED9": """
SRP0    33
mdrp[rp0,rnd,white] 26
mirp[min,rnd,grey]  hstem 19
mdrp[rnd,grey]  22
ip  32
ip  31
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 2
mdrp[rp0,rnd,grey]  7
mirp[min,rnd,grey]  hstem 9
IUP[x]
shpix   -24 21
shpix   -24 23
#
SVTCA[y-axis]
MDAP[rnd]   33
mdrp[rnd,grey]  9
mdrp[rp0,rnd,grey]  0
mirp[min,rnd,grey]  vstem_curve 17
srp0    33
mirp[rp0,rnd,grey]  vheight_lo 24
alignrp 12
mdrp[rnd,grey]  20
ip  31
ip  30
mirp[min,rnd,grey]  vstem_curve 5
IUP[y]
""",

    #LAO HO NO
    "uni0EDC": """
SRP0    89
mdrp[rp0,rnd,white] 46
alignrp 50
mirp[min,rnd,grey]  hstem 58
mdrp[rnd,grey]  54
f_deltap    54 12-4
ip  2
ip  6
mdrp[rp0,rnd,grey]  62
mirp[rp0,min,rnd,grey]  hstem 41
mdrp[rnd,grey]  69
f_deltap    69 12+4  69 16+8  
ip  9
ip  13
ip  73
mdrp[rp0,rnd,grey]  14
mirp[min,rnd,grey]  hstem 34
mdrp[rnd,grey]  30
f_deltap    30 16+8  
ip  86
ip  80
ip  26
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  hstem 19
IUP[x]
shpix   -24 53
shpix   -24 55
shpix   24  70
shpix   24  68
shpix   24  31
shpix   24  29
#
SVTCA[y-axis]
MDAP[rnd]   89
mdrp[rnd,grey]  20
mdrp[rp0,rnd,grey]  52
alignrp 71
alignrp 75
mirp[min,rnd,grey]  vstem_curve 37
mdrp[rnd,grey]  48
sloop   5
ip  0 4 7 11 73 
srp0    89
mirp[rp0,rnd,grey]  vheight_lo  44
alignrp 28
alignrp 24
mirp[min,rnd,grey]  vstem_curve 60
shp[rp2]    17
mdrp[rnd,grey]  32
ip  83
ip  77
ip  26
IUP[y]
""",

    #LAO HO MO
    "uni0EDD": """
SRP0    74
mdrp[rp0,rnd,white] 43
alignrp 47
mdrp[rnd,grey]  51
f_deltap    51 12-4
ip  2
ip  6
mirp[min,rnd,grey]  hstem 55
mdrp[rp0,rnd,grey]  59
mirp[rp0,min,rnd,grey]  hstem 38
ip  70
mdrp[rnd,grey]  66
f_deltap    66 12+4  66 16+8
ip  9
ip  13
mdrp[rnd,grey]  29
mdrp[rp0,min,rnd,white]  14
mirp[min,rnd,grey]  hstem 31
ip  26
mdrp[rp0,rnd,grey]  21
mirp[min,rnd,grey]  hstem 19
IUP[x]
shpix   -24 50
shpix   -24 52
shpix   24  67
shpix   24  65
#
SVTCA[y-axis]
MDAP[rnd]   74
mdrp[rnd,grey]  21
mdrp[rp0,rnd,grey]  49
alignrp 68
alignrp 72
mirp[min,rnd,grey]  vstem_curve 34
mdrp[rnd,grey]  45
sloop   5
ip  1 4 8 11 70
shp[rp2]    62
srp0    74
mirp[rp0,rnd,grey]  vheight_lo 41
alignrp 28
alignrp 24
mirp[min,rnd,grey]  vstem_curve 57
shp[rp2]    29
shp[rp2]    17
IUP[y]
""",

#LAO'S
#    "w_115":            69,     #115    =gap1
#    "w_186":            70,     #186    =gap2
#    "w_184":            8,      #184    =hstem
#    "w_195":            18,     #195    =hstem_curve
#    "w_156":            135,    #156    =vstem
#    "w_1147":           184,    #1147   =vheight_shoot
#    "w_1556":           151,    #1556   =vheight_po
#    "w_29":             140,    #29     =vheight_lo
#    "w_1120":           188,    #1120   =vheight
#    "w_426":            189,    #426    =vheight_lu
#    "w_492":            158,    #492    =vheight_lowest


#    #CHAR_NAME
#    "uni0EXX": """
#SRP0    0
#
#IUP[x]
#SVTCA[y-axis]
#MDAP[rnd]   0
#
#IUP[y]
#""",


}

if __name__=="__main__":
    if sys.argv[1] == "--all":
        #$0 --all = ENCODE ALL CHARS
        sfd_file = os.path.basename(sys.argv[0]).split('.',1)[0] + '.sfd'
        print "Encoding all character in %s" % (sfd_file)
        dfont.inst_encode_all( sfd_file, pseudo_code_dict, cvt_dict )
    else:
        #$0 uni0E01 > x.txt = PRINT INSTRUCTION CODE OF uni0E01 TO x.txt
        print '\n'.join(dfont.inst_encode( pseudo_code_dict[sys.argv[1]], cvt_dict ))
